<?php

/**
 * Elementor daltech About Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_About extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve About widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'daltech_about';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve About Nav Tab widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('About', 'daltech-core');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve About Nav Tab widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-code';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the About Nav Tab widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['daltech'];
	}

	// Add The Input For User
	protected function register_controls()
	{

		$this->start_controls_section(
			'about_content_style',
			[
				'label'		=> esc_html__('About Style', 'daltech-core'),
				'tab'		=> \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'style',
			[
				'label' 	=> esc_html__('Style', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  	=> esc_html__('Style One', 'daltech-core'),
					'2'  	=> esc_html__('Style Two', 'daltech-core'),
					'3'  	=> esc_html__('Style Three', 'daltech-core'),
					'4'  	=> esc_html__('Style Four', 'daltech-core'),
				],
			]
		);

		$this->add_control(
			'title',
			[
				'label' 		=> esc_html__('Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'label_block' 	=> true,
				'rows' 			=> '2',
				'placeholder' 	=> esc_html__('title', 'daltech-core'),
				'default' 		=> esc_html__('Default Title', 'daltech-core'),
				'condition' => [
					'style' => ['1', '4', '2', '3']
				]
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label' 		=> esc_html__('Sub-Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'label_block' 	=> true,
				'rows' 			=> '2',
				'placeholder' 	=> esc_html__('subtitle', 'daltech-core'),
				'default' 		=> esc_html__('Default Sub-Title', 'daltech-core'),
				'condition' => [
					'style' => ['1', '4', '2', '3']
				]
			]
		);

		$this->add_control(
			'summary',
			[
				'label' 		=> esc_html__('Summary', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'label_block' 	=> true,
				'rows' 			=> '4',
				'placeholder' 	=> esc_html__('summary', 'daltech-core'),
				'default' 		=> esc_html__('Default Summary', 'daltech-core'),
				'condition' => [
					'style' => ['1', '4', '2', '3']
				]
			]
		);

		$this->add_control(
			'button_label',
			[
				'label' 	=> __('Button Label', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 		=> 2,
				'default'  	=> __('Button Label', 'daltech-core'),
				'condition' => [
					'style' => ['1']
				]
			]
		);

		$this->add_control(
			'url',
			[
				'label' 		=> __('URL', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::URL,
				'placeholder' 	=> __('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
				'condition' => [
					'style' => ['1']
				]
			]
		);

		$this->add_control(
			'author_name',
			[
				'label' 	=> __('Name', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 		=> 2,
				'default'  	=> __('Name', 'daltech-core'),
				'condition' => [
					'style' => ['1']
				]
			]
		);

		$this->add_control(
			'experinace_title',
			[
				'label' 	=> __('Experinace Title', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 		=> 2,
				'default'  	=> __('Experinace Title', 'daltech-core'),
				'condition' => [
					'style' => ['2', '3']
				]
			]
		);

		$this->add_control(
			'experinace_year',
			[
				'label' 	=> __('Experinace Year', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 		=> 1,
				'default'  	=> __('Experinace Year', 'daltech-core'),
				'condition' => [
					'style' => ['2', '3']
				]
			]
		);

		$this->add_control(
			'experinace_operator',
			[
				'label' 	=> __('Experinace Operator', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 		=> 1,
				'default'  	=> __('Experinace Operator', 'daltech-core'),
				'condition' => [
					'style' => ['2']
				]
			]
		);

		$this->add_control(
			'rating_text',
			[
				'label' 	=> __('Rating Text', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 		=> 1,
				'default'  	=> __('Rating Text', 'daltech-core'),
				'condition' => [
					'style' => ['2']
				]
			]
		);

		$this->add_control(
			'rating_number',
			[
				'label' 	=> __('Rating Number', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 		=> 1,
				'default'  	=> __('Rating Number', 'daltech-core'),
				'condition' => [
					'style' => ['2']
				]
			]
		);

		$this->add_control(
			'rating',
			[
				'label' => __('Rating', 'ploming-addon'),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['count'],
				'range' => [
					'count' => [
						'min' => 1,
						'max' => 5,
						'step' => 1,
					],
				],
				'default' => [
					'unit' => 'count',
					'size' => 5,
				],
				'condition' => [
					'style' => ['2']
				]
			]
		);

		$this->add_control(
			'about_check_list_divider',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$this->add_control(
			'check_list',
			[
				'label' 	=> __('Check List', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 		=> 6,
				'default'  	=> __('Check List', 'daltech-core'),
				'condition' => [
					'style' => ['1', '2']
				]
			]
		);

		$layout_one_circle_list = new \Elementor\Repeater();

		$layout_one_circle_list->add_control(
			'title',
			[
				'label' 		=> esc_html__('Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 			=> '1',
				'default'  	=> __('Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_one_circle_list->add_control(
			'number',
			[
				'label' 		=> esc_html__('Number', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'rows'			=> '2',
				'default'  	=> __('Number', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'layout_one_circle_list',
			[
				'label' 	=> esc_html__('Circle List', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::REPEATER,
				'fields' 	=> $layout_one_circle_list->get_controls(),
				'default' 	=> [
					[
						'list_title' => esc_html__('Add Circle List', 'daltech-core'),
					],
				],
				'title_field' => '{{{ title }}}',
				'condition' => [
					'style' => '1'
				]
			]
		);


		$layout_two_feature_list = new \Elementor\Repeater();

		$layout_two_feature_list->add_control(
			'title',
			[
				'label' 		=> esc_html__('Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 			=> '1',
				'default'  	=> __('Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_two_feature_list->add_control(
			'subtitle',
			[
				'label' 		=> esc_html__('Subtitle', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'rows'			=> '2',
				'default'  	=> __('Subtitle', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_two_feature_list->add_control(
			'form_icon_style',
			[
				'label'     => esc_html__('Form Icon Style', 'daltech-core'),
				'type'         => \Elementor\Controls_Manager::SELECT,
				'default'     => '1',
				'options'     => [
					'1'      => esc_html__('Flaticon', 'daltech-core'),
					'3'     => esc_html__('Icon Image', 'daltech-core'),
					'2'      => esc_html__('Custom Icon', 'daltech-core'),
				],
			]
		);

		$layout_two_feature_list->add_control(
			'flat_icon',
			[
				'label'      => esc_html__('Icon One', 'cleanu-core'),
				'type'       => \Elementor\Controls_Manager::ICON,
				'options'    => daltech_flaticons(),
				'include'    => daltech_include_flaticons(),
				'condition' => [
					'form_icon_style' => '1'
				]
			]
		);

		$layout_two_feature_list->add_control(
			'custom_icon',
			[
				'label'         => esc_html__('Custom Icon', 'daltech-core'),
				'type'             => \Elementor\Controls_Manager::TEXTAREA,
				'label_block'     => true,
				'rows'          => '2',
				'condition' => [
					'form_icon_style' => '2'
				]
			]
		);

		$layout_two_feature_list->add_control(
			'icon_image',
			[
				'label'            => esc_html__('Add Image Icon', 'daltech-core'),
				'type'             => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'form_icon_style' => '3'
				]
			]
		);

		$this->add_control(
			'layout_two_feature_list',
			[
				'label' 	=> esc_html__('Feature List', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::REPEATER,
				'fields' 	=> $layout_two_feature_list->get_controls(),
				'default' 	=> [
					[
						'list_title' => esc_html__('Add Feature List', 'daltech-core'),
					],
				],
				'title_field' => '{{{ title }}}',
				'condition' => [
					'style' => '2'
				]
			]
		);

		$layout_two_image_list = new \Elementor\Repeater();

		$layout_two_image_list->add_control(
			'image',
			[
				'label'			=> esc_html__('Add Image', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'layout_two_image_list',
			[
				'label' 	=> esc_html__('Team Image List', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::REPEATER,
				'fields' 	=> $layout_two_image_list->get_controls(),
				'default' 	=> [
					[
						'list_title' => esc_html__('Add Team Image', 'daltech-core'),
					],
				],
				'condition' => [
					'style' => '2'
				]
			]
		);

		$this->add_control(
			'client_text',
			[
				'label' 		=> esc_html__('Client Text', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 			=> '1',
				'default'  	=> __('Client Text', 'daltech-core'),
				'label_block' 	=> true,
				'condition' => [
					'style' => '2'
				]
			]
		);

		$this->add_control(
			'layout_two_client_text_shape',
			[
				'label' => esc_html__('Client Text Shape', 'agrofa-addon'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'selectors' => [
					'{{WRAPPER}} .about-wrapper.style-2 .about-content .about-author .author-image .content p::before' => 'background-image:url({{URL}});',
				],
				'condition' => [
					'style' => ['2']
				]
			]
		);

		$layout_one_feature_list = new \Elementor\Repeater();

		$layout_one_feature_list->add_control(
			'title',
			[
				'label' 		=> esc_html__('Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 			=> '1',
				'default'  	=> __('Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_one_feature_list->add_control(
			'subtitle',
			[
				'label' 		=> esc_html__('Subtitle', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'rows'			=> '2',
				'default'  	=> __('Subtitle', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_one_feature_list->add_control(
			'icon_image',
			[
				'label'			=> esc_html__('Add Image Icon', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'layout_one_feature_list',
			[
				'label' 	=> esc_html__('Feature List', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::REPEATER,
				'fields' 	=> $layout_one_feature_list->get_controls(),
				'default' 	=> [
					[
						'list_title' => esc_html__('Add Feature List', 'daltech-core'),
					],
				],
				'title_field' => '{{{ title }}}',
				'condition' => [
					'style' => '4'
				]
			]
		);

		$this->add_control(
			'about_image_divider',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
			]
		);

		$layout_three_tab_list = new \Elementor\Repeater();

		$layout_three_tab_list->add_control(
			'title',
			[
				'label' 		=> esc_html__('Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 			=> '1',
				'default'  	=> __('Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_three_tab_list->add_control(
			'image',
			[
				'label'			=> esc_html__('Add Image', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$layout_three_tab_list->add_control(
			'url',
			[
				'label' 		=> __('URL', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::URL,
				'placeholder' 	=> __('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				]
			]
		);

		$layout_three_tab_list->add_control(
			'check_list',
			[
				'label' 		=> esc_html__('Check List', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::CODE,
				'rows'			=> '4',
				'default'  	=> __('Check List', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_three_tab_list->add_control(
			'team_image_one',
			[
				'label'			=> esc_html__('Team Image One', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$layout_three_tab_list->add_control(
			'team_image_two',
			[
				'label'			=> esc_html__('Team Image Two', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$layout_three_tab_list->add_control(
			'team_image_three',
			[
				'label'			=> esc_html__('Team Image Three', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$layout_three_tab_list->add_control(
			'customer_text',
			[
				'label' 		=> esc_html__('Customer Text', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'rows'			=> '1',
				'default'  	=> __('Customer Text', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_three_tab_list->add_control(
			'contact_img',
			[
				'label'			=> esc_html__('Contact Image', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$layout_three_tab_list->add_control(
			'contact_info',
			[
				'label' 		=> esc_html__('Contact Info', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::CODE,
				'rows'			=> '4',
				'default'  	=> __('Contact Info', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$this->add_control(
			'layout_three_tab_list',
			[
				'label' 	=> esc_html__('Tab List', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::REPEATER,
				'fields' 	=> $layout_three_tab_list->get_controls(),
				'default' 	=> [
					[
						'list_title' => esc_html__('Add Tab List', 'daltech-core'),
					],
				],
				'title_field' => '{{{ title }}}',
				'condition' => [
					'style' => '3'
				]
			]
		);

		$this->add_control(
			'about_bg_image_one',
			[
				'label'			=> esc_html__('Add Image One', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['1', '2', '4', '3']
				]
			]
		);

		$this->add_control(
			'about_bg_image_two',
			[
				'label'			=> esc_html__('Add Image Two', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['1', '2', '4', '3']
				]
			]
		);

		$this->add_control(
			'about_border_shape',
			[
				'label'			=> esc_html__('Add Border Shape', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['1', '2', '3']
				]
			]
		);

		$this->add_control(
			'about_rounded_shape',
			[
				'label'			=> esc_html__('Add Rounded Shape', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['1', '3']
				]
			]
		);

		$this->add_control(
			'about_rounded_img',
			[
				'label'			=> esc_html__('Add Rounded Image', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['1']
				]
			]
		);

		$this->add_control(
			'author_image',
			[
				'label'			=> esc_html__('Add Author Image', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['1']
				]
			]
		);

		$this->add_control(
			'author_signature_image',
			[
				'label'			=> esc_html__('Add Signature Image', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['1']
				]
			]
		);

		$this->add_control(
			'arrow_shape',
			[
				'label'			=> esc_html__('Add Arrow Shape', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['4']
				]
			]
		);

		$this->add_control(
			'circle_shape',
			[
				'label'			=> esc_html__('Add Circle Shape', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['4']
				]
			]
		);

		$this->add_control(
			'bg_shape',
			[
				'label'			=> esc_html__('Add Bg Shape', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['2', '4']
				]
			]
		);



		$this->end_controls_section();

		include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'about-style.php';
	}

	// Output For User
	protected function render()
	{
		$settings = $this->get_settings_for_display();
		if ($settings['style'] == '1') :
?>

			<!-- Start About Style One -->
			<section class="about-section fix section-padding pt-0">
				<div class="container">
					<div class="about-wrapper">
						<div class="row">
							<div class="col-lg-6">
								<div class="about-image-items">
									<div class="circle-shape">
										<?php
										if (!empty($settings['about_rounded_shape']['url'])) {
											echo daltech_img_tag(array(
												'url'	=> esc_url($settings['about_rounded_shape']['url']),
												'class' => 'text-circle'
											));
										}
										?>
										<div class="award-img">
											<?php
											if (!empty($settings['about_rounded_img']['url'])) {
												echo daltech_img_tag(array(
													'url'	=> esc_url($settings['about_rounded_img']['url']),
												));
											}
											?>
										</div>
									</div>
									<div class="border-shape">
										<?php
										if (!empty($settings['about_border_shape']['url'])) {
											echo daltech_img_tag(array(
												'url'	=> esc_url($settings['about_border_shape']['url']),
											));
										}
										?>
									</div>
									<div class="about-image bg-cover wow fadeInLeft" data-wow-delay=".3s" style="background-image: url(<?php echo esc_url($settings['about_bg_image_one']['url']); ?>);">
										<div class="about-image-2 wow fadeInUp" data-wow-delay=".5s">
											<?php
											if (!empty($settings['about_bg_image_two']['url'])) {
												echo daltech_img_tag(array(
													'url'	=> esc_url($settings['about_bg_image_two']['url']),
												));
											}
											?>
										</div>
									</div>
								</div>
							</div>
							<div class="col-lg-6 mt-5 mt-lg-0">
								<div class="about-content">
									<div class="section-title">
										<span class="wow fadeInUp"><?php echo wp_kses($settings['subtitle'], 'daltech_allowed_tags'); ?></span>
										<h2 class="wow fadeInUp" data-wow-delay=".3s">
											<?php echo wp_kses($settings['title'], 'daltech_allowed_tags'); ?>
										</h2>
									</div>
									<p class=" mt-4 mt-md-0 wow fadeInUp" data-wow-delay=".5s">
										<?php echo wp_kses($settings['summary'], 'daltech_allowed_tags'); ?>
									</p>
									<?php if (!empty($settings['layout_one_circle_list'])) : ?>
										<div class="circle-progress-bar-wrapper">
											<?php foreach ($settings['layout_one_circle_list'] as $item) : ?>
												<div class="single-circle-bar wow fadeInUp" data-wow-delay=".3s">
													<div class="circle-bar" data-percent="<?php echo esc_attr($item['number']); ?>" data-duration="1000">
													</div>
													<div class="content">
														<h6>
															<?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?>
														</h6>
													</div>
												</div>
											<?php endforeach; ?>
										</div>
									<?php endif; ?>
									<?php if (!empty($settings['check_list'])) : ?>
										<ul class="about-list wow fadeInUp" data-wow-delay=".7s">
											<?php echo wp_kses($settings['check_list'], 'daltech_allowed_tags'); ?>
										</ul>
									<?php endif; ?>
									<div class="about-author">
										<?php if (!empty($settings['button_label'])) : ?>
											<div class="about-button wow fadeInUp" data-wow-delay=".8s">
												<a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn">
													<span>
														<?php echo wp_kses($settings['button_label'], 'daltech_allowed_tags'); ?>
														<i class="fas fa-chevron-right"></i>
													</span>
												</a>
											</div>
										<?php endif; ?>
										<div class="author-image wow fadeInUp" data-wow-delay=".9s">
											<?php
											if (!empty($settings['author_image']['url'])) {
												echo daltech_img_tag(array(
													'url'	=> esc_url($settings['author_image']['url']),
												));
											}
											?>
											<div class="content">
												<?php
												if (!empty($settings['author_signature_image']['url'])) {
													echo daltech_img_tag(array(
														'url'	=> esc_url($settings['author_signature_image']['url']),
													));
												}
												?>
												<p><?php echo wp_kses($settings['author_name'], 'daltech_allowed_tags'); ?></p>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</section>
			<!-- End  About Style One -->

		<?php elseif ($settings['style'] == '2') : ?>

			<!--<< About Section Start TWo >>-->
			<section class="about-section section-padding section-bg-2 pt-0">
				<div class="left-shape">
					<?php
					if (!empty($settings['bg_shape']['url'])) {
						echo daltech_img_tag(array(
							'url'	=> esc_url($settings['bg_shape']['url']),
						));
					}
					?>
				</div>
				<div class="container">
					<div class="about-wrapper style-2">
						<div class="row">
							<div class="col-lg-6">
								<div class="about-image-items">
									<div class="border-shape">
										<?php
										if (!empty($settings['about_border_shape']['url'])) {
											echo daltech_img_tag(array(
												'url'	=> esc_url($settings['about_border_shape']['url']),
											));
										}
										?>
									</div>
									<div class="about-image bg-cover wow fadeInUp" data-wow-delay=".3s" style="background-image: url(<?php echo esc_url($settings['about_bg_image_one']['url']); ?>);">
										<div class="about-image-2 wow fadeInUp" data-wow-delay=".4s">
											<?php
											if (!empty($settings['about_bg_image_two']['url'])) {
												echo daltech_img_tag(array(
													'url'	=> esc_url($settings['about_bg_image_two']['url']),
												));
											}
											?>
										</div>
										<div class="experience-text-area wow fadeInUp" data-wow-delay=".5s">
											<h2><span class="count"><?php echo wp_kses($settings['experinace_year'], 'daltech_allowed_tags'); ?></span><?php echo wp_kses($settings['experinace_operator'], 'daltech_allowed_tags'); ?>
											</h2>
											<h6><?php echo wp_kses($settings['experinace_title'], 'daltech_allowed_tags'); ?></h6>
											<div class="star">
												<?php for ($i = 0; $i < $settings['rating']['size']; $i++) : ?>
													<span class="fas fa-star"></span>
												<?php endfor; ?>
												<span><?php echo wp_kses($settings['rating_text'], 'daltech_allowed_tags'); ?></span>
											</div>
											<div class="ratting">
												<span><?php echo wp_kses($settings['rating_number'], 'daltech_allowed_tags'); ?></span>
											</div>
										</div>
									</div>
								</div>
							</div>
							<div class="col-lg-6 mt-5 mt-lg-0">
								<div class="about-content">
									<div class="section-title">
										<span class="wow fadeInUp"><?php echo wp_kses($settings['subtitle'], 'daltech_allowed_tags'); ?></span>
										<h2 class="wow fadeInUp" data-wow-delay=".3s">
											<?php echo wp_kses($settings['title'], 'daltech_allowed_tags'); ?>
										</h2>
									</div>
									<p class=" mt-4 mt-md-0 wow fadeInUp" data-wow-delay=".5s">
										<?php echo wp_kses($settings['summary'], 'daltech_allowed_tags'); ?>
									</p>
									<div class="icon-area">
										<?php foreach ($settings['layout_two_feature_list'] as $item) : ?>
											<div class="icon-items wow fadeInUp" data-wow-delay=".7s">
												<div class="icon">
													<?php if (!empty($item['flat_icon'])) : ?>
														<i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
													<?php endif; ?>
													<?php if (!empty($item['icon_image']['url'])) : ?>
														<img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
													<?php endif; ?>
													<?php
													if (!empty($item['custom_icon'])) : ?>
														<i class="<?php echo esc_attr($item['custom_icon']); ?>"></i>
													<?php endif; ?>
												</div>
												<div class="content">
													<h5><?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?></h5>
													<p>
														<?php echo wp_kses($item['subtitle'], 'daltech_allowed_tags'); ?>
													</p>
												</div>
											</div>
										<?php endforeach; ?>
									</div>
									<ul class="about-list wow fadeInUp" data-wow-delay=".4s">
										<?php echo wp_kses($settings['check_list'], 'daltech_allowed_tags'); ?>
									</ul>
									<div class="about-author wow fadeInUp" data-wow-delay=".6s">
										<div class="author-image">
											<div class="all-client">
												<?php foreach ($settings['layout_two_image_list'] as $item) : ?>
													<div class="client-img">
														<?php
														if (!empty($item['image']['url'])) {
															echo daltech_img_tag(array(
																'url'	=> esc_url($item['image']['url']),
															));
														}
														?>
													</div>
												<?php endforeach; ?>
											</div>
											<div class="content">
												<p><?php echo wp_kses($settings['client_text'], 'daltech_allowed_tags'); ?></p>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</section>
			<!-- Start  About Style Two -->

		<?php elseif ($settings['style'] == '3') : ?>

			<!-- Start  About Style Three -->
			<section class="about-section section-padding">
				<div class="line-shape">
					<?php
					if (!empty($item['about_border_shape']['url'])) {
						echo daltech_img_tag(array(
							'url'	=> esc_url($item['about_border_shape']['url']),
						));
					}
					?>
				</div>
				<div class="container">
					<div class="about-wrapper-2">
						<div class="row">
							<div class="col-lg-6">
								<div class="about-image-items">
									<div class="about-image-1 bg-cover wow fadeInLeft" data-wow-delay=".3s" style="background-image: url(<?php echo esc_url($settings['about_bg_image_one']['url']); ?>);">
										<div class="about-image-2 wow fadeInUp" data-wow-delay=".5s">
											<?php
											if (!empty($settings['about_bg_image_two']['url'])) {
												echo daltech_img_tag(array(
													'url'	=> esc_url($settings['about_bg_image_two']['url']),
												));
											}
											?>
										</div>
									</div>
									<div class="circle-shape">
										<?php
										if (!empty($settings['about_rounded_shape']['url'])) {
											echo daltech_img_tag(array(
												'url'	=> esc_url($settings['about_rounded_shape']['url']),
												'class' => 'text-circle'
											));
										}
										?>
										<div class="about-title">
											<h2><span class="count"><?php echo wp_kses($settings['experinace_year'], 'daltech_allowed_tags'); ?></span>
											</h2>
											<p><?php echo wp_kses($settings['experinace_title'], 'daltech_allowed_tags'); ?></p>
										</div>
									</div>
								</div>
							</div>
							<div class="col-lg-6 mt-5 mt-lg-0">
								<div class="about-content">
									<div class="section-title style-2">
										<span class="wow fadeInUp"><?php echo wp_kses($settings['subtitle'], 'daltech_allowed_tags'); ?></span>
										<h2 class="wow fadeInUp" data-wow-delay=".3s">
											<?php echo wp_kses($settings['title'], 'daltech_allowed_tags'); ?>
										</h2>
									</div>
									<p class=" mt-4 mt-md-0 wow fadeInUp" data-wow-delay=".5s">
										<?php echo wp_kses($settings['summary'], 'daltech_allowed_tags'); ?>
									</p>
									<div class="single-tab-items">
										<ul class="nav mb-4" role="tablist">
											<?php
											$counter = 1;
											foreach ($settings['layout_three_tab_list'] as $item) : ?>
												<li class="nav-item wow fadeInUp" data-wow-delay=".3s" role="presentation">
													<a href="#<?php echo esc_attr(strtolower($item['title'])); ?>" data-bs-toggle="tab" class="nav-link <?php if ($counter == '1') {
																																							echo esc_attr("active", 'daltech-core');
																																						} ?>" aria-selected="true" role="tab">
														<?php echo wp_kses_post($item['title'], 'restan_kses_allowed_html'); ?>
													</a>
												</li>
											<?php
												$counter++;
											endforeach;
											?>
										</ul>
									</div>
									<div class="tab-content">
										<?php
										$counter = 1;
										foreach ($settings['layout_three_tab_list'] as $item) : ?>
											<div id="<?php echo esc_attr(strtolower($item['title'])); ?>" class="tab-pane fade <?php if ($counter == '1') {
																																	echo esc_attr("show active", 'daltech-core');
																																} ?>" role="tabpanel">
												<div class="about-tabs-area">
													<div class="about-list-items">
														<div class="video-image wow fadeInUp" data-wow-delay=".3s">
															<?php
															if (!empty($item['image']['url'])) {
																echo daltech_img_tag(array(
																	'url'	=> esc_url($item['image']['url']),
																));
															}
															?>
															<?php if (!empty($item['url']['url'])) : ?>
																<div class="video-box">
																	<a href="<?php echo esc_url($item['url']['url']); ?>" class="video-btn ripple video-popup">
																		<i class="fas fa-play"></i>
																	</a>
																</div>
															<?php endif; ?>
														</div>
														<ul class="wow fadeInUp" data-wow-delay=".4s">
															<?php echo wp_kses_post($item['check_list'], 'restan_kses_allowed_html'); ?>
														</ul>
													</div>
													<div class="about-author">
														<div class="author-image wow fadeInUp" data-wow-delay=".3s">
															<div class="all-client">
																<div class="client-img">
																	<?php
																	if (!empty($item['team_image_one']['url'])) {
																		echo daltech_img_tag(array(
																			'url'	=> esc_url($item['team_image_one']['url']),
																		));
																	}
																	?>
																</div>
																<div class="client-img">
																	<?php
																	if (!empty($item['team_image_two']['url'])) {
																		echo daltech_img_tag(array(
																			'url'	=> esc_url($item['team_image_two']['url']),
																		));
																	}
																	?>
																</div>
																<div class="client-img">
																	<?php
																	if (!empty($item['team_image_three']['url'])) {
																		echo daltech_img_tag(array(
																			'url'	=> esc_url($item['team_image_three']['url']),
																		));
																	}
																	?>
																</div>
															</div>
															<div class="content">
																<h6><?php echo wp_kses_post($item['customer_text'], 'restan_kses_allowed_html'); ?>
																</h6>
															</div>
														</div>
														<div class="author-contact wow fadeInUp" data-wow-delay=".5s">
															<div class="icon">
																<?php
																if (!empty($item['contact_img']['url'])) {
																	echo daltech_img_tag(array(
																		'url'	=> esc_url($item['contact_img']['url']),
																	));
																}
																?>
															</div>
															<div class="content">
																<?php echo wp_kses_post($item['contact_info'], 'restan_kses_allowed_html'); ?>
															</div>
														</div>
													</div>
												</div>
											</div>
										<?php
											$counter++;
										endforeach;
										?>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</section>
			<!-- Start  About Style THree -->

		<?php elseif ($settings['style'] == '4') : ?>

			<!-- Start  About Style Four -->
			<section class="about-section fix section-padding">
				<div class="shape float-bob-y">
					<?php
					if (!empty($settings['arrow_shape']['url'])) {
						echo daltech_img_tag(array(
							'url'	=> esc_url($settings['arrow_shape']['url']),
						));
					}
					?>
				</div>
				<div class="container">
					<div class="section-title text-center">
						<span class="wow fadeInUp">
							<?php echo wp_kses($settings['subtitle'], 'daltech_allowed_tags'); ?>
						</span>
						<h2 class="wow fadeInUp" data-wow-delay=".3s">
							<?php echo wp_kses($settings['title'], 'daltech_allowed_tags'); ?>
						</h2>
					</div>
					<div class="single-about-wrapper-2">
						<div class="row">
							<div class="col-xl-6 col-lg-6">
								<div class="about-image-item ralt">
									<div class="circle-shape">
										<?php
										if (!empty($settings['circle_shape']['url'])) {
											echo daltech_img_tag(array(
												'url'	=> esc_url($settings['circle_shape']['url']),
											));
										}
										?>
									</div>
									<div class="bg-shape">
										<?php
										if (!empty($settings['bg_shape']['url'])) {
											echo daltech_img_tag(array(
												'url'	=> esc_url($settings['bg_shape']['url']),
											));
										}
										?>
									</div>
									<div class="row">
										<div class="col-lg-6 col-md-6 col-sm-6 wow fadeInUp" data-wow-delay=".3s">
											<div class="about-image-1">
												<?php
												if (!empty($settings['about_bg_image_one']['url'])) {
													echo daltech_img_tag(array(
														'url'	=> esc_url($settings['about_bg_image_one']['url']),
													));
												}
												?>
											</div>
										</div>
										<div class="col-lg-6 col-md-6 col-sm-6 wow fadeInUp" data-wow-delay=".5s">
											<div class="about-image-2">
												<?php
												if (!empty($settings['about_bg_image_two']['url'])) {
													echo daltech_img_tag(array(
														'url'	=> esc_url($settings['about_bg_image_two']['url']),
													));
												}
												?>
											</div>
										</div>
									</div>
								</div>
							</div>
							<div class="col-xl-6 col-lg-6 mt-5 mt-lg-0">
								<div class="about-content">
									<p class="text  wow fadeInUp">
										<?php echo wp_kses($settings['summary'], 'daltech_allowed_tags'); ?>
									</p>
									<?php if (!empty($settings['layout_one_feature_list'])) : ?>
										<?php foreach ($settings['layout_one_feature_list'] as $item) : ?>
											<div class="single-system-item wow fadeInUp" data-wow-delay=".3s">
												<div class="icon">
													<?php
													if (!empty($item['icon_image']['url'])) {
														echo daltech_img_tag(array(
															'url'	=> esc_url($item['icon_image']['url']),
														));
													}
													?>
												</div>
												<div class="content">
													<h4>
														<?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?>
													</h4>
													<p>
														<?php echo wp_kses($item['subtitle'], 'daltech_allowed_tags'); ?>
													</p>
												</div>
											</div>
										<?php endforeach; ?>
									<?php endif; ?>

								</div>
							</div>
						</div>
					</div>
				</div>
			</section>

			<!-- End  About Style Four -->
<?php
		endif;
	}
}
