<?php

/**
 * Elementor Blog Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Blog extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Blog widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_blog';
    }

    /**
     * Get widget title.
     *
     * Retrieve Blog widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Blog', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Blog widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */

    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Blog widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }


    protected function register_controls()
    {

        $this->start_controls_section(
            'blog_section_content',
            [
                'label'        => esc_html__('Set Content', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                    '2'      => esc_html__('Style Two', 'daltech-core'),
                    '3'      => esc_html__('Style Three', 'daltech-core'),
                    '4'      => esc_html__('Style Four', 'daltech-core'),
                    '5'      => esc_html__('Style Five', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'section_title',
            [
                'label'         => esc_html__('Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section title', 'daltech-core'),
                'default'         => esc_html__('Default Section Title', 'daltech-core'),
                'rows'           => '4',
                'label_block'     => true,
            ]
        );

        $this->add_control(
            'section_subtitle',
            [
                'label'         => esc_html__('Sub-Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section subtitle', 'daltech-core'),
                'default'         => esc_html__('Default Section SubTitle', 'daltech-core'),
                'rows'           => '4',
                'label_block'     => true,
            ]
        );

        $this->add_control(
            'button_label',
            [
                'label'     => __('Button Label', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::TEXTAREA,
                'rows'         => 2,
                'default'      => __('Button Label', 'daltech-core'),
                'condition' => [
                    'style' => ['2', '3', '5']
                ]
            ]
        );

        $this->add_control(
            'url',
            [
                'label'         => __('URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => __('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => false,
                    'nofollow'         => false,
                ],
                'condition' => [
                    'style' => ['2', '3', '5']
                ]
            ]
        );

        $this->add_control(
            'post_from',
            [
                'label'         => esc_html__('Post From', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::SELECT,
                'default'         => 'all',
                'options'         => [
                    'all'              => esc_html__('All', 'daltech-core'),
                    'categories'     => esc_html__('Categories', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'post_limit',
            [
                'label'         => esc_html__('Post Limit', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'placeholder'    => esc_html__('Only Number Work. Like 4 or 6', 'daltech-core'),
            ]
        );

        $this->add_control(
            'order',
            [
                'label'         => esc_html__('Order', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::SELECT,
                'default'         => 'ASC',
                'options'         => [
                    'ASC'              => esc_html__('Ascending', 'daltech-core'),
                    'DESC'             => esc_html__('Descending', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'order_by',
            [
                'label'         => esc_html__('Order By', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::SELECT,
                'default'         => 'date',
                'options'         => [
                    'none'          => esc_html__('None', 'daltech-core'),
                    'type'             => esc_html__('Type', 'daltech-core'),
                    'title'         => esc_html__('Title', 'daltech-core'),
                    'name'             => esc_html__('Name', 'daltech-core'),
                    'date'             => esc_html__('Date', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'content_length',
            [
                'label'         => esc_html__('Content Length', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'default'         => '16',
                'placeholder'     => esc_html__('Type Content Length', 'daltech-core'),
            ]
        );

        $this->add_control(
            'read_more',
            [
                'label'         => esc_html__('Read More Text', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'placeholder'    => esc_html__('read more text', 'daltech-core'),
                'default'         => esc_html__('Read More', 'daltech-core'),
            ]
        );


        $this->end_controls_section();

        // Slider Option
        $this->start_controls_section(
            'slider_settings',
            [
                'label' => __('Carousel Settings', 'daltech-core'),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'slidestoshow',
            [
                'label' => __('Slides To Show', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => true,
                'default' => '1',
                'options' => [
                    '1'  => __('1', 'daltech-core'),
                    '2'  => __('2', 'daltech-core'),
                    '3'  => __('3', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'slidestoscroll',
            [
                'label' => __('Slides To Scroll', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => true,
                'default' => '1',
                'options' => [
                    '1'  => __('1', 'daltech-core'),
                    '2'  => __('2', 'daltech-core'),
                    '3'  => __('3', 'daltech-core'),
                    '4'  => __('4', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label' => __('Auto Play?', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'daltech-core'),
                'label_off' => __('Hide', 'daltech-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'infinite',
            [
                'label' => __('Infinite Loop', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'daltech-core'),
                'label_off' => __('Hide', 'daltech-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'autoplaytimeout',
            [
                'label' => __('Autoplay Timeout', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => true,
                'default' => '1000',
                'options' => [
                    '1000'  => __('1 Second', 'daltech-core'),
                    '2000'  => __('2 Second', 'daltech-core'),
                    '3000'  => __('3 Second', 'daltech-core'),
                    '4000'  => __('4 Second', 'daltech-core'),
                    '5000'  => __('5 Second', 'daltech-core'),
                    '6000'  => __('6 Second', 'daltech-core'),
                    '7000'  => __('7 Second', 'daltech-core'),
                    '8000'  => __('8 Second', 'daltech-core'),
                    '9000'  => __('9 Second', 'daltech-core'),
                    '10000' => __('10 Second', 'daltech-core'),
                    '11000' => __('11 Second', 'daltech-core'),
                    '12000' => __('12 Second', 'daltech-core'),
                    '13000' => __('13 Second', 'daltech-core'),
                    '14000' => __('14 Second', 'daltech-core'),
                    '15000' => __('15 Second', 'daltech-core'),
                ],
            ]
        );

        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'blog-style.php';
    }


    protected function render()
    {

        $settings = $this->get_settings_for_display();

        $slidestoshow = !empty($settings['slidestoshow']) ? $settings['slidestoshow'] : '2';
        $slidestoscroll = !empty($settings['slidestoscroll']) ? $settings['slidestoscroll'] : '2';
        $infinite = $settings['infinite'] == 'yes' ? 'true' : 'false';
        $autoplay = $settings['autoplay'] == 'yes' ? 'true' : 'false';
        $autoplaytimeout =  !empty($settings['autoplaytimeout']) ? $settings['autoplaytimeout'] : '800';

        global $post;
        $paged = (get_query_var('paged')) ? get_query_var('paged') : 1;
        $blog = array(
            'post_type'         => 'post',
            'posts_per_page'    => esc_attr($settings['post_limit']),
            'order'             => esc_attr($settings['order']),
            'orderby'           => esc_attr($settings['order_by']),
            'paged' => $paged,
        );
        $daltech_blog = new WP_Query($blog);
        if ($settings['style'] == '1') :
?>
            <!-- Start Blog Area One  -->

            <section class="news-section fix section-padding pt-0">
                <div class="container">
                    <div class="section-title">
                        <span class="wow fadeInUp">
                            <?php echo wp_kses($settings['section_subtitle'], 'daltech_allowed_tags'); ?>
                        </span>
                        <h2 class="wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?>
                        </h2>
                    </div>
                    <div class="row">
                        <?php
                        $counter = 1;
                        while ($daltech_blog->have_posts()) :
                            $daltech_blog->the_post();
                            $daltech_blog_one_img_url = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'full');
                            $categories = get_the_category();
                        ?>
                            <div class="col-lg-6 wow fadeInUp" data-wow-delay=".3s">
                                <div class="single-news-items">
                                    <div class="news-image bg-cover" style="background-image: url(<?php echo esc_url($daltech_blog_one_img_url[0]); ?>);">
                                        <a href="<?php echo  esc_url(get_permalink()); ?>" class="icon">
                                            <i class="fal fa-arrow-right"></i>
                                        </a>
                                    </div>
                                    <div class="news-content">
                                        <ul class="post-date">
                                            <li><?php echo get_the_date('F j, Y'); ?></li>
                                        </ul>
                                        <h3>
                                            <a href="<?php echo  esc_url(get_permalink()); ?>"><?php echo esc_html(get_the_title()); ?></a>
                                        </h3>
                                        <?php if (!empty($settings['read_more'])) : ?>
                                            <div class="news-button mt-4">
                                                <a href="<?php echo  esc_url(get_permalink()); ?>" class="link-btn">
                                                    <span><?php echo wp_kses($settings['read_more'], 'daltech_allowed_tags'); ?></span>
                                                    <i class="fas fa-chevron-right"></i>
                                                </a>
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        <?php $counter++;
                        endwhile;
                        wp_reset_postdata();
                        ?>
                    </div>
                </div>
            </section>

            <!-- End Blog Area One -->

        <?php elseif ($settings['style'] == '2') : ?>

            <!--<< News Section Start Two >>-->
            <section class="news-section section-padding fix">
                <div class="container">
                    <div class="title-section-area">
                        <div class="section-title">
                            <span class="wow fadeInUp">
                                <?php echo wp_kses($settings['section_subtitle'], 'daltech_allowed_tags'); ?>
                            </span>
                            <h2 class="wow fadeInUp" data-wow-delay=".3s">
                                <?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?>
                            </h2>
                        </div>
                        <?php if (!empty($settings['button_label'])) : ?>
                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn wow fadeInUp" data-wow-delay=".5s">
                                <span>
                                    <?php echo wp_kses($settings['button_label'], 'daltech_allowed_tags'); ?>
                                    <i class="fas fa-chevron-right"></i>
                                </span>
                            </a>
                        <?php endif; ?>
                    </div>
                    <div class="news-carousel-active">
                        <?php
                        $counter = 1;
                        while ($daltech_blog->have_posts()) :
                            $daltech_blog->the_post();
                            $daltech_blog_one_img_url = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'full');
                            $categories = get_the_category();
                        ?>
                            <div class="news-card-items">
                                <div class="news-image bg-cover" style="background-image: url(<?php echo esc_url($daltech_blog_one_img_url[0]); ?>);"></div>
                                <div class="news-content">
                                    <ul class="post-area">
                                        <li>
                                            <i class="far fa-user-circle"></i>
                                            <?php echo esc_html(ucwords(get_the_author())); ?>
                                        </li>
                                        <li>
                                            <?php daltech_comment_count(); ?>
                                        </li>
                                    </ul>
                                    <h5>
                                        <a href="<?php echo  esc_url(get_permalink()); ?>"><?php echo esc_html(get_the_title()); ?></a>
                                    </h5>
                                    <a href="<?php echo  esc_url(get_permalink()); ?>" class="link-btn">
                                        <span><?php echo wp_kses($settings['read_more'], 'daltech_allowed_tags'); ?></span>
                                        <i class="fas fa-chevron-right"></i>
                                    </a>
                                </div>
                            </div>
                        <?php $counter++;
                        endwhile;
                        wp_reset_postdata();
                        ?>
                    </div>
                </div>
            </section>

            <!-- End Blog Area TWo -->

            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.news-carousel-active').length > 0) {
                            $('.news-carousel-active').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                speed: 800,
                                arrows: false,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                dots: true,
                                dotsClass: 'slide-dots',
                                responsive: [{
                                        breakpoint: 1399,
                                        settings: {
                                            slidesToShow: 3,
                                        }
                                    },
                                    {
                                        breakpoint: 1191,
                                        settings: {
                                            slidesToShow: 2,
                                        }
                                    },
                                    {
                                        breakpoint: 768,
                                        settings: {
                                            slidesToShow: 1,
                                            center: true,
                                        }
                                    },
                                    {
                                        breakpoint: 480,
                                        settings: {
                                            slidesToShow: 1
                                        }
                                    }
                                ],

                            });
                        }

                    });
                }(jQuery));
            </script>

        <?php elseif ($settings['style'] == '3') : ?>

            <!--<< News Section Start Thyree >>-->
            <section class="news-section section-padding fix">
                <div class="container">
                    <div class="title-section-area">
                        <div class="section-title style-2">
                            <span class="wow fadeInUp">
                                <?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?>
                            </span>
                            <h2 class="wow fadeInUp" data-wow-delay=".3s">
                                <?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?>
                            </h2>
                        </div>
                        <?php if (!empty($settings['button_label'])) : ?>
                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn theme-btn-2 wow fadeInUp" data-wow-delay=".5s">
                                <span>
                                    <?php echo wp_kses($settings['button_label'], 'daltech_allowed_tags'); ?>
                                    <i class="fas fa-chevron-right"></i>
                                </span>
                            </a>
                        <?php endif; ?>
                    </div>
                    <div class="row">
                        <?php
                        $counter = 1;
                        while ($daltech_blog->have_posts()) :
                            $daltech_blog->the_post();
                            $daltech_blog_one_img_url = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'full');
                            $categories = get_the_category();
                        ?>
                            <div class="col-xl-4 col-lg-6 col-md-6 wow fadeInUp" data-wow-delay=".3s">
                                <div class="single-news-items-2">
                                    <div class="news-image bg-cover" style="background-image: url(<?php echo esc_url($daltech_blog_one_img_url[0]); ?>);">
                                        <div class="post-date">
                                            <h4>
                                                <?php echo get_the_date('j'); ?> <br>
                                                <span><?php echo get_the_date('F'); ?></span>
                                            </h4>
                                        </div>
                                    </div>
                                    <div class="news-content">
                                        <?php if (!empty($categories[0]->name)) : ?>
                                            <p><?php echo esc_attr($categories[0]->name); ?></p>
                                            <!-- /.blog-card__tagline -->
                                        <?php endif; ?>
                                        <h4>
                                            <a href="<?php echo  esc_url(get_permalink()); ?>"><?php echo esc_html(get_the_title()); ?></a>
                                        </h4>
                                        <a href="<?php echo  esc_url(get_permalink()); ?>" class="link-btn link-btn-2">
                                            <span><?php echo wp_kses($settings['read_more'], 'daltech_allowed_tags'); ?></span>
                                            <i class="fas fa-chevron-right"></i>
                                        </a>
                                    </div>
                                </div>
                            </div>
                        <?php $counter++;
                        endwhile;
                        wp_reset_postdata();
                        ?>

                    </div>
                </div>
            </section>

        <?php elseif ($settings['style'] == '4') : ?>

            <!-- News Blog Section Here -->
            <section class="news-section fix ralt section-padding">
                <div class="container">
                    <div class="section-title text-center">
                        <span class="wow fadeInUp">
                            <?php echo wp_kses($settings['section_subtitle'], 'daltech_allowed_tags'); ?>
                        </span>
                        <h2 class="wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?>
                        </h2>
                    </div>
                    <div class="row">
                        <?php
                        $counter = 1;
                        while ($daltech_blog->have_posts()) :
                            $daltech_blog->the_post();
                            $daltech_blog_one_img_url = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'full');
                            $categories = get_the_category();
                            $user = wp_get_current_user();
                            $author_id = get_the_author_meta('ID');
                            $author_img = get_avatar_url($author_id, array("size" => 31));
                        ?>
                            <div class="col-xl-4 col-lg-6 col-md-6 wow fadeInUp" data-wow-delay=".3s">
                                <div class="single-news-style-1">
                                    <div class="news-image">
                                        <?php the_post_thumbnail('full'); ?>
                                        <div class="post-date">
                                            <h3> <?php echo get_the_date('j'); ?> <br></h3>
                                            <p><?php echo get_the_date('F'); ?></p>
                                        </div>
                                    </div>
                                    <div class="news-content">
                                        <div class="author-item mb-4">
                                            <div class="post-cat">
                                                <a href="<?php echo esc_url(get_permalink()); ?>">
                                                    <?php if (!empty($categories[0]->name)) : ?>
                                                        <?php echo esc_attr($categories[0]->name); ?>
                                                        <!-- /.blog-card__tagline -->
                                                    <?php endif; ?>
                                                </a>
                                            </div>
                                            <div class="post-author d-flex align-items-center">
                                                <img src="<?php echo esc_url($author_img); ?>" alt="<?php echo bloginfo('name') ?>">
                                                <p><?php echo get_the_author(); ?></p>
                                            </div>
                                        </div>
                                        <h3>
                                            <a href="<?php echo  esc_url(get_permalink()); ?>"><?php echo esc_html(get_the_title()); ?></a>
                                        </h3>
                                        <a href="<?php echo esc_url(get_permalink()); ?>" class="link-btn mt-4">
                                            <?php echo wp_kses($settings['read_more'], 'daltech_allowed_tags'); ?><i class="fas fa-chevron-right"></i>
                                        </a>
                                    </div>
                                </div>
                            </div>
                        <?php $counter++;
                        endwhile;
                        wp_reset_postdata();
                        ?>
                    </div>
                </div>
            </section>
            <!-- News Blog Section Four Here -->

        <?php elseif ($settings['style'] == '5') : ?>

            <!-- News Blog Section Five Here -->
            <section class="news-section-2 section-padding fix">
                <div class="container">
                    <div class="title-section-area">
                        <div class="section-title">
                            <span class="wow fadeInUp">
                                <?php echo wp_kses($settings['section_subtitle'], 'daltech_allowed_tags'); ?>
                            </span>
                            <h2 class="wow fadeInUp" data-wow-delay=".3s">
                                <?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?>
                            </h2>
                        </div>

                        <?php if (!empty($settings['button_label'])) : ?>
                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn wow fadeInUp" data-wow-delay=".5s">
                                <span>
                                    <?php echo wp_kses($settings['button_label'], 'daltech_allowed_tags'); ?>
                                    <i class="fas fa-chevron-right"></i>
                                </span>
                            </a>
                        <?php endif; ?>

                    </div>
                    <div class="news-carousel-active">
                        <?php
                        $counter = 1;
                        while ($daltech_blog->have_posts()) :
                            $daltech_blog->the_post();
                            $daltech_blog_one_img_url = wp_get_attachment_image_src(get_post_thumbnail_id($post->ID), 'full');
                            $categories = get_the_category();
                        ?>
                            <div class="news-card-items">
                                <div class="news-image bg-cover" style="background-image: url(<?php echo esc_url($daltech_blog_one_img_url[0]); ?>);"></div>
                                <div class="news-content">
                                    <ul class="post-area">
                                        <li>
                                            <i class="far fa-user-circle"></i>
                                            <?php echo get_the_author(); ?>
                                        </li>
                                        <li>
                                            <?php daltech_comment_count(); ?>
                                        </li>
                                    </ul>
                                    <h5>
                                        <a href="<?php echo  esc_url(get_permalink()); ?>"><?php echo esc_html(get_the_title()); ?></a>
                                    </h5>
                                    <a href="<?php echo  esc_url(get_permalink()); ?>" class="link-btn">
                                        <span><?php echo wp_kses($settings['read_more'], 'daltech_allowed_tags'); ?></span>
                                        <i class="fas fa-chevron-right"></i>
                                    </a>
                                </div>
                            </div>
                        <?php $counter++;
                        endwhile;
                        wp_reset_postdata();
                        ?>
                    </div>
                </div>
            </section>
            <!-- News Blog Section Five Here -->
            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.news-carousel-active').length > 0) {
                            $('.news-carousel-active').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                speed: 800,
                                arrows: false,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                dots: true,
                                dotsClass: 'slide-dots',
                                responsive: [{
                                        breakpoint: 1399,
                                        settings: {
                                            slidesToShow: 3,
                                        }
                                    },
                                    {
                                        breakpoint: 1191,
                                        settings: {
                                            slidesToShow: 2,
                                        }
                                    },
                                    {
                                        breakpoint: 768,
                                        settings: {
                                            slidesToShow: 1,
                                            center: true,
                                        }
                                    },
                                    {
                                        breakpoint: 480,
                                        settings: {
                                            slidesToShow: 1
                                        }
                                    }
                                ],

                            });
                        }

                    });
                }(jQuery));
            </script>

<?php
        endif;
    }
}
