<?php

/**
 * Elementor Brand Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Brand extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Brand widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_brand';
    }

    /**
     * Get widget title.
     *
     * Retrieve Brand widget title.
     *
     * @since 1.0.0
     * @access public 
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Brand', 'restan-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Brand widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Brand widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    public function get_script_depends()
    {
        return array('main');
    }

    // Add The Input For User
    protected function register_controls()
    {


        $this->start_controls_section(
            'brand_content',
            [
                'label'        => esc_html__('Set Content', 'restan-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'restan-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'restan-core'),
                    '2'      => esc_html__('Style Two', 'restan-core'),
                    '3'      => esc_html__('Style Three', 'restan-core'),
                    '4'      => esc_html__('Style Four', 'restan-core'),
                    '5'      => esc_html__('Style Five', 'restan-core'),
                ],
            ]
        );

        $this->add_control(
            'sec_title',
            [
                'label'         => esc_html__('Title', 'restan-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 2,
                'placeholder' => __('Title', 'daltech-core'),
                'default' => __('Default Title', 'daltech-core'),
                'label_block' => true,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $layout_one_brand_list = new \Elementor\Repeater();

        $layout_one_brand_list->add_control(
            'image',
            [
                'label'     => esc_html__('Image', 'restan-core'),
                'type'         => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'layout_one_brand_list',
            [
                'label'     => esc_html__('Brand List', 'restan-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_one_brand_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Brand', 'restan-core'),
                    ],
                ],
                'condition' => [
                    'style' => ['1', '2', '3', '4', '5']
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'slider_settings',
            [
                'label' => __('Carousel Settings', 'modina-core'),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'slidestoshow',
            [
                'label' => __('Slides To Show', 'modina-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => true,
                'default' => '6',
                'options' => [
                    '1'  => __('1', 'modina-core'),
                    '2'  => __('2', 'modina-core'),
                    '3'  => __('3', 'modina-core'),
                    '4'  => __('4', 'modina-core'),
                    '5'  => __('5', 'modina-core'),
                    '6'  => __('6', 'modina-core'),
                ],
            ]
        );

        $this->add_control(
            'slidestoscroll',
            [
                'label' => __('Slides To Scroll', 'modina-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => true,
                'default' => '1',
                'options' => [
                    '1'  => __('1', 'modina-core'),
                    '2'  => __('2', 'modina-core'),
                    '3'  => __('3', 'modina-core'),
                    '4'  => __('4', 'modina-core'),
                    '5'  => __('5', 'modina-core'),
                    '6'  => __('6', 'modina-core'),
                ],
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label' => __('Auto Play?', 'modina-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'modina-core'),
                'label_off' => __('Hide', 'modina-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'infinite',
            [
                'label' => __('Infinite Loop', 'modina-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'modina-core'),
                'label_off' => __('Hide', 'modina-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'autoplaytimeout',
            [
                'label' => __('Autoplay Timeout', 'modina-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => true,
                'default' => '2000',
                'options' => [
                    '1000'  => __('1 Second', 'modina-core'),
                    '2000'  => __('2 Second', 'modina-core'),
                    '3000'  => __('3 Second', 'modina-core'),
                    '4000'  => __('4 Second', 'modina-core'),
                    '5000'  => __('5 Second', 'modina-core'),
                    '6000'  => __('6 Second', 'modina-core'),
                    '7000'  => __('7 Second', 'modina-core'),
                    '8000'  => __('8 Second', 'modina-core'),
                    '9000'  => __('9 Second', 'modina-core'),
                    '10000' => __('10 Second', 'modina-core'),
                    '11000' => __('11 Second', 'modina-core'),
                    '12000' => __('12 Second', 'modina-core'),
                    '13000' => __('13 Second', 'modina-core'),
                    '14000' => __('14 Second', 'modina-core'),
                    '15000' => __('15 Second', 'modina-core'),
                ],
            ]
        );

        $this->end_controls_section();
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $dynamic_id = rand(123, 456);
        $slidestoshow = !empty($settings['slidestoshow']) ? $settings['slidestoshow'] : '6';
        $slidestoscroll = !empty($settings['slidestoscroll']) ? $settings['slidestoscroll'] : '6';
        $infinite = $settings['infinite'] == 'yes' ? 'true' : 'false';
        $autoplay = $settings['autoplay'] == 'yes' ? 'true' : 'false';
        $autoplaytimeout =  !empty($settings['autoplaytimeout']) ? $settings['autoplaytimeout'] : '800';

        if ($settings['style'] == '1') : ?>

            <!--<< Brand Section Start >>-->
            <section class="brand-section fix section-padding pt-0">
                <div class="container">
                    <div class="brand-wrapper">
                        <h6 class="text-center wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses($settings['sec_title'], 'daltech_allowed_tags'); ?></h6>
                        <div class="brand-carousel-active">
                            <?php
                            foreach ($settings['layout_one_brand_list'] as $item) :
                            ?>
                                <div class="brand-image">
                                    <?php
                                    if (!empty($item['image']['url'])) {
                                        echo daltech_img_tag(array(
                                            'url'    => esc_url($item['image']['url']),
                                        ));
                                    }
                                    ?>
                                </div>
                            <?php
                            endforeach;
                            ?>
                        </div>
                    </div>
                </div>
            </section>
            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.brand-carousel-active').length > 0) {
                            $('.brand-carousel-active').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                //centerMode: true,
                                speed: 500,
                                arrows: false,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                dots: false,
                                dotsClass: 'slide-dots',
                                responsive: [{
                                        breakpoint: 1199,
                                        settings: {
                                            slidesToShow: 5,
                                        }
                                    },
                                    {
                                        breakpoint: 991,
                                        settings: {
                                            slidesToShow: 4,
                                        }
                                    },
                                    {
                                        breakpoint: 768,
                                        settings: {
                                            slidesToShow: 3,
                                            center: true,
                                        }
                                    },
                                    {
                                        breakpoint: 575,
                                        settings: {
                                            slidesToShow: 2,
                                        }
                                    }
                                ],

                            });
                        }

                    });
                }(jQuery));
            </script>
            <!-- End Our Brands One -->

        <?php elseif ($settings['style'] == '2') : ?>

            <!--<< Brand Section Start >>-->
            <div class="brand-section fix">
                <div class="container">
                    <div class="brand-wrapper-3">
                        <div class="brand-carousel-active">
                            <?php
                            foreach ($settings['layout_one_brand_list'] as $item) :
                            ?>
                                <div class="brand-image">
                                    <?php
                                    if (!empty($item['image']['url'])) {
                                        echo daltech_img_tag(array(
                                            'url'    => esc_url($item['image']['url']),
                                        ));
                                    }
                                    ?>
                                </div>
                            <?php
                            endforeach;
                            ?>
                        </div>
                    </div>
                </div>
            </div>

            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.brand-carousel-active').length > 0) {
                            $('.brand-carousel-active').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                //centerMode: true,
                                speed: 500,
                                arrows: false,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                dots: false,
                                dotsClass: 'slide-dots',
                                responsive: [{
                                        breakpoint: 1199,
                                        settings: {
                                            slidesToShow: 5,
                                        }
                                    },
                                    {
                                        breakpoint: 991,
                                        settings: {
                                            slidesToShow: 4,
                                        }
                                    },
                                    {
                                        breakpoint: 768,
                                        settings: {
                                            slidesToShow: 3,
                                            center: true,
                                        }
                                    },
                                    {
                                        breakpoint: 575,
                                        settings: {
                                            slidesToShow: 2,
                                        }
                                    }
                                ],

                            });
                        }

                    });
                }(jQuery));
            </script>
            <!-- End Our Brands Two -->

        <?php elseif ($settings['style'] == '3') : ?>

            <!--<< Brand Section Three Start >>-->
            <div class="brand-section-3 fix section-padding pt-0">
                <div class="container">
                    <div class="brand-wrapper">
                        <div class="brand-carousel-active">
                            <?php
                            foreach ($settings['layout_one_brand_list'] as $item) :
                            ?>
                                <div class="brand-image center">
                                    <?php
                                    if (!empty($item['image']['url'])) {
                                        echo daltech_img_tag(array(
                                            'url'    => esc_url($item['image']['url']),
                                        ));
                                    }
                                    ?>
                                </div>
                            <?php
                            endforeach;
                            ?>
                        </div>
                    </div>
                </div>
            </div>

            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.brand-carousel-active').length > 0) {
                            $('.brand-carousel-active').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                //centerMode: true,
                                speed: 500,
                                arrows: false,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                dots: false,
                                dotsClass: 'slide-dots',
                                responsive: [{
                                        breakpoint: 1199,
                                        settings: {
                                            slidesToShow: 5,
                                        }
                                    },
                                    {
                                        breakpoint: 991,
                                        settings: {
                                            slidesToShow: 4,
                                        }
                                    },
                                    {
                                        breakpoint: 768,
                                        settings: {
                                            slidesToShow: 3,
                                            center: true,
                                        }
                                    },
                                    {
                                        breakpoint: 575,
                                        settings: {
                                            slidesToShow: 2,
                                        }
                                    }
                                ],

                            });
                        }

                    });
                }(jQuery));
            </script>
            <!--<< Brand Section Three Start >>-->

        <?php elseif ($settings['style'] == '4') : ?>

            <!--<< Brand Section Four Start >>-->
            <div class="brand-section-2 fix section-bg-2 mt-0">
                <div class="container">
                    <div class="brand-wrapper style-2">
                        <div class="brand-carousel-active-2">
                            <?php
                            foreach ($settings['layout_one_brand_list'] as $item) :
                            ?>
                                <div class="brand-image">
                                    <?php
                                    if (!empty($item['image']['url'])) {
                                        echo daltech_img_tag(array(
                                            'url'    => esc_url($item['image']['url']),
                                        ));
                                    }
                                    ?>
                                </div>
                            <?php
                            endforeach;
                            ?>
                        </div>
                    </div>
                </div>
            </div>
            <!--<< Brand Section Four Start >>-->
            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.brand-carousel-active-2').length > 0) {
                            $('.brand-carousel-active-2').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                //centerMode: true,
                                speed: 500,
                                arrows: false,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                dots: false,
                                dotsClass: 'slide-dots',
                                responsive: [{
                                        breakpoint: 1199,
                                        settings: {
                                            slidesToShow: 5,
                                        }
                                    },
                                    {
                                        breakpoint: 991,
                                        settings: {
                                            slidesToShow: 4,
                                        }
                                    },
                                    {
                                        breakpoint: 768,
                                        settings: {
                                            slidesToShow: 3,
                                            center: true,
                                        }
                                    },
                                    {
                                        breakpoint: 575,
                                        settings: {
                                            slidesToShow: 2,
                                        }
                                    }
                                ],

                            });
                        }
                    });
                }(jQuery));
            </script>

        <?php elseif ($settings['style'] == '5') : ?>

            <!--<< Brand Section Five Start >>-->
            <div class="brand-section-2 fix section-bg-2">
                <div class="container">
                    <div class="brand-wrapper style-2">
                        <div class="brand-carousel-active-2">

                            <?php
                            foreach ($settings['layout_one_brand_list'] as $item) :
                            ?>
                                <div class="brand-image">
                                    <?php
                                    if (!empty($item['image']['url'])) {
                                        echo daltech_img_tag(array(
                                            'url'    => esc_url($item['image']['url']),
                                        ));
                                    }
                                    ?>
                                </div>
                            <?php
                            endforeach;
                            ?>

                        </div>
                    </div>
                </div>
            </div>
            <!--<< Brand Section Five Start >>-->

            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.brand-carousel-active-2').length > 0) {
                            $('.brand-carousel-active-2').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                //centerMode: true,
                                speed: 500,
                                arrows: false,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                dots: false,
                                dotsClass: 'slide-dots',
                                responsive: [{
                                        breakpoint: 1199,
                                        settings: {
                                            slidesToShow: 5,
                                        }
                                    },
                                    {
                                        breakpoint: 991,
                                        settings: {
                                            slidesToShow: 4,
                                        }
                                    },
                                    {
                                        breakpoint: 768,
                                        settings: {
                                            slidesToShow: 3,
                                            center: true,
                                        }
                                    },
                                    {
                                        breakpoint: 575,
                                        settings: {
                                            slidesToShow: 2,
                                        }
                                    }
                                ],

                            });
                        }
                    });
                }(jQuery));
            </script>
<?php
        endif;
    }
}
