<?php

/**
 * Elementor daltech CallToAction Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Call_To_Action extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve CallToAction widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_call_to_action';
    }

    /**
     * Get widget title.
     *
     * Retrieve CallToAction Nav Tab widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Call To Action', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve CallToAction Nav Tab widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the CallToAction Nav Tab widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'daltech_CallToAction_style',
            [
                'label'        => esc_html__('CallToAction Style', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('CallToAction Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                    '2'      => esc_html__('Style Two', 'daltech-core'),
                    '3'      => esc_html__('Style Three', 'daltech-core'),
                    '4'      => esc_html__('Style Four', 'daltech-core'),
                    '5'      => esc_html__('Style Five', 'daltech-core'),
                ],
            ]
        );


        $this->add_control(
            'section_title',
            [
                'label'         => esc_html__('Section Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section title', 'daltech-core'),
                'default'         => esc_html__('Default Section Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1', '2', '3', '4', '5'],
                ]
            ]

        );

        $this->add_control(
            'section_subtitle',
            [
                'label'         => esc_html__('Section Subtitle', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section subtitle', 'daltech-core'),
                'default'         => esc_html__('Default Section SubTitle', 'daltech-core'),
                'condition' => [
                    'style' => ['1', '2', '3', '4', '5'],
                ]

            ]
        );

        $this->add_control(
            'button_label',
            [
                'label'     => __('Button Label', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::TEXTAREA,
                'rows'         => 2,
                'default'      => __('Button Label', 'daltech-core'),
                'condition' => [
                    'style' => ['1', '2', '3', '4', '5'],
                ]
            ]
        );

        $this->add_control(
            'url',
            [
                'label'         => __('URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => __('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => false,
                    'nofollow'         => false,
                ],
                'condition' => [
                    'style' => ['1', '2', '3', '4', '5'],
                ]
            ]
        );

        $this->add_control(
            'bg_image_one',
            [
                'label' => esc_html__('Background Image One', 'agrofa-addon'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => ['1', '3', '5'],
                ]
            ]
        );

        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'call-to-action-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') :
?>

            <!--<< Cta Banner Section Start >>-->
            <section class="cta-banner-section bg-cover section-padding" style="background-image: url(<?php echo esc_url($settings['bg_image_one']['url']); ?>);">
                <div class="container">
                    <div class="cta-banner-wrapper section-padding pt-0">
                        <div class="section-title mb-0">
                            <span class="text-white wow fadeInUp">
                                <?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?>
                            </span>
                            <h2 class="text-white wow fadeInUp" data-wow-delay=".3s">
                                <?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
                            </h2>
                        </div>
                        <?php if (!empty($settings['button_label'])) : ?>
                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn hover-white wow fadeInUp" data-wow-delay=".5s">
                                <span>
                                    <?php echo wp_kses_post($settings['button_label'], 'daltech_kses_allowed_html'); ?>
                                    <i class="fas fa-chevron-right"></i>
                                </span>
                            </a>
                        <?php
                        endif;
                        ?>
                    </div>
                </div>
            </section>
            <!-- End CallToActions style one -->

        <?php elseif ($settings['style'] == '2') : ?>

            <!--<< Cta Chat Section Start Two >>-->
            <section class="cta-chat-section section-padding pt-0">
                <div class="container">
                    <div class="cta-chat-wrapper">
                        <div class="chat-items wow fadeInUp" data-wow-delay=".3s">
                            <div class="icon">
                                <i class="flaticon-chat"></i>
                            </div>
                            <div class="content">
                                <h3> <?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?></h3>
                                <p> <?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?></p>
                            </div>
                        </div>
                        <?php if (!empty($settings['button_label'])) : ?>
                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn bg-white wow fadeInUp" data-wow-delay=".5s">
                                <span>
                                    <?php echo wp_kses_post($settings['button_label'], 'daltech_kses_allowed_html'); ?>
                                    <i class="fas fa-chevron-right"></i>
                                </span>
                            </a>
                        <?php
                        endif;
                        ?>
                    </div>
                </div>
            </section>
            <!-- End CallToActions style Two -->

        <?php elseif ($settings['style'] == '3') : ?>

            <!--<< Cta Discuss Section Start >>-->
            <section class="cta-discuss-section">
                <div class="container">
                    <div class="cta-discuss-wrapper">
                        <div class="cta-discuss-image wow fadeInUp" data-wow-delay=".3s">
                            <?php
                            if (!empty($settings['bg_image_one']['url'])) {
                                echo daltech_img_tag(array(
                                    'url'    => esc_url($settings['bg_image_one']['url']),
                                ));
                            }
                            ?>
                            <div class="icon">
                                <i class="flaticon-chat"></i>
                            </div>
                        </div>
                        <div class="cta-discuss-content">
                            <div class="section-title mb-0">
                                <span class="wow fadeInUp" data-wow-delay=".5s">
                                    <i class="far fa-arrow-right"></i>
                                    <?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?>
                                </span>
                                <h2 class="wow fadeInUp" data-wow-delay=".7s">
                                    <?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
                                </h2>
                            </div>
                            <?php if (!empty($settings['button_label'])) : ?>
                                <div class="cta-button wow fadeInUp" data-wow-delay=".9s">
                                    <a href="contact.html" class="link-btn">
                                        <span>
                                            <?php echo wp_kses_post($settings['button_label'], 'daltech_kses_allowed_html'); ?></span>
                                        <i class="fas fa-chevron-right"></i>
                                    </a>
                                </div>
                            <?php
                            endif;
                            ?>
                        </div>
                    </div>
                </div>
            </section>
            <!-- End CallToActions style Three -->

        <?php elseif ($settings['style'] == '4') : ?>

            <!--<< Cta Chat Section Start Four >>-->
            <section class="cta-chat-section-2">
                <div class="container">
                    <div class="cta-chat-wrapper style-2">
                        <div class="chat-items wow fadeInUp" data-wow-delay=".3s">
                            <div class="icon">
                                <i class="flaticon-chat"></i>
                            </div>
                            <div class="content">
                                <h3> <?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?></h3>
                                <p> <?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?></p>
                            </div>
                        </div>
                        <?php if (!empty($settings['button_label'])) : ?>
                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn bg-white wow fadeInUp" data-wow-delay=".5s">
                                <span>
                                    <?php echo wp_kses_post($settings['button_label'], 'daltech_kses_allowed_html'); ?>
                                    <i class="fas fa-chevron-right"></i>
                                </span>
                            </a>
                        <?php
                        endif;
                        ?>
                    </div>
                </div>
            </section>

            <!--<< Cta Chat Section End Four >>-->

        <?php elseif ($settings['style'] == '5') : ?>

            <!--<< Cta  Section End Five >>-->
            <section class="cta-banner-section-4">
                <div class="container">
                    <div class="cta-banner-style-1 bg-cover" style="background: url(<?php echo esc_url($settings['bg_image_one']['url']); ?>);">
                        <div class="section-title">
                            <span class="text-white">
                                <?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?>
                            </span>
                            <h2 class="text-white">
                                <?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
                            </h2>
                        </div>
                        <?php if (!empty($settings['button_label'])) : ?>
                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn bg-white mt-4">
                                <span> <?php echo wp_kses_post($settings['button_label'], 'daltech_kses_allowed_html'); ?></span>
                            </a>
                        <?php
                        endif;
                        ?>
                    </div>
                </div>
            </section>
            <!--<< Cta Section End Five >>-->
<?php
        endif;
    }
}
