<?php

/**
 * Elementor daltech Subscribe Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Footer_About extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Subscribe widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_footer_about';
    }

    /**
     * Get widget title.
     *
     * Retrieve Subscribe Nav Tab widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Footer About', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Subscribe Nav Tab widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Subscribe Nav Tab widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'content_style',
            [
                'label'        => esc_html__('Footer About Content', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                    '2'      => esc_html__('Style Two', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'footer_logo',
            [
                'label'            => esc_html__('Footer Logo', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'section_title',
            [
                'label'         => esc_html__('Section Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section title', 'daltech-core'),
                'default'         => esc_html__('Default Section Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'section_subtitle',
            [
                'label'         => esc_html__('Section Subtitle', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section subtitle', 'daltech-core'),
                'default'         => esc_html__('Default Section SubTitle', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $social = new \Elementor\Repeater();

        $social->add_control(
            'icon_style',
            [
                'label'     => esc_html__('Icon Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Flaticon', 'daltech-core'),
                    '3'     => esc_html__('Icon Image', 'daltech-core'),
                    '2'      => esc_html__('Custom Icon', 'daltech-core'),
                ],
            ]
        );

        $social->add_control(
            'flat_icon',
            [
                'label'      => esc_html__('Icon One', 'cleanu-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
                'default'    => 'flaticon-budget',
                'condition' => [
                    'icon_style' => '1'
                ]
            ]
        );

        $social->add_control(
            'custom_icon',
            [
                'label'         => esc_html__('Custom Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'label_block'     => true,
                'condition' => [
                    'icon_style' => '2'
                ]
            ]
        );


        $social->add_control(
            'icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'icon_style' => '3'
                ]
            ]
        );

        $social->add_control(
            'url',
            [
                'label' => __('Add Url', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('#', 'daltech-core'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'show_label' => false,
            ]
        );

        $this->add_control(
            'social_list',
            [
                'label' => __('Social List', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $social->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'social_url' => [
                            'url' => '#',
                            'is_external' => false,
                            'nofollow' => false,
                        ],
                    ],
                ],
                'condition' => [
                    'style' => ['1']
                ]

            ]
        );

        $social_list_two = new \Elementor\Repeater();

        $social_list_two->add_control(
            'icon_style',
            [
                'label'     => esc_html__('Icon Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Flaticon', 'daltech-core'),
                    '3'     => esc_html__('Icon Image', 'daltech-core'),
                    '2'      => esc_html__('Custom Icon', 'daltech-core'),
                ],
            ]
        );

        $social_list_two->add_control(
            'flat_icon',
            [
                'label'      => esc_html__('Icon One', 'cleanu-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
                'default'    => 'flaticon-budget',
                'condition' => [
                    'icon_style' => '1'
                ]
            ]
        );

        $social_list_two->add_control(
            'custom_icon',
            [
                'label'         => esc_html__('Custom Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'label_block'     => true,
                'condition' => [
                    'icon_style' => '2'
                ]
            ]
        );


        $social_list_two->add_control(
            'icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'icon_style' => '3'
                ]
            ]
        );

        $social_list_two->add_control(
            'url',
            [
                'label' => __('Add Url', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('#', 'daltech-core'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'show_label' => false,
            ]
        );

        $social_list_two->add_control(
            'text',
            [
                'label'         => esc_html__('Text', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'label_block'     => true,
                'default'         => esc_html__('Facebook', 'daltech-core'),
            ]
        );

        $this->add_control(
            'social_list_two',
            [
                'label' => __('Social List', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $social_list_two->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'social_url' => [
                            'url' => '#',
                            'is_external' => false,
                            'nofollow' => false,
                        ],
                    ],
                ],
                'condition' => [
                    'style' => ['2']
                ]

            ]
        );

        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'footer-about-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') :
?>
            <!--<< Subscribe Section Start >>-->
            <div class="wow fadeInUp" data-wow-delay=".2s">
                <div class="single-footer-widget">
                    <div class="widget-head">
                        <a href="<?php echo esc_url(home_url()); ?>">
                            <?php
                            if (!empty($settings['footer_logo']['url'])) {
                                echo daltech_img_tag(array(
                                    'url'    => esc_url($settings['footer_logo']['url']),
                                ));
                            }
                            ?>
                        </a>
                    </div>
                    <div class="footer-content">
                        <p>
                            <?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?>
                        </p>
                        <?php echo wp_kses($settings['section_subtitle'], 'daltech_allowed_tags'); ?>
                        <div class="social-icon d-flex align-items-center">
                            <?php
                            foreach ($settings['social_list'] as $single_item) :
                            ?>

                                <a href="<?php echo esc_url($single_item['url']['url']); ?>">
                                    <?php if (!empty($single_item['flat_icon'])) : ?>
                                        <i class="<?php echo esc_attr($single_item['flat_icon']); ?>"></i>
                                    <?php endif; ?>
                                    <?php if (!empty($single_item['icon_image']['url'])) : ?>
                                        <img src="<?php echo esc_url($single_item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                    <?php endif; ?>
                                    <?php
                                    if (!empty($single_item['custom_icon'])) : ?>
                                        <i class="<?php echo esc_attr($single_item['custom_icon']); ?>"></i>
                                    <?php endif; ?>
                                </a>

                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End about Style One -->

        <?php elseif ($settings['style'] == '2') : ?>

            <!-- Start about Style One -->
            <div class="footer-top">
                <div class="footer-logo wow fadeInUp" data-wow-delay=".3s">
                    <a href="<?php echo esc_url(home_url()); ?>">
                        <?php
                        if (!empty($settings['footer_logo']['url'])) {
                            echo daltech_img_tag(array(
                                'url'    => esc_url($settings['footer_logo']['url']),
                            ));
                        }
                        ?>
                    </a>
                </div>
                <ul class="wow fadeInUp" data-wow-delay=".5s">
                    <?php
                    foreach ($settings['social_list_two'] as $single_item) :
                    ?>
                        <li>
                            <?php if (!empty($single_item['flat_icon'])) : ?>
                                <i class="<?php echo esc_attr($single_item['flat_icon']); ?>"></i>
                            <?php endif; ?>
                            <?php if (!empty($single_item['icon_image']['url'])) : ?>
                                <img src="<?php echo esc_url($single_item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                            <?php endif; ?>
                            <?php
                            if (!empty($single_item['custom_icon'])) : ?>
                                <i class="<?php echo esc_attr($single_item['custom_icon']); ?>"></i>
                            <?php endif; ?>
                            <a href="<?php echo esc_url($single_item['url']['url']); ?>">
                                <?php echo wp_kses($single_item['text'], 'daltech_allowed_tags'); ?></a>
                        </li>
                    <?php endforeach; ?>
                </ul>
            </div>
            <!-- Start about Style One -->
<?php
        endif;
    }
}
