<?php

/**
 * Elementor daltech Subscribe Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Footer_App extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Subscribe widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_footer_app';
    }

    /**
     * Get widget title.
     *
     * Retrieve Subscribe Nav Tab widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Footer App', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Subscribe Nav Tab widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Subscribe Nav Tab widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'content_style',
            [
                'label'        => esc_html__('Footer About Content', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                ],
            ]
        );



        $this->add_control(
            'section_title',
            [
                'label'         => esc_html__('Section Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section title', 'daltech-core'),
                'default'         => esc_html__('Default Section Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'section_subtitle',
            [
                'label'         => esc_html__('Section Subtitle', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section subtitle', 'daltech-core'),
                'default'         => esc_html__('Default Section SubTitle', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'image_one',
            [
                'label'            => esc_html__('Image One', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'image_url_one',
            [
                'label' => __('Add Url One', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('#', 'daltech-core'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'show_label' => false,
            ]
        );

        $this->add_control(
            'image_two',
            [
                'label'            => esc_html__('Image Two', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'image_url_two',
            [
                'label' => __('Add Url Two', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('#', 'daltech-core'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'show_label' => false,
            ]
        );


        $this->add_control(
            'contact_title',
            [
                'label'         => esc_html__('Contact Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('Contact Title', 'daltech-core'),
                'default'         => esc_html__('Contact Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'contact_info',
            [
                'label'         => esc_html__('Contact Info', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('Contact Info', 'daltech-core'),
                'default'         => esc_html__('Contact Info', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );



        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'footer-app-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') :
?>
            <!--<< Subscribe Section Start >>-->
            <div class="wow fadeInUp" data-wow-delay=".9s">
                <div class="single-footer-widget">
                    <div class="widget-head">
                        <h5> <?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?></h5>
                    </div>
                    <div class="footer-apps-items">
                        <p> <?php echo wp_kses($settings['section_subtitle'], 'daltech_allowed_tags'); ?></p>
                        <div class="apps-image d-flex align-items-center">
                            <a href="<?php echo esc_url($settings['image_url_one']['url']); ?>">
                                <?php
                                if (!empty($settings['image_one']['url'])) {
                                    echo daltech_img_tag(array(
                                        'url'    => esc_url($settings['image_one']['url']),
                                    ));
                                }
                                ?>
                            </a>
                            <a href="<?php echo esc_url($settings['image_url_two']['url']); ?>">
                                <?php
                                if (!empty($settings['image_two']['url'])) {
                                    echo daltech_img_tag(array(
                                        'url'    => esc_url($settings['image_two']['url']),
                                    ));
                                }
                                ?>
                            </a>
                        </div>
                        <div class="support-text">
                            <p> <?php echo wp_kses($settings['contact_title'], 'daltech_allowed_tags'); ?></p>
                            <h3> <?php echo wp_kses($settings['contact_info'], 'daltech_allowed_tags'); ?></h3>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End  app Style One -->
<?php
        endif;
    }
}
