<?php

/**
 * Elementor Footer Copyright Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Footer_Copyright extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Footer Copyright widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_footer_copyright';
    }

    /**
     * Get widget title.
     *
     * Retrieve Footer Copyright widget title.
     *
     * @since 1.0.0
     * @access public 
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Footer Copyright', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Footer Copyright widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Footer Copyright widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    public function get_script_depends()
    {
        return array('main');
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'footer_copyright_content',
            [
                'label'        => esc_html__('Set Footer Copyright Content', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                    '2'      => esc_html__('Style Two', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'copyright_text',
            [
                'label'         => esc_html__('Copyright Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('Copyright title', 'daltech-core'),
                'default'         => esc_html__('Default Copyright Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1', '2']
                ]
            ]
        );

        $nav_menus = new \Elementor\Repeater();

        $nav_menus->add_control(
            'nav_menu',
            [
                'label' => __('Select Nav Menu', 'ogency-addon'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => daltech_get_nav_menu(),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'nav_menus',
            [
                'label' => __('Nav Menus', 'ogency-addon'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'prevent_empty' => false,
                'fields' => $nav_menus->get_controls(),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'footer-copyright-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') : ?>

            <!-- Start Our Service Menu  One -->
            <div class="footer-bottom">
                <div class="container">
                    <div class="footer-wrapper d-flex align-items-center justify-content-between">
                        <p class="wow fadeInLeft color-2" data-wow-delay=".3s">
                            <?php echo wp_kses_post($settings['copyright_text'], 'daltech_kses_allowed_html'); ?>
                        </p>
                        <?php foreach ($settings['nav_menus'] as $nav_menu) : ?>
                            <?php wp_nav_menu(array(
                                'menu' => $nav_menu['nav_menu'],
                                'container'  => '',
                                'menu_class' => 'footer-menu wow fadeInRight'
                            )); ?>
                        <?php endforeach; ?>
                    </div>
                </div>
                <a href="#" id="scrollUp" class="scroll-icon">
                    <i class="far fa-arrow-up"></i>
                </a>
            </div>
            <!-- End Our Service Menu One -->

        <?php elseif ($settings['style'] == '2') : ?>

            <div class="footer-bottom style-2">
                <div class="container">
                    <div class="footer-wrapper d-flex align-items-center justify-content-between">
                        <p class="wow fadeInUp color-2" data-wow-delay=".4s">
                            <?php echo wp_kses_post($settings['copyright_text'], 'daltech_kses_allowed_html'); ?>
                        </p>
                    </div>
                </div>
            </div>
<?php
        endif;
    }
}
