<?php

/**
 * Elementor daltech Subscribe Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Footer_Subscribe extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Subscribe widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_footer_subscribe';
    }

    /**
     * Get widget title.
     *
     * Retrieve Subscribe Nav Tab widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Footer Subscribe', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Subscribe Nav Tab widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Subscribe Nav Tab widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'content_style',
            [
                'label'        => esc_html__('Footer Subscribe Content', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                    '2'      => esc_html__('Style Two', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'section_title',
            [
                'label'         => esc_html__('Section Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section title', 'daltech-core'),
                'default'         => esc_html__('Default Section Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1', '2']
                ]
            ]
        );

        $this->add_control(
            'section_subtitle',
            [
                'label'         => esc_html__('Section Subtitle', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section subtitle', 'daltech-core'),
                'default'         => esc_html__('Default Section SubTitle', 'daltech-core'),
                'condition' => [
                    'style' => ['1', '2']
                ]
            ]
        );

        $this->add_control(
            'privacy_text',
            [
                'label'         => esc_html__('Privacy Text', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('Privacy Text', 'daltech-core'),
                'default'         => esc_html__('Default Privacy Text', 'daltech-core'),
                'condition' => [
                    'style' => ['2']
                ]
            ]
        );

        $this->add_control(
            'button_label',
            [
                'label'     => __('Button Label', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::TEXTAREA,
                'rows'         => 2,
                'default'      => __('Button Label', 'daltech-core'),
                'condition' => [
                    'style' => ['1', '2']
                ]
            ]
        );

        $this->add_control(
            'shape_one',
            [
                'label'            => esc_html__('Shape One', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition'        => ['style'    =>    ['1']],
            ]
        );

        $this->add_control(
            'shape_two',
            [
                'label'            => esc_html__('Shape Two', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition'        => ['style'    =>    ['1']],
            ]
        );

        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'footer-subscribe-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') :
?>
            <!--<< Subscribe Section Start >>-->
            <div class="newsletter-area">
                <div class="shape-1">
                    <?php
                    if (!empty($settings['shape_one']['url'])) :
                        echo daltech_img_tag(array(
                            'url'   => esc_url($settings['shape_one']['url'])
                        ));
                    endif;
                    ?>
                </div>
                <div class="shape-2">
                    <?php
                    if (!empty($settings['shape_two']['url'])) :
                        echo daltech_img_tag(array(
                            'url'   => esc_url($settings['shape_two']['url'])
                        ));
                    endif;
                    ?>
                </div>
                <div class="newsletter-title">
                    <h2 class="wow fadeInUp" data-wow-delay=".3s">
                        <?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?>
                    </h2>
                    <p class="wow fadeInUp" data-wow-delay=".5s">
                        <?php echo wp_kses($settings['section_subtitle'], 'daltech_allowed_tags'); ?>
                    </p>
                </div>
                <div class="newsletter-items">
                    <form class="newsletter-form mc-form">
                        <div class="form-clt wow fadeInUp" data-wow-delay=".3s">
                            <input type="text" name="email" id="email2" placeholder="<?php echo esc_attr__("Email Address", 'daltech-core'); ?>">
                        </div>
                        <button class="theme-btn hover-white wow fadeInUp" data-wow-delay=".5s" type="submit">
                            <span><?php echo wp_kses($settings['button_label'], 'daltech_allowed_tags'); ?> <i class="far fa-arrow-right"></i></span>
                        </button>
                    </form>
                </div>
            </div>
            <!-- End  Subscribe Style One -->

        <?php elseif ($settings['style'] == '2') : ?>

            <!-- Start  Subscribe Style Two -->
            <div class="wow fadeInUp" data-wow-delay=".3s">
                <div class="single-footer-widget me-4">
                    <div class="widget-head">
                        <h3><?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?></h3>
                    </div>
                    <div class="footer-content">
                        <p>
                            <?php echo wp_kses($settings['section_subtitle'], 'daltech_allowed_tags'); ?>
                        </p>
                        <div class="newsletter-items">
                            <div class="form-clt">
                                <input type="text" name="email" id="email2" placeholder="<?php echo esc_html__("Email Address", 'daltech-addons') ?>">
                            </div>
                            <button class="theme-btn hover-white" type="submit">
                                <span><?php echo wp_kses($settings['button_label'], 'daltech_allowed_tags'); ?><i class="fas fa-chevron-right"></i></span>
                            </button>
                        </div>
                        <h6 class="label-text"><?php echo wp_kses($settings['privacy_text'], 'daltech_allowed_tags'); ?></h6>
                    </div>
                </div>
            </div>
            <!-- End  Subscribe Style Two -->
<?php
        endif;
    }
}
