<?php

/**
 * Elementor daltech Grow Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Grow extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Grow widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_grow';
    }

    /**
     * Get widget title.
     *
     * Retrieve Grow Nav Tab widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Grow', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Grow Nav Tab widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Grow Nav Tab widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'grow_content_style',
            [
                'label'        => esc_html__('Grow Style', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core')
                ],
            ]
        );

        $this->add_control(
            'section_title',
            [
                'label'         => esc_html__('Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'rows'             => '2',
                'placeholder'     => esc_html__('title', 'daltech-core'),
                'default'         => esc_html__('Default Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'section_subtitle',
            [
                'label'         => esc_html__('Sub-Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'rows'             => '2',
                'placeholder'     => esc_html__('subtitle', 'daltech-core'),
                'default'         => esc_html__('Default Sub-Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'button_label',
            [
                'label'     => __('Button Label', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::TEXTAREA,
                'rows'         => 2,
                'default'      => __('Button Label', 'daltech-core'),
                'condition' => [
                    'style' => ['1', '2', '3', '4']
                ]
            ]
        );

        $this->add_control(
            'button_url',
            [
                'label'         => __('URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => __('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => false,
                    'nofollow'         => false,
                ],
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $layout_one_funfact_list = new \Elementor\Repeater();

        $layout_one_funfact_list->add_control(
            'title',
            [
                'label'         => esc_html__('Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '1',
                'default'      => __('Title', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_funfact_list->add_control(
            'subtitle',
            [
                'label'         => esc_html__('Sub-Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '3',
                'default'      => __('Sub-Title', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_funfact_list->add_control(
            'number',
            [
                'label'         => esc_html__('Number', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'            => '1',
                'default'      => __('Number', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $this->add_control(
            'layout_one_funfact_list',
            [
                'label'     => esc_html__('Funfact List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_one_funfact_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Funfact List', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ title }}}',
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'grow-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') :
?>
            <!--<< Grow Section Start >>-->
            <section class="grow-section section-padding section-bg-3">
                <div class="container">
                    <div class="grow-wrapper">
                        <div class="title-section-area">
                            <div class="section-title style-2">
                                <span class="text-white wow fadeInUp">
                                    <?php echo wp_kses($settings['section_subtitle'], 'daltech_allowed_tags'); ?>
                                </span>
                                <h2 class="text-white wow fadeInUp" data-wow-delay=".3s">
                                    <?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?>
                                </h2>
                            </div>
                            <?php if (!empty($settings['button_url']['url'])) : ?>
                                <a href="<?php echo esc_url($settings['button_url']['url']); ?>" class="theme-btn theme-btn-2 hover-white wow fadeInUp" data-wow-delay=".5s">
                                    <span>
                                        <?php echo wp_kses($settings['button_label'], 'daltech_allowed_tags'); ?>
                                        <i class="fas fa-chevron-right"></i>
                                    </span>
                                </a>
                            <?php endif; ?>
                        </div>
                        <div class="circle-progress-bar-wrapper mbm-10">
                            <?php
                            foreach ($settings['layout_one_funfact_list'] as $item) :
                            ?>
                                <div class="single-circle-bar wow fadeInUp" data-wow-delay=".3s">
                                    <div class="circle-bar" data-percent="<?php echo esc_attr($item['number']); ?>" data-duration="1000">
                                    </div>
                                    <div class="content">
                                        <h6>
                                            <?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?>
                                        </h6>
                                        <p>
                                            <?php echo wp_kses($item['subtitle'], 'daltech_allowed_tags'); ?>
                                        </p>
                                    </div>
                                </div>
                            <?php
                            endforeach;
                            ?>
                        </div>
                    </div>
                </div>
            </section>
            <!-- End  Grow Style One -->
<?php
        endif;
    }
}
