<?php

/**
 * Elementor Header Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Header extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Header widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_header';
    }

    /**
     * Get widget title.
     *
     * Retrieve Header widget title.
     *
     * @since 1.0.0
     * @access public 
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Header', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Header widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Header widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    public function get_script_depends()
    {
        return array('main');
    }

    // Add The Input For User
    protected function register_controls()
    {


        $this->start_controls_section(
            'header_content',
            [
                'label'        => esc_html__('Set Header Content', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                    '2'      => esc_html__('Style Two', 'daltech-core'),
                    '3'      => esc_html__('Style Three', 'daltech-core'),
                    '4'      => esc_html__('Style Four', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'header_logo',
            [
                'label'            => esc_html__('Header Logo', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'header_logo_scroll',
            [
                'label'            => esc_html__('Header Logo Scroll', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => ['2', '4']
                ]
            ]
        );

        $this->add_control(
            'nav_menu',
            [
                'label' => __('Select Nav Menu', 'daltech-addon'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => daltech_get_nav_menu(),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'contact_info_icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'contact_info_custom_icon',
            [
                'label'         => esc_html__('Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'rows'          => '1',
                'condition' => [
                    'style' => '4'
                ]
            ]
        );

        $this->add_control(
            'contact_title',
            [
                'label'         => esc_html__('Contact Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 1,
                'placeholder' => __('Contact Title', 'daltech-core'),
                'default' => __('Default Contact Title', 'daltech-core'),
                'label_block' => true,
                'condition' => [
                    'style' => ['1', '4']
                ]
            ]
        );

        $this->add_control(
            'contact_info',
            [
                'label'         => esc_html__('Contact Info', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 3,
                'placeholder' => __('Contact Info', 'daltech-core'),
                'default' => __('Default Contact Info', 'daltech-core'),
                'label_block' => true,
                'condition' => [
                    'style' => ['1', '4']
                ]
            ]
        );

        $this->add_control(
            'button_label',
            [
                'label'     => __('Read More Label', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::TEXTAREA,
                'rows'         => 2,
                'default'      => __('Button Label', 'daltech-core'),
                'condition' => [
                    'style' => ['1', '3', '4']
                ]
            ]
        );

        $this->add_control(
            'url',
            [
                'label'         => __('URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => __('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => false,
                    'nofollow'         => false,
                ],
                'condition' => [
                    'style' => ['1', '3', '4']
                ]
            ]
        );

        $contact_info_list = new \Elementor\Repeater();

        $contact_info_list->add_control(
            'title',
            [
                'label'         => esc_html__('Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 3,
                'placeholder' => __('Title', 'daltech-core'),
                'default' => __('Default Title', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $contact_info_list->add_control(
            'content',
            [
                'label'         => esc_html__('Content', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 3,
                'placeholder' => __('Content', 'daltech-core'),
                'default' => __('Default Content', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $contact_info_list->add_control(
            'icon_style',
            [
                'label'     => esc_html__('Icon Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Flaticon', 'daltech-core'),
                    '3'     => esc_html__('Icon Image', 'daltech-core'),
                    '2'      => esc_html__('Custom Icon', 'daltech-core'),
                ],
            ]
        );

        $contact_info_list->add_control(
            'flat_icon',
            [
                'label'      => esc_html__('Icon One', 'cleanu-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
                'condition' => [
                    'icon_style' => '1'
                ]
            ]
        );

        $contact_info_list->add_control(
            'custom_icon',
            [
                'label'         => esc_html__('Custom Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'rows'          => '2',
                'condition' => [
                    'icon_style' => '2'
                ]
            ]
        );


        $contact_info_list->add_control(
            'icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'icon_style' => '3'
                ]
            ]
        );

        $this->add_control(
            'contact_info_list',
            [
                'label'     => esc_html__('Contact Info List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $contact_info_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Contact Info', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ title }}}',
                'condition' => [
                    'style' => ['2']
                ]
            ]
        );

        $contact_info_list_two = new \Elementor\Repeater();

        $contact_info_list_two->add_control(
            'content',
            [
                'label'         => esc_html__('Content', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 3,
                'placeholder' => __('Content', 'daltech-core'),
                'default' => __('Default Content', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $contact_info_list_two->add_control(
            'icon_style',
            [
                'label'     => esc_html__('Icon Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Flaticon', 'daltech-core'),
                    '3'     => esc_html__('Icon Image', 'daltech-core'),
                    '2'      => esc_html__('Custom Icon', 'daltech-core'),
                ],
            ]
        );

        $contact_info_list_two->add_control(
            'flat_icon',
            [
                'label'      => esc_html__('Icon One', 'cleanu-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
                'condition' => [
                    'icon_style' => '1'
                ]
            ]
        );

        $contact_info_list_two->add_control(
            'custom_icon',
            [
                'label'         => esc_html__('Custom Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'rows'          => '2',
                'condition' => [
                    'icon_style' => '2'
                ]
            ]
        );


        $contact_info_list_two->add_control(
            'icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'icon_style' => '3'
                ]
            ]
        );

        $this->add_control(
            'contact_info_list_two',
            [
                'label'     => esc_html__('Contact Info List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $contact_info_list_two->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Contact Info', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ content }}}',
                'condition' => [
                    'style' => ['4']
                ]
            ]
        );

        $this->add_control(
            'contact_info_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );


        $social = new \Elementor\Repeater();

        $social->add_control(
            'icon_style',
            [
                'label'     => esc_html__('Icon Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Flaticon', 'daltech-core'),
                    '3'     => esc_html__('Icon Image', 'daltech-core'),
                    '2'      => esc_html__('Custom Icon', 'daltech-core'),
                ],
            ]
        );

        $social->add_control(
            'flat_icon',
            [
                'label'      => esc_html__('Icon One', 'cleanu-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
                'default'    => 'flaticon-budget',
                'condition' => [
                    'icon_style' => '1'
                ]
            ]
        );

        $social->add_control(
            'custom_icon',
            [
                'label'         => esc_html__('Custom Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'label_block'     => true,
                'condition' => [
                    'icon_style' => '2'
                ]
            ]
        );


        $social->add_control(
            'icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'icon_style' => '3'
                ]
            ]
        );

        $social->add_control(
            'url',
            [
                'label' => __('Add Url', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('#', 'daltech-core'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'show_label' => false,
            ]
        );

        $this->add_control(
            'social_list',
            [
                'label' => __('Social List', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $social->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'social_url' => [
                            'url' => '#',
                            'is_external' => false,
                            'nofollow' => false,
                        ],
                    ],
                ],
                'condition' => [
                    'style' => ['4']
                ]

            ]
        );

        $this->add_control(
            'search_enable',
            [
                'label' => __('Enable Search?', 'daltech-addon'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'daltech-addon'),
                'label_off' => __('No', 'daltech-addon'),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'style' => ['1', '2']
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'daltech_side_menu_style',
            [
                'label'        => esc_html__('Sidemenu Style', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'sidemenu_position',
            [
                'label' => __('Sidemenu Show/Hide', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'daltech-core'),
                'label_off' => __('Hide', 'daltech-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'sidemenu_logo',
            [
                'label'            => esc_html__('Sidemenu Logo', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'sidemenu_position' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'sidemenu_content',
            [
                'label'         => esc_html__('Content', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'condition' => [
                    'sidemenu_position' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'sidemenu_contact_heading',
            [
                'label'     => __('Contact Heading', 'daltech-core'),
                'type'      => \Elementor\Controls_Manager::TEXT,
                'default'   => __('Title', 'daltech-core')
            ]
        );

        $sidemenu_info_list = new \Elementor\Repeater();

        $sidemenu_info_list->add_control(
            'content',
            [
                'label'         => esc_html__('Content', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'rows'             => '3'
            ]
        );

        $sidemenu_info_list->add_control(
            'icon_style',
            [
                'label'     => esc_html__('Icon Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Flaticon', 'daltech-core'),
                    '3'     => esc_html__('Icon Image', 'daltech-core'),
                    '2'      => esc_html__('Custom Icon', 'daltech-core'),
                ],
            ]
        );

        $sidemenu_info_list->add_control(
            'flat_icon',
            [
                'label'      => esc_html__('Icon One', 'daltech-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
                'default'    => 'flaticon-budget',
                'condition' => [
                    'icon_style' => '1'
                ]
            ]
        );

        $sidemenu_info_list->add_control(
            'custom_icon',
            [
                'label'         => esc_html__('Custom Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'label_block'     => true,
                'condition' => [
                    'icon_style' => '2'
                ]
            ]
        );

        $sidemenu_info_list->add_control(
            'icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'icon_style' => '3'
                ]
            ]
        );

        $this->add_control(
            'sidemenu_info_list',
            [
                'label'     => esc_html__('Sidemanu Contact Info List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $sidemenu_info_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Sidemanu Info', 'daltech-core'),
                    ],
                ],
                'prevent_empty' => false,
                'title_field' => '{{{ content }}}',
                'condition' => [
                    'sidemenu_position' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'sidemenu_button_label',
            [
                'label'     => __('Sidemenu Button Label', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::TEXTAREA,
                'rows'         => 2,
                'default'      => __('Button Label', 'daltech-core'),
                'condition' => [
                    'style' => ['2']
                ]
            ]
        );

        $this->add_control(
            'sidemanu_url',
            [
                'label'         => __('URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => __('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => false,
                    'nofollow'         => false,
                ],
                'condition' => [
                    'style' => ['2']
                ]
            ]
        );

        $social = new \Elementor\Repeater();

        $social->add_control(
            'icon_style',
            [
                'label'     => esc_html__('Icon Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Flaticon', 'daltech-core'),
                    '3'     => esc_html__('Icon Image', 'daltech-core'),
                    '2'      => esc_html__('Custom Icon', 'daltech-core'),
                ],
            ]
        );

        $social->add_control(
            'flat_icon',
            [
                'label'      => esc_html__('Icon One', 'daltech-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
                'default'    => 'flaticon-budget',
                'condition' => [
                    'icon_style' => '1'
                ]
            ]
        );

        $social->add_control(
            'custom_icon',
            [
                'label'         => esc_html__('Custom Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'label_block'     => true,
                'condition' => [
                    'icon_style' => '2'
                ]
            ]
        );


        $social->add_control(
            'icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'icon_style' => '3'
                ]
            ]
        );

        $social->add_control(
            'url',
            [
                'label' => __('Add Url', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('#', 'daltech-core'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'show_label' => false,
            ]
        );

        $this->add_control(
            'sidemenu_social_list',
            [
                'label' => __('Social List', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $social->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'social_url' => [
                            'url' => '#',
                            'is_external' => false,
                            'nofollow' => false,
                        ],
                    ],
                ],

            ]
        );

        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'header-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') : ?>

            <!-- Header Area Start -->
            <header class="header-section-1">
                <div id="header-sticky" class="header-1">
                    <div class="container-fluid">
                        <div class="mega-menu-wrapper">
                            <div class="header-main">
                                <div class="header-left">
                                    <div class="logo">
                                        <a href="<?php echo esc_url(home_url()); ?>" class="header-logo">
                                            <?php
                                            if (!empty($settings['header_logo']['url'])) {
                                                echo daltech_img_tag(array(
                                                    'url'    => esc_url($settings['header_logo']['url']),
                                                ));
                                            }
                                            ?>
                                        </a>
                                    </div>
                                    <div class="mean__menu-wrapper">
                                        <div class="main-menu">
                                            <nav id="mobile-menu">
                                                <?php
                                                wp_nav_menu(
                                                    array(
                                                        'menu' => $settings['nav_menu'],
                                                        'fallback_cb'     => 'Daltech_Bootstrap_Navwalker::fallback',
                                                        'walker'          => new Daltech_Bootstrap_Navwalker(),
                                                    )
                                                );
                                                ?>
                                            </nav>
                                        </div>
                                    </div>
                                </div>
                                <div class="header-right d-flex justify-content-end align-items-center">
                                    <div class="contact-info">
                                        <div class="icon">
                                            <?php
                                            if (!empty($settings['contact_info_icon_image']['url'])) {
                                                echo daltech_img_tag(array(
                                                    'url'    => esc_url($settings['contact_info_icon_image']['url']),
                                                ));
                                            }
                                            ?>
                                        </div>
                                        <div class="content">
                                            <p><?php echo wp_kses($settings['contact_title'], 'daltech_allowed_tags'); ?></p>
                                            <h6>
                                                <?php echo wp_kses($settings['contact_info'], 'daltech_allowed_tags'); ?>
                                            </h6>
                                        </div>
                                    </div>
                                    <?php if (!empty($settings['url']['url'])) : ?>
                                        <div class="header-button">
                                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="link-btn">
                                                <span><?php echo wp_kses($settings['button_label'], 'daltech_allowed_tags'); ?></span>
                                                <i class="fas fa-chevron-right"></i>
                                            </a>
                                        </div>
                                    <?php endif; ?>
                                    <?php
                                    if ('yes' == $settings['search_enable']) :
                                    ?>
                                        <a href="#0" class="search-trigger search-icon"><i class="fal fa-search"></i></a>
                                        <div class="header__hamburger d-lg-none my-auto">
                                            <div class="sidebar__toggle">
                                                <i class="far fa-bars"></i>
                                            </div>
                                        </div>
                                    <?php endif; ?>

                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </header>
            <!-- End Header One -->

        <?php elseif ($settings['style'] == '2') : ?>

            <!-- Start Header Two -->
            <!-- Header Middle Start -->
            <section class="middle-header">
                <div class="container">
                    <div class="middle-header-wrapper">
                        <div class="header-logo">
                            <a href="<?php echo esc_url(home_url()); ?>">
                                <?php
                                if (!empty($settings['header_logo']['url'])) {
                                    echo daltech_img_tag(array(
                                        'url'    => esc_url($settings['header_logo']['url']),
                                    ));
                                }
                                ?>
                            </a>
                        </div>
                        <div class="header-contact-items">
                            <?php
                            foreach ($settings['contact_info_list'] as $item) :
                            ?>
                                <div class="contact-info-items">
                                    <div class="icon">
                                        <?php if (!empty($item['flat_icon'])) : ?>
                                            <i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
                                        <?php endif; ?>
                                        <?php if (!empty($item['icon_image']['url']['0'])) : ?>
                                            <img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                        <?php endif; ?>
                                        <?php
                                        if (!empty($item['custom_icon'])) : ?>
                                            <i class="<?php echo esc_attr($item['custom_icon']); ?>"></i>
                                        <?php endif; ?>
                                    </div>
                                    <div class="content">
                                        <h6><?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?></h6>
                                        <p><?php echo wp_kses($item['content'], 'daltech_allowed_tags'); ?></p>
                                    </div>
                                </div>
                            <?php
                            endforeach; ?>
                        </div>
                    </div>
                </div>
            </section>

            <!-- Header Area Start -->
            <header class="header-section-2">
                <div id="header-sticky" class="header-2">
                    <div class="container">
                        <div class="mega-menu-wrapper">
                            <div class="header-main">
                                <div class="logo">
                                    <a href="<?php echo esc_url(home_url()); ?>" class="header-logo">
                                        <?php
                                        if (!empty($settings['header_logo_scroll']['url'])) {
                                            echo daltech_img_tag(array(
                                                'url'    => esc_url($settings['header_logo_scroll']['url']),
                                            ));
                                        }
                                        ?>
                                    </a>
                                </div>
                                <div class="header-left">
                                    <div class="mean__menu-wrapper">
                                        <div class="main-menu">
                                            <nav id="mobile-menu">
                                                <?php
                                                wp_nav_menu(
                                                    array(
                                                        'menu' => $settings['nav_menu'],
                                                        'fallback_cb'     => 'Daltech_Bootstrap_Navwalker::fallback',
                                                        'walker'          => new Daltech_Bootstrap_Navwalker(),
                                                    )
                                                );
                                                ?>
                                            </nav>
                                        </div>
                                    </div>
                                </div>

                                <div class="header-right d-flex justify-content-end align-items-center">
                                    <?php
                                    if ('yes' == $settings['search_enable']) :
                                    ?>
                                        <a href="#0" class="search-trigger search-icon"><i class="fal fa-search"></i></a>
                                    <?php endif; ?>
                                    <?php
                                    if ('yes' == $settings['sidemenu_position']) : ?>
                                        <div class="header__hamburger d-xl-block my-auto">
                                            <div class="sidebar__toggle">
                                                <div class="header-bar">
                                                    <span></span>
                                                    <span></span>
                                                    <span></span>
                                                </div>
                                            </div>
                                        </div>
                                    <?php endif; ?>
                                </div>

                            </div>
                        </div>
                    </div>
                </div>
            </header>
            <!-- End Header Two -->

        <?php elseif ($settings['style'] == '3') : ?>

            <!-- Start Header Three -->
            <header class="header-section-3">
                <div id="header-sticky" class="header-3">
                    <div class="container-fluid">
                        <div class="mega-menu-wrapper">
                            <div class="header-main">
                                <div class="logo">
                                    <a href="<?php echo esc_url(home_url()); ?>" class="header-logo">
                                        <?php
                                        if (!empty($settings['header_logo']['url'])) {
                                            echo daltech_img_tag(array(
                                                'url'    => esc_url($settings['header_logo']['url']),
                                            ));
                                        }
                                        ?>
                                    </a>
                                </div>
                                <div class="header-left">
                                    <div class="mean__menu-wrapper">
                                        <div class="main-menu">
                                            <nav id="mobile-menu">
                                                <?php
                                                wp_nav_menu(
                                                    array(
                                                        'menu' => $settings['nav_menu'],
                                                        'fallback_cb'     => 'Daltech_Bootstrap_Navwalker::fallback',
                                                        'walker'          => new Daltech_Bootstrap_Navwalker(),
                                                    )
                                                );
                                                ?>
                                            </nav>
                                        </div>
                                    </div>
                                </div>
                                <div class="header-right d-flex justify-content-end align-items-center">
                                    <div class="header-button">
                                        <?php if (!empty($settings['button_label'])) : ?>
                                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn theme-btn-2">
                                                <span>
                                                    <?php echo wp_kses($settings['button_label'], 'daltech_allowed_tags'); ?>
                                                    <i class="fas fa-chevron-right"></i>
                                                </span>
                                            </a>
                                        <?php endif; ?>
                                    </div>
                                    <?php
                                    if ('yes' == $settings['sidemenu_position']) : ?>
                                        <div class="header__hamburger d-xl-block my-auto">
                                            <div class="sidebar__toggle">
                                                <div class="header-bar">
                                                    <span></span>
                                                    <span></span>
                                                    <span></span>
                                                </div>
                                            </div>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </header>
            <!-- End Header Three -->

        <?php elseif ($settings['style'] == '4') : ?>

            <!-- Start Header Four -->
            <header class="header-section-4">
                <div class="top-header-2">
                    <div class="container-fluid">
                        <div class="top-header-items">
                            <ul class="contact-list">
                                <?php
                                $counter = 1;
                                foreach ($settings['contact_info_list_two'] as $item) :
                                ?>
                                    <li>
                                        <?php if (!empty($item['flat_icon'])) : ?>
                                            <i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
                                        <?php endif; ?>
                                        <?php if (!empty($item['icon_image']['url']['0'])) : ?>
                                            <img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                        <?php endif; ?>
                                        <?php
                                        if (!empty($item['custom_icon'])) : ?>
                                            <i class="<?php echo esc_attr($item['custom_icon']); ?>"></i>
                                        <?php endif; ?> <?php echo wp_kses($item['content'], 'daltech_allowed_tags'); ?>
                                    </li>
                                <?php
                                    if ($counter == '2') {
                                        break;
                                    }
                                    $counter++;
                                endforeach; ?>
                            </ul>
                            <div class="header-right">
                                <ul class="contact-list">
                                    <?php
                                    foreach ($settings['contact_info_list_two'] as $key => $item) :
                                        if ($key === 2) :
                                    ?>
                                            <li>
                                                <?php if (!empty($item['flat_icon'])) : ?>
                                                    <i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
                                                <?php endif; ?>
                                                <?php if (!empty($item['icon_image']['url']['0'])) : ?>
                                                    <img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                                <?php endif; ?>
                                                <?php
                                                if (!empty($item['custom_icon'])) : ?>
                                                    <i class="<?php echo esc_attr($item['custom_icon']); ?>"></i>
                                                <?php endif; ?> <?php echo wp_kses($item['content'], 'daltech_allowed_tags'); ?>
                                            </li>
                                    <?php
                                        endif;
                                    endforeach; ?>
                                </ul>
                                <ul class="social-icon">
                                    <?php
                                    foreach ($settings['social_list'] as $single_item) :
                                    ?>
                                        <li>
                                            <a href="<?php echo esc_url($single_item['url']['url']); ?>">
                                                <?php if (!empty($single_item['flat_icon'])) : ?>
                                                    <i class="<?php echo esc_attr($single_item['flat_icon']); ?>"></i>
                                                <?php endif; ?>
                                                <?php if (!empty($single_item['icon_image']['url'])) : ?>
                                                    <img src="<?php echo esc_url($single_item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                                <?php endif; ?>
                                                <?php
                                                if (!empty($single_item['custom_icon'])) : ?>
                                                    <i class="<?php echo esc_attr($single_item['custom_icon']); ?>"></i>
                                                <?php endif; ?>
                                            </a>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>

                <div id="header-sticky" class="header-4">
                    <div class="container-fluid">
                        <div class="mega-menu-wrapper">
                            <div class="header-main">
                                <div class="header-left">
                                    <div class="logo">
                                        <a href="<?php echo esc_url(home_url()); ?>" class="header-logo-1">
                                            <?php
                                            if (!empty($settings['header_logo']['url'])) {
                                                echo daltech_img_tag(array(
                                                    'url'    => esc_url($settings['header_logo']['url']),
                                                ));
                                            }
                                            ?>
                                        </a>
                                        <a href="<?php echo esc_url(home_url()); ?>" class="header-logo-2">
                                            <?php
                                            if (!empty($settings['header_logo_scroll']['url'])) {
                                                echo daltech_img_tag(array(
                                                    'url'    => esc_url($settings['header_logo_scroll']['url']),
                                                ));
                                            }
                                            ?>
                                        </a>
                                    </div>
                                    <div class="mean__menu-wrapper">
                                        <div class="main-menu">
                                            <nav id="mobile-menu">
                                                <?php
                                                wp_nav_menu(
                                                    array(
                                                        'menu' => $settings['nav_menu'],
                                                        'fallback_cb'     => 'Daltech_Bootstrap_Navwalker::fallback',
                                                        'walker'          => new Daltech_Bootstrap_Navwalker(),
                                                    )
                                                );
                                                ?>
                                            </nav>
                                        </div>
                                    </div>
                                </div>
                                <div class="header-right d-flex justify-content-end align-items-center">
                                    <div class="contact-info-items">
                                        <div class="icon d">
                                            <?php
                                            if (!empty($settings['contact_info_custom_icon'])) : ?>
                                                <i class="<?php echo esc_attr($settings['contact_info_custom_icon']); ?>"></i>
                                            <?php endif; ?>
                                        </div>
                                        <div class="content">
                                            <p><?php echo wp_kses($settings['contact_title'], 'daltech_allowed_tags'); ?></p>
                                            <h6>
                                                <?php echo wp_kses($settings['contact_info'], 'daltech_allowed_tags'); ?>
                                            </h6>
                                        </div>
                                    </div>

                                    <?php if (!empty($settings['button_label'])) : ?>
                                        <div class="header-button">
                                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn">
                                                <span> <?php echo wp_kses($settings['button_label'], 'daltech_allowed_tags'); ?></span>
                                            </a>
                                        </div>
                                    <?php endif; ?>
                                    <div class="header__hamburger d-lg-none my-auto">
                                        <div class="sidebar__toggle">
                                            <i class="far fa-bars"></i>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </header>
            <!-- End Header Four -->

        <?php endif; ?>

        <!-- Search Area Start -->
        <div class="search-wrap">
            <div class="search-inner">
                <i class="fas fa-times search-close" id="search-close"></i>
                <div class="search-cell">
                    <form role="search" method="get" action="<?php echo esc_url(home_url('/')); ?>">
                        <div class="search-field-holder">
                            <input name="s" type="text" class="main-search-input" value="<?php echo esc_attr(get_search_query()); ?>" placeholder="<?php echo esc_attr__("Search...", 'daltech-addons'); ?>">
                        </div>
                    </form>
                </div>
            </div>
        </div>

        <div class="fix-area">
            <div class="offcanvas__info">
                <div class="offcanvas__wrapper">
                    <div class="offcanvas__content">
                        <div class="offcanvas__top mb-5 d-flex justify-content-between align-items-center">
                            <div class="offcanvas__logo">
                                <a href="<?php echo esc_url(home_url()); ?>">
                                    <?php
                                    if (!empty($settings['sidemenu_logo']['url'])) {
                                        echo daltech_img_tag(array(
                                            'url'    => esc_url($settings['sidemenu_logo']['url']),
                                        ));
                                    }
                                    ?>
                                </a>
                            </div>
                            <div class="offcanvas__close">
                                <button>
                                    <i class="fas fa-times"></i>
                                </button>
                            </div>
                        </div>
                        <?php if (!empty($settings['sidemenu_content'])) : ?>
                            <p class="d-none d-lg-block">
                                <?php echo wp_kses($settings['sidemenu_content'], 'daltech_allowed_tags'); ?>
                            </p>
                        <?php endif; ?>
                        <div class="mobile-menu fix mb-3"></div>
                        <div class="offcanvas__contact">
                            <?php if (!empty($settings['sidemenu_contact_heading'])) : ?>
                                <h4>
                                    <?php echo wp_kses($settings['sidemenu_contact_heading'], 'daltech_allowed_tags'); ?>
                                </h4>
                            <?php endif; ?>
                            <?php if (!empty($settings['sidemenu_info_list'])) : ?>
                                <ul>
                                    <?php
                                    $counter = 1;
                                    foreach ($settings['sidemenu_info_list'] as $item) :
                                    ?>
                                        <li class="d-flex align-items-center">
                                            <div class="offcanvas__contact-icon">
                                                <?php if (!empty($item['flat_icon'])) : ?>
                                                    <i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
                                                <?php endif; ?>
                                                <?php if (!empty($item['icon_image']['url']['0'])) : ?>
                                                    <img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                                <?php endif; ?>
                                                <?php
                                                if (!empty($item['custom_icon'])) : ?>
                                                    <i class="<?php echo esc_attr($item['custom_icon']); ?>"></i><?php endif; ?>
                                            </div>
                                            <div class="offcanvas__contact-text">
                                                <?php echo wp_kses($item['content'], 'daltech_allowed_tags'); ?>
                                            </div>
                                        </li>
                                    <?php $counter++;
                                    endforeach; ?>
                                </ul>
                            <?php endif; ?>

                            <?php if (!empty($settings['sidemenu_button_label'])) : ?>
                                <div class="header-button mt-4">
                                    <a href="<?php echo esc_url($settings['sidemanu_url']['url']); ?>" class="theme-btn text-center">
                                        <span> <?php echo wp_kses($settings['sidemenu_button_label'], 'daltech_allowed_tags'); ?><i class="fas fa-chevron-right"></i></span>
                                    </a>
                                </div>
                            <?php endif; ?>
                            <?php if (!empty($settings['sidemenu_social_list'])) : ?>
                                <div class="social-icon d-flex align-items-center">
                                    <?php
                                    foreach ($settings['sidemenu_social_list'] as $single_item) :
                                    ?>
                                        <a href="<?php echo esc_url($single_item['url']['url']); ?>">
                                            <?php if (!empty($single_item['flat_icon'])) : ?>
                                                <i class="<?php echo esc_attr($single_item['flat_icon']); ?>"></i>
                                            <?php endif; ?>
                                            <?php if (!empty($single_item['icon_image']['url'])) : ?>
                                                <img src="<?php echo esc_url($single_item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                            <?php endif; ?>
                                            <?php
                                            if (!empty($single_item['custom_icon'])) : ?>
                                                <i class="<?php echo esc_attr($single_item['custom_icon']); ?>"></i>
                                            <?php endif; ?>
                                        </a>
                                    <?php endforeach; ?>
                                </div>
                            <?php endif; ?>

                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="offcanvas__overlay"></div>
<?php
    }
}
