<?php

/**
 * Elementor daltech PricingWidget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Pricing extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Pricingwidget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_pricing';
    }

    /**
     * Get widget title.
     *
     * Retrieve PricingNav Tab widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Pricing', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve PricingNav Tab widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the PricingNav Tab widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'daltech_pricing_style',
            [
                'label'        => esc_html__('Pricing Style', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('PricingStyle', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                    '2'      => esc_html__('Style Two', 'daltech-core'),
                ],
            ]
        );


        $this->add_control(
            'section_title',
            [
                'label'         => esc_html__('Section Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section title', 'daltech-core'),
                'default'         => esc_html__('Default Section Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1', '2']
                ]
            ]
        );

        $this->add_control(
            'section_subtitle',
            [
                'label'         => esc_html__('Section Subtitle', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section subtitle', 'daltech-core'),
                'default'         => esc_html__('Default Section SubTitle', 'daltech-core'),
                'condition' => [
                    'style' => ['1', '2']
                ]
            ]
        );

        $layout_two_pricing_list = new \Elementor\Repeater();

        $layout_two_pricing_list->add_control(
            'price',
            [
                'label'         => esc_html__('Price', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('Price', 'daltech-core'),
                'default'         => esc_html__('Default Price', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_two_pricing_list->add_control(
            'icon_image',
            [
                'label' => esc_html__('Icon Image', 'agrofa-addon'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ]
            ]
        );

        $layout_two_pricing_list->add_control(
            'plan',
            [
                'label'         => esc_html__('Plan', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('Plan', 'daltech-core'),
                'default'         => esc_html__('Default Plan', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_two_pricing_list->add_control(
            'summary',
            [
                'label'         => esc_html__('Summary', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('Summary', 'daltech-core'),
                'default'         => esc_html__('Default Summary', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_two_pricing_list->add_control(
            'check_list',
            [
                'label'         => esc_html__('Check List', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::CODE,
                'rows'             => '6',
                'placeholder'     => esc_html__('Check List', 'daltech-core'),
                'default'         => esc_html__('Default Check List', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_two_pricing_list->add_control(
            'button_label',
            [
                'label'     => __('Button Label', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::TEXTAREA,
                'rows'         => 2,
                'default'      => __('Button Label', 'daltech-core'),
            ]
        );

        $layout_two_pricing_list->add_control(
            'url',
            [
                'label'         => __('URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => __('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => false,
                    'nofollow'         => false,
                ]
            ]
        );

        $layout_two_pricing_list->add_control(
            'active_status',
            [
                'label' => __('Is active?', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'ploming-addon'),
                'label_off' => __('No', 'ploming-addon'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $layout_two_pricing_list->add_control(
            'active_image',
            [
                'label' => esc_html__('Active Image', 'agrofa-addon'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'selectors' => [
                    '{{WRAPPER}} .single-pricing-items.active-tag::before' => 'background-image:url({{URL}});',
                ],
                'condition' => [
                    'active_status' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'layout_two_pricing_list',
            [
                'label'     => esc_html__('Trusted Client', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_two_pricing_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Trusted Client', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ price }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $layout_one_pricing_list = new \Elementor\Repeater();

        $layout_one_pricing_list->add_control(
            'price',
            [
                'label'         => esc_html__('Price', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('Price', 'daltech-core'),
                'default'         => esc_html__('Default Price', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_pricing_list->add_control(
            'plan',
            [
                'label'         => esc_html__('Plan', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('Plan', 'daltech-core'),
                'default'         => esc_html__('Default Plan', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_pricing_list->add_control(
            'offer',
            [
                'label'         => esc_html__('Offer', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('Offer', 'daltech-core'),
                'default'         => esc_html__('Default Offer', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_pricing_list->add_control(
            'check_list',
            [
                'label'         => esc_html__('Check List', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::CODE,
                'rows'             => '6',
                'placeholder'     => esc_html__('Check List', 'daltech-core'),
                'default'         => esc_html__('Default Check List', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_pricing_list->add_control(
            'button_label',
            [
                'label'     => __('Button Label', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::TEXTAREA,
                'rows'         => 2,
                'default'      => __('Button Label', 'daltech-core'),
            ]
        );

        $layout_one_pricing_list->add_control(
            'url',
            [
                'label'         => __('URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => __('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => false,
                    'nofollow'         => false,
                ]
            ]
        );

        $layout_one_pricing_list->add_control(
            'active_status',
            [
                'label' => __('Is active?', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'ploming-addon'),
                'label_off' => __('No', 'ploming-addon'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );


        $this->add_control(
            'layout_one_pricing_list',
            [
                'label'     => esc_html__('Trusted Client', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_one_pricing_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Trusted Client', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ price }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'shape_one',
            [
                'label' => esc_html__('Shape One', 'agrofa-addon'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->add_control(
            'shape_two',
            [
                'label' => esc_html__('Shape Two', 'agrofa-addon'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->add_control(
            'shape_three',
            [
                'label' => esc_html__('Shape Three', 'agrofa-addon'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => '2'
                ]
            ]
        );

        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'pricing-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') :
?>
            <!--<< Pricing Section Start >>-->
            <section class="pricing-section fix section-padding">
                <div class="container">
                    <div class="section-title style-2 text-center">
                        <span class="wow fadeInUp">
                            <?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?>
                        </span>
                        <h2 class="wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
                        </h2>
                    </div>
                    <div class="row">
                        <?php
                        foreach ($settings['layout_one_pricing_list'] as $item) :
                        ?>
                            <div class="col-xl-4 col-lg-6 col-md-6 wow fadeInUp" data-wow-delay=".3s">
                                <div class="pricing-items <?php echo esc_attr(('yes' == $item['active_status'] ? 'active' : '')); ?>">
                                    <div class="pricing-header">
                                        <h2><?php echo wp_kses($item['price'], 'daltech_allowed_tags'); ?></h2>
                                        <div class="offer-text-area">
                                            <h4><?php echo wp_kses($item['plan'], 'daltech_allowed_tags'); ?></h4>
                                            <h6 class="offer"><?php echo wp_kses($item['offer'], 'daltech_allowed_tags'); ?></h6>
                                        </div>
                                    </div>
                                    <ul class="pricing-list">
                                        <?php echo wp_kses($item['check_list'], 'daltech_allowed_tags'); ?>
                                    </ul>
                                    <?php if (!empty($item['button_label'])) : ?>
                                        <div class="pricing-button">
                                            <a href="<?php echo esc_url($item['url']['url']); ?>" class="theme-btn d-flex justify-content-between align-items-center">
                                                <span> <?php echo wp_kses($item['button_label'], 'daltech_allowed_tags'); ?></span>
                                                <span><i class="far fa-long-arrow-right"></i></span>
                                            </a>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        <?php
                        endforeach;
                        ?>
                    </div>
                </div>
            </section>
            <!-- End Pricing style one -->

        <?php elseif ($settings['style'] == '2') : ?>

            <!-- Start Pricing style Three -->
            <section class="pricing-section fix section-padding section-bg-4">
                <div class="dot-shape">
                    <?php
                    if (!empty($settings['shape_one']['url'])) :
                        echo daltech_img_tag(array(
                            'url'   => esc_url($settings['shape_one']['url'])
                        ));
                    endif;
                    ?>
                </div>
                <div class="arrow-shape float-bob-y">
                    <?php
                    if (!empty($settings['shape_two']['url'])) :
                        echo daltech_img_tag(array(
                            'url'   => esc_url($settings['shape_two']['url'])
                        ));
                    endif;
                    ?>
                </div>
                <div class="dot-shape-2">
                    <?php
                    if (!empty($settings['shape_three']['url'])) :
                        echo daltech_img_tag(array(
                            'url'   => esc_url($settings['shape_three']['url'])
                        ));
                    endif;
                    ?>
                </div>
                <div class="container">
                    <div class="section-title text-center">
                        <span class="wow fadeInUp">
                            <?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?>
                        </span>
                        <h2 class="wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
                        </h2>
                    </div>
                    <div class="row">
                        <?php
                        foreach ($settings['layout_two_pricing_list'] as $item) :
                        ?>
                            <div class="col-xl-4 col-lg-6 wow fadeInUp" data-wow-delay=".5s">
                                <div class="single-pricing-items <?php echo esc_attr(('yes' == $item['active_status'] ? 'active-tag' : '')); ?>">
                                    <div class="icon">
                                        <?php
                                        if (!empty($item['icon_image']['url'])) :
                                            echo daltech_img_tag(array(
                                                'url'   => esc_url($item['icon_image']['url'])
                                            ));
                                        endif;
                                        ?>
                                    </div>
                                    <div class="content">
                                        <h3>
                                            <?php echo wp_kses($item['plan'], 'daltech_allowed_tags'); ?>
                                        </h3>
                                        <p>
                                            <?php echo wp_kses($item['summary'], 'daltech_allowed_tags'); ?>
                                        </p>
                                    </div>
                                    <div class="price-plan">
                                        <h2>
                                            <?php echo wp_kses($item['price'], 'daltech_allowed_tags'); ?>
                                        </h2>
                                    </div>
                                    <ul>
                                        <?php echo wp_kses($item['check_list'], 'daltech_allowed_tags'); ?>
                                    </ul>
                                    <?php if (!empty($item['button_label'])) : ?>
                                        <a href="<?php echo esc_url($item['url']['url']); ?>" class="theme-btn mt-5">
                                            <span> <?php echo wp_kses($item['button_label'], 'daltech_allowed_tags'); ?></span>
                                        </a>
                                    <?php endif; ?>
                                </div>
                            </div>
                        <?php
                        endforeach;
                        ?>
                    </div>
                </div>
            </section>

            <!-- Start Pricing style Three -->
<?php
        endif;
    }
}
