<?php

/**
 * Elementor daltech Project Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Project_Details_Navigation extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Project widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_project_details_navigation';
    }

    /**
     * Get widget title.
     *
     * Retrieve Project Nav Tab widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Project Details Navigation', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Project Nav Tab widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Project Nav Tab widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'project_content_style',
            [
                'label'        => esc_html__('Project Style', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'preview_title',
            [
                'label'         => esc_html__('Preview Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('Preview title', 'daltech-core'),
                'default'         => esc_html__('Default Preview Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'preview_subtitle',
            [
                'label'         => esc_html__('Preview Subtitle', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section Preview Subtitle', 'daltech-core'),
                'default'         => esc_html__('Default Preview SubTitle', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'preview_url',
            [
                'label'         => __('Preview URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => __('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => false,
                    'nofollow'         => false,
                ],
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'next_title',
            [
                'label'         => esc_html__('Next Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('Next title', 'daltech-core'),
                'default'         => esc_html__('Default Next Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'next_subtitle',
            [
                'label'         => esc_html__('Next Subtitle', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section Next Subtitle', 'daltech-core'),
                'default'         => esc_html__('Default Next SubTitle', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'next_url',
            [
                'label'         => __('Next URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => __('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => false,
                    'nofollow'         => false,
                ],
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->end_controls_section();
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') :
?>
            <!--<< Project Section Start >>-->
            <div class="container">
                <div class="project-details-wrapper">
                    <div class="previous-button">
                        <div class="preview-button">
                            <span><?php echo wp_kses($settings['preview_subtitle'], 'daltech_allowed_tags'); ?><i class="fas fa-chevron-right"></i></span>
                            <h4>
                                <a href="<?php echo esc_url($settings['preview_url']['url']); ?>"><?php echo wp_kses($settings['preview_title'], 'daltech_allowed_tags'); ?></a>
                            </h4>
                        </div>
                        <div class="icon">
                            <i class="fas fa-th"></i>
                        </div>
                        <div class="preview-button style-2">
                            <span><?php echo wp_kses($settings['next_subtitle'], 'daltech_allowed_tags'); ?><i class="fas fa-chevron-right"></i></span>
                            <h4>
                                <a href="<?php echo esc_url($settings['preview_url']['url']); ?>"><?php echo wp_kses($settings['next_title'], 'daltech_allowed_tags'); ?></a>
                            </h4>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End  Project Style One -->


<?php
        endif;
    }
}
