<?php

/**
 * Elementor daltech Service Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Service extends \Elementor\Widget_Base
{

	/**
	 * Get widget name.
	 *
	 * Retrieve Service widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name()
	{
		return 'daltech_service';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Service Nav Tab widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title()
	{
		return esc_html__('Service', 'daltech-core');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Service Nav Tab widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon()
	{
		return 'eicon-code';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Service Nav Tab widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories()
	{
		return ['daltech'];
	}

	// Add The Input For User
	protected function register_controls()
	{

		$this->start_controls_section(
			'daltech_service_style',
			[
				'label'		=> esc_html__('Service Style', 'daltech-core'),
				'tab'		=> \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'style',
			[
				'label' 	=> esc_html__('Service Style', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::SELECT,
				'default' 	=> '1',
				'options' 	=> [
					'1'  	=> esc_html__('Style One', 'daltech-core'),
					'2'  	=> esc_html__('Style Two', 'daltech-core'),
					'3'  	=> esc_html__('Style Three', 'daltech-core'),
					'4'  	=> esc_html__('Style Four', 'daltech-core'),
					'5'  	=> esc_html__('Style Five', 'daltech-core'),
					'6'  	=> esc_html__('Style Six', 'daltech-core'),
					'7'  	=> esc_html__('Style Seven', 'daltech-core'),
					'8'  	=> esc_html__('Style Eight', 'daltech-core'),
					'9'  	=> esc_html__('Style Nine', 'daltech-core'),
				],
			]
		);


		$this->add_control(
			'section_title',
			[
				'label' 		=> esc_html__('Section Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('section title', 'daltech-core'),
				'default' 		=> esc_html__('Default Section Title', 'daltech-core'),
				'condition' => [
					'style' => ['1', '2', '3', '4', '5', '6', '7', '8', '9']
				]
			]

		);

		$this->add_control(
			'section_subtitle',
			[
				'label' 		=> esc_html__('Section Subtitle', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('section subtitle', 'daltech-core'),
				'default' 		=> esc_html__('Default Section SubTitle', 'daltech-core'),
				'condition' => [
					'style' => ['1', '2', '3', '4', '5', '6', '7', '8', '9']
				]

			]
		);

		$this->add_control(
			'section_summary',
			[
				'label' 		=> esc_html__('Section Summary', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('section Summary', 'daltech-core'),
				'default' 		=> esc_html__('Default Section Summary', 'daltech-core'),
				'condition' => [
					'style' => ['3', '4', '6']
				]

			]
		);

		$this->add_control(
			'check_list',
			[
				'label' 		=> esc_html__('Check List', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('Check List', 'daltech-core'),
				'default' 		=> esc_html__('Default Check List', 'daltech-core'),
				'condition' => [
					'style' => ['9']
				]

			]
		);


		$this->add_control(
			'button_label',
			[
				'label' 	=> __('Button Label', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 		=> 2,
				'default'  	=> __('Button Label', 'daltech-core'),
				'condition' => [
					'style' => ['1', '3', '6']
				]
			]
		);

		$this->add_control(
			'url',
			[
				'label' 		=> __('URL', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::URL,
				'placeholder' 	=> __('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
				'condition' => [
					'style' => ['1', '3', '6']
				]
			]
		);

		$layout_one_service_list = new \Elementor\Repeater();

		$layout_one_service_list->add_control(
			'title',
			[
				'label' 		=> esc_html__('Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('title', 'daltech-core'),
				'default' 		=> esc_html__('Default Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_one_service_list->add_control(
			'subtitle',
			[
				'label' 		=> esc_html__('Sub Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('sub-title', 'daltech-core'),
				'default' 		=> esc_html__('Default Sub Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_one_service_list->add_control(
			'number',
			[
				'label' 		=> esc_html__('Number', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('number', 'daltech-core'),
				'default' 		=> esc_html__('01', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_one_service_list->add_control(
			'image',
			[
				'label' => esc_html__('Image', 'agrofa-addon'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				]
			]
		);

		$layout_one_service_list->add_control(
			'url',
			[
				'label' 		=> esc_html__('URL', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::URL,
				'placeholder' 	=> esc_html__('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> true,
					'nofollow' 		=> true,
				],
			]
		);

		$layout_one_service_list->add_control(
			'form_icon_style',
			[
				'label'     => esc_html__('Form Icon Style', 'daltech-core'),
				'type'         => \Elementor\Controls_Manager::SELECT,
				'default'     => '1',
				'options'     => [
					'1'      => esc_html__('Flaticon', 'daltech-core'),
					'3'     => esc_html__('Icon Image', 'daltech-core'),
					'2'      => esc_html__('Custom Icon', 'daltech-core'),
				],
			]
		);

		$layout_one_service_list->add_control(
			'flat_icon',
			[
				'label'      => esc_html__('Icon One', 'cleanu-core'),
				'type'       => \Elementor\Controls_Manager::ICON,
				'options'    => daltech_flaticons(),
				'include'    => daltech_include_flaticons(),
				'condition' => [
					'form_icon_style' => '1'
				]
			]
		);

		$layout_one_service_list->add_control(
			'custom_icon',
			[
				'label'         => esc_html__('Custom Icon', 'daltech-core'),
				'type'             => \Elementor\Controls_Manager::TEXTAREA,
				'label_block'     => true,
				'rows'          => '2',
				'condition' => [
					'form_icon_style' => '2'
				]
			]
		);

		$layout_one_service_list->add_control(
			'icon_image',
			[
				'label'            => esc_html__('Add Image Icon', 'daltech-core'),
				'type'             => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'form_icon_style' => '3'
				]
			]
		);

		$this->add_control(
			'layout_one_service_list',
			[
				'label' 	=> esc_html__('Service', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::REPEATER,
				'fields' 	=> $layout_one_service_list->get_controls(),
				'default' 	=> [
					[
						'list_title' => esc_html__('Add Service', 'daltech-core'),
					],
				],
				'title_field' => '{{{ title }}}',
				'prevent_empty' => false,
				'condition' => [
					'style' => '1'
				]
			]
		);

		$layout_two_service_list = new \Elementor\Repeater();

		$layout_two_service_list->add_control(
			'title',
			[
				'label' 		=> esc_html__('Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('title', 'daltech-core'),
				'default' 		=> esc_html__('Default Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_two_service_list->add_control(
			'subtitle',
			[
				'label' 		=> esc_html__('Sub Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('sub-title', 'daltech-core'),
				'default' 		=> esc_html__('Default Sub Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_two_service_list->add_control(
			'hover_shape',
			[
				'label' => esc_html__('Hover Shape', 'agrofa-addon'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'selectors' => [
					'{{WRAPPER}} .service-box-items::after' => 'background-image:url({{URL}});',
				],
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				]
			]
		);

		$layout_two_service_list->add_control(
			'url',
			[
				'label' 		=> esc_html__('URL', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::URL,
				'placeholder' 	=> esc_html__('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> true,
					'nofollow' 		=> true,
				],
			]
		);

		$layout_two_service_list->add_control(
			'form_icon_style',
			[
				'label'     => esc_html__('Form Icon Style', 'daltech-core'),
				'type'         => \Elementor\Controls_Manager::SELECT,
				'default'     => '1',
				'options'     => [
					'1'      => esc_html__('Flaticon', 'daltech-core'),
					'3'     => esc_html__('Icon Image', 'daltech-core'),
					'2'      => esc_html__('Custom Icon', 'daltech-core'),
				],
			]
		);

		$layout_two_service_list->add_control(
			'flat_icon',
			[
				'label'      => esc_html__('Icon One', 'cleanu-core'),
				'type'       => \Elementor\Controls_Manager::ICON,
				'options'    => daltech_flaticons(),
				'include'    => daltech_include_flaticons(),
				'condition' => [
					'form_icon_style' => '1'
				]
			]
		);

		$layout_two_service_list->add_control(
			'custom_icon',
			[
				'label'         => esc_html__('Custom Icon', 'daltech-core'),
				'type'             => \Elementor\Controls_Manager::TEXTAREA,
				'label_block'     => true,
				'rows'          => '2',
				'condition' => [
					'form_icon_style' => '2'
				]
			]
		);

		$layout_two_service_list->add_control(
			'icon_image',
			[
				'label'            => esc_html__('Add Image Icon', 'daltech-core'),
				'type'             => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'form_icon_style' => '3'
				]
			]
		);

		$this->add_control(
			'layout_two_service_list',
			[
				'label' 	=> esc_html__('Service', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::REPEATER,
				'fields' 	=> $layout_two_service_list->get_controls(),
				'default' 	=> [
					[
						'list_title' => esc_html__('Add Service', 'daltech-core'),
					],
				],
				'title_field' => '{{{ title }}}',
				'prevent_empty' => false,
				'condition' => [
					'style' => ['2', '8']
				]
			]
		);

		$layout_three_service_list = new \Elementor\Repeater();

		$layout_three_service_list->add_control(
			'title',
			[
				'label' 		=> esc_html__('Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('title', 'daltech-core'),
				'default' 		=> esc_html__('Default Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_three_service_list->add_control(
			'subtitle',
			[
				'label' 		=> esc_html__('Sub Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('sub-title', 'daltech-core'),
				'default' 		=> esc_html__('Default Sub Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_three_service_list->add_control(
			'form_icon_style',
			[
				'label'     => esc_html__('Form Icon Style', 'daltech-core'),
				'type'         => \Elementor\Controls_Manager::SELECT,
				'default'     => '1',
				'options'     => [
					'1'      => esc_html__('Flaticon', 'daltech-core'),
					'3'     => esc_html__('Icon Image', 'daltech-core'),
					'2'      => esc_html__('Custom Icon', 'daltech-core'),
				],
			]
		);

		$layout_three_service_list->add_control(
			'flat_icon',
			[
				'label'      => esc_html__('Icon One', 'cleanu-core'),
				'type'       => \Elementor\Controls_Manager::ICON,
				'options'    => daltech_flaticons(),
				'include'    => daltech_include_flaticons(),
				'condition' => [
					'form_icon_style' => '1'
				]
			]
		);

		$layout_three_service_list->add_control(
			'custom_icon',
			[
				'label'         => esc_html__('Custom Icon', 'daltech-core'),
				'type'             => \Elementor\Controls_Manager::TEXTAREA,
				'label_block'     => true,
				'rows'          => '2',
				'condition' => [
					'form_icon_style' => '2'
				]
			]
		);

		$layout_three_service_list->add_control(
			'icon_image',
			[
				'label'            => esc_html__('Add Image Icon', 'daltech-core'),
				'type'             => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'form_icon_style' => '3'
				]
			]
		);

		$layout_three_service_list->add_control(
			'url',
			[
				'label' 		=> esc_html__('URL', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::URL,
				'placeholder' 	=> esc_html__('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> true,
					'nofollow' 		=> true,
				],
			]
		);

		$this->add_control(
			'layout_three_service_list',
			[
				'label' 	=> esc_html__('Service', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::REPEATER,
				'fields' 	=> $layout_three_service_list->get_controls(),
				'default' 	=> [
					[
						'list_title' => esc_html__('Add Service', 'daltech-core'),
					],
				],
				'title_field' => '{{{ title }}}',
				'prevent_empty' => false,
				'condition' => [
					'style' => '3'
				]
			]
		);

		$layout_four_service_list = new \Elementor\Repeater();

		$layout_four_service_list->add_control(
			'title',
			[
				'label' 		=> esc_html__('Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('title', 'daltech-core'),
				'default' 		=> esc_html__('Default Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_four_service_list->add_control(
			'url',
			[
				'label' 		=> esc_html__('URL', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::URL,
				'placeholder' 	=> esc_html__('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> true,
					'nofollow' 		=> true,
				],
			]
		);

		$layout_four_service_list->add_control(
			'form_icon_style',
			[
				'label'     => esc_html__('Form Icon Style', 'daltech-core'),
				'type'         => \Elementor\Controls_Manager::SELECT,
				'default'     => '1',
				'options'     => [
					'1'      => esc_html__('Flaticon', 'daltech-core'),
					'3'     => esc_html__('Icon Image', 'daltech-core'),
					'2'      => esc_html__('Custom Icon', 'daltech-core'),
				],
			]
		);

		$layout_four_service_list->add_control(
			'flat_icon',
			[
				'label'      => esc_html__('Icon One', 'cleanu-core'),
				'type'       => \Elementor\Controls_Manager::ICON,
				'options'    => daltech_flaticons(),
				'include'    => daltech_include_flaticons(),
				'condition' => [
					'form_icon_style' => '1'
				]
			]
		);

		$layout_four_service_list->add_control(
			'custom_icon',
			[
				'label'         => esc_html__('Custom Icon', 'daltech-core'),
				'type'             => \Elementor\Controls_Manager::TEXTAREA,
				'label_block'     => true,
				'rows'          => '2',
				'condition' => [
					'form_icon_style' => '2'
				]
			]
		);

		$layout_four_service_list->add_control(
			'icon_image',
			[
				'label'            => esc_html__('Add Image Icon', 'daltech-core'),
				'type'             => \Elementor\Controls_Manager::MEDIA,
				'condition' => [
					'form_icon_style' => '3'
				]
			]
		);

		$layout_four_service_list->add_control(
			'active_status',
			[
				'label' => __('Is active?', 'daltech-core'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('Yes', 'ploming-addon'),
				'label_off' => __('No', 'ploming-addon'),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'layout_four_service_list',
			[
				'label' 	=> esc_html__('Service', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::REPEATER,
				'fields' 	=> $layout_four_service_list->get_controls(),
				'default' 	=> [
					[
						'list_title' => esc_html__('Add Service', 'daltech-core'),
					],
				],
				'title_field' => '{{{ title }}}',
				'prevent_empty' => false,
				'condition' => [
					'style' => '4'
				]
			]
		);

		$layout_five_service_list = new \Elementor\Repeater();

		$layout_five_service_list->add_control(
			'title',
			[
				'label' 		=> esc_html__('Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('title', 'daltech-core'),
				'default' 		=> esc_html__('Default Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_five_service_list->add_control(
			'subtitle',
			[
				'label' 		=> esc_html__('Sub Title', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('sub-title', 'daltech-core'),
				'default' 		=> esc_html__('Default Sub Title', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_five_service_list->add_control(
			'icon_image',
			[
				'label' => esc_html__('Icon Image', 'agrofa-addon'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$layout_five_service_list->add_control(
			'read_more_text',
			[
				'label' 		=> esc_html__('Read More Text', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('Read More Text', 'daltech-core'),
				'default' 		=> esc_html__('Read More Text', 'daltech-core'),
				'label_block' 	=> true,
			]
		);

		$layout_five_service_list->add_control(
			'url',
			[
				'label' 		=> esc_html__('URL', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::URL,
				'placeholder' 	=> esc_html__('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> true,
					'nofollow' 		=> true,
				],
			]
		);

		$this->add_control(
			'layout_five_service_list',
			[
				'label' 	=> esc_html__('Service', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::REPEATER,
				'fields' 	=> $layout_five_service_list->get_controls(),
				'default' 	=> [
					[
						'list_title' => esc_html__('Add Service', 'daltech-core'),
					],
				],
				'title_field' => '{{{ title }}}',
				'prevent_empty' => false,
				'condition' => [
					'style' => ['5', '7']
				]
			]
		);

		$this->add_control(
			'layout_four_bottom_text',
			[
				'label' 		=> esc_html__('Bottom text', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::TEXTAREA,
				'placeholder' 	=> esc_html__('Bottom text', 'daltech-core'),
				'default' 		=> esc_html__('Default Bottom text', 'daltech-core'),
				'label_block' 	=> true,
				'condition' => [
					'style' => '4'
				]
			]
		);

		$this->add_control(
			'layout_four_bottom_link_text',
			[
				'label' 	=> __('Link Text', 'daltech-core'),
				'type' 		=> \Elementor\Controls_Manager::TEXTAREA,
				'rows' 		=> 2,
				'default'  	=> __('Button Label', 'daltech-core'),
				'condition' => [
					'style' => ['4']
				]
			]
		);

		$this->add_control(
			'layout_four_bottom_link',
			[
				'label' 		=> __('URL', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::URL,
				'placeholder' 	=> __('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
				'condition' => [
					'style' => ['4']
				]
			]
		);

		$this->add_control(
			'video_url',
			[
				'label' 		=> __('Video URL', 'daltech-core'),
				'type' 			=> \Elementor\Controls_Manager::URL,
				'placeholder' 	=> __('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' 		=> [
					'url' 			=> '#',
					'is_external' 	=> false,
					'nofollow' 		=> false,
				],
				'condition' => [
					'style' => ['6', '9']
				]
			]
		);

		$this->add_control(
			'bg_image_one',
			[
				'label' => esc_html__('Background Image One', 'agrofa-addon'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['6', '9']
				]
			]
		);

		$this->add_control(
			'bg_shape_one',
			[
				'label' => esc_html__('Background Shape One', 'agrofa-addon'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['1', '3', '5', '6', '7']
				]
			]
		);

		$this->add_control(
			'bg_shape_two',
			[
				'label' => esc_html__('Background Shape Two', 'agrofa-addon'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['1', '3', '6']
				]
			]
		);

		$this->add_control(
			'bg_shape_three',
			[
				'label' => esc_html__('Background Shape Three', 'agrofa-addon'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['3', '6']
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'slider_settings',
			[
				'label' => __('Carousel Settings', 'modina-core'),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'slidestoshow',
			[
				'label' => __('Slides To Show', 'modina-core'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'label_block' => true,
				'default' => '1',
				'options' => [
					'1'  => __('1', 'modina-core'),
					'2'  => __('2', 'modina-core'),
					'3'  => __('3', 'modina-core'),
				],
			]
		);

		$this->add_control(
			'slidestoscroll',
			[
				'label' => __('Slides To Scroll', 'modina-core'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'label_block' => true,
				'default' => '1',
				'options' => [
					'1'  => __('1', 'modina-core'),
					'2'  => __('2', 'modina-core'),
					'3'  => __('3', 'modina-core'),
					'4'  => __('4', 'modina-core'),
				],
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label' => __('Auto Play?', 'modina-core'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('Show', 'modina-core'),
				'label_off' => __('Hide', 'modina-core'),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'infinite',
			[
				'label' => __('Infinite Loop', 'modina-core'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('Show', 'modina-core'),
				'label_off' => __('Hide', 'modina-core'),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'autoplaytimeout',
			[
				'label' => __('Autoplay Timeout', 'modina-core'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'label_block' => true,
				'default' => '2000',
				'options' => [
					'1000'  => __('1 Second', 'modina-core'),
					'2000'  => __('2 Second', 'modina-core'),
					'3000'  => __('3 Second', 'modina-core'),
					'4000'  => __('4 Second', 'modina-core'),
					'5000'  => __('5 Second', 'modina-core'),
					'6000'  => __('6 Second', 'modina-core'),
					'7000'  => __('7 Second', 'modina-core'),
					'8000'  => __('8 Second', 'modina-core'),
					'9000'  => __('9 Second', 'modina-core'),
					'10000' => __('10 Second', 'modina-core'),
					'11000' => __('11 Second', 'modina-core'),
					'12000' => __('12 Second', 'modina-core'),
					'13000' => __('13 Second', 'modina-core'),
					'14000' => __('14 Second', 'modina-core'),
					'15000' => __('15 Second', 'modina-core'),
				],
			]
		);

		$this->end_controls_section();

		include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'service-style.php';
	}

	// Output For User
	protected function render()
	{
		$settings = $this->get_settings_for_display();

		$dynamic_id = rand(123, 456);
		$slidestoshow = !empty($settings['slidestoshow']) ? $settings['slidestoshow'] : '2';
		$slidestoscroll = !empty($settings['slidestoscroll']) ? $settings['slidestoscroll'] : '2';
		$infinite = $settings['infinite'] == 'yes' ? 'true' : 'false';
		$autoplay = $settings['autoplay'] == 'yes' ? 'true' : 'false';
		$autoplaytimeout =  !empty($settings['autoplaytimeout']) ? $settings['autoplaytimeout'] : '800';

		if ($settings['style'] == '1') :
?>
			<!--<< Service Section Start >>-->
			<section class="service-section fix section-padding section-bg">
				<div class="shape-image">
					<?php
					if (!empty($settings['bg_shape_one']['url'])) :
						echo daltech_img_tag(array(
							'url'   => esc_url($settings['bg_shape_one']['url'])
						));
					endif;
					?>
				</div>
				<div class="bottom-shape">
					<?php
					if (!empty($settings['bg_shape_two']['url'])) :
						echo daltech_img_tag(array(
							'url'   => esc_url($settings['bg_shape_two']['url'])
						));
					endif;
					?>
				</div>
				<div class="container">
					<div class="title-section-area">
						<div class="section-title">
							<span class="wow fadeInUp"><?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?></span>
							<h2 class="wow fadeInUp" data-wow-delay=".3s">
								<?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
							</h2>
						</div>
						<?php if (!empty($settings['button_label'])) : ?>
							<a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn wow fadeInUp" data-wow-delay=".5s">
								<span>
									<?php echo wp_kses_post($settings['button_label'], 'daltech_kses_allowed_html'); ?>
									<i class="fas fa-chevron-right"></i>
								</span>
							</a>
						<?php
						endif;
						?>
					</div>
				</div>
				<div class="service-wrapper">
					<div class="service-carousel-active">
						<?php
						$counter = 1;
						foreach ($settings['layout_one_service_list'] as $item) :
						?>
							<div class="service-card-items">
								<div class="service-content">
									<div class="icon">
										<?php if (!empty($item['flat_icon'])) : ?>
											<i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
										<?php endif; ?>
										<?php if (!empty($item['icon_image']['url'])) : ?>
											<img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
										<?php endif; ?>
										<?php
										if (!empty($item['custom_icon'])) : ?>
											<i class="<?php echo esc_attr($item['custom_icon']); ?>"></i>
										<?php endif; ?>
									</div>
									<div class="content">
										<h4><?php echo wp_kses_post($item['number'], 'daltech_kses_allowed_html'); ?></h4>
										<h3>
											<a href="<?php echo esc_url($item['url']['url']); ?>"><?php echo wp_kses_post($item['title'], 'daltech_kses_allowed_html'); ?>
											</a>
										</h3>
										<p>
											<?php echo wp_kses_post($item['subtitle'], 'daltech_kses_allowed_html'); ?>
										</p>
									</div>
								</div>
								<div class="service-image bg-cover" style="background-image: url(<?php echo esc_url($item['image']['url']); ?>);">
									<a href="<?php echo esc_url($item['url']['url']); ?>" class="arrow-icon">
										<i class="far fa-arrow-right"></i>
									</a>
								</div>
							</div>
						<?php
							$counter++;
						endforeach;
						?>
					</div>
				</div>
			</section>
			<!-- End Services style one -->

			<script>
				(function($) {
					"use strict";
					$(document).ready(function() {
						if ($('.service-carousel-active').length > 0) {
							$('.service-carousel-active').slick({
								autoplay: <?php echo $autoplay; ?>,
								autoplaySpeed: <?php echo $autoplaytimeout; ?>,
								infinite: <?php echo $infinite; ?>,
								speed: 500,
								arrows: false,
								slidesToShow: <?php echo $slidestoshow; ?>,
								slidesToScroll: <?php echo $slidestoscroll; ?>,
								dots: true,
								dotsClass: 'slide-dots',
								responsive: [{
										breakpoint: 1600,
										settings: {
											slidesToShow: 3
										}
									},
									{
										breakpoint: 1399,
										settings: {
											slidesToShow: 2
										}
									},
									{
										breakpoint: 768,
										settings: {
											slidesToShow: 1,
											center: true,
										}
									},
									{
										breakpoint: 480,
										settings: {
											slidesToShow: 1
										}
									}
								],

							});
						}

					});
				}(jQuery));
			</script>

		<?php elseif ($settings['style'] == '2') : ?>

			<!--<< Service Section Start >>-->
			<section class="service-section-2 fix section-padding">
				<div class="container">
					<div class="section-title text-center">
						<span class="wow fadeInUp"><?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?></span>
						<h2 class="wow fadeInUp" data-wow-delay=".3s">
							<?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
						</h2>
					</div>
					<div class="row">
						<?php
						$counter = 1;
						foreach ($settings['layout_two_service_list'] as $item) :
						?>
							<div class="col-xl-3 col-lg-6 col-md-6 wow fadeInUp" data-wow-delay=".3s">
								<div class="service-box-items">
									<div class="icon">
										<?php if (!empty($item['flat_icon'])) : ?>
											<i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
										<?php endif; ?>
										<?php if (!empty($item['icon_image']['url'])) : ?>
											<img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
										<?php endif; ?>
										<?php
										if (!empty($item['custom_icon'])) : ?>
											<i class="<?php echo esc_attr($item['custom_icon']); ?>"></i>
										<?php endif; ?>
									</div>
									<div class="content">
										<h3>
											<a href="<?php echo esc_url($item['url']['url']); ?>"><?php echo wp_kses_post($item['title'], 'daltech_kses_allowed_html'); ?>
											</a>
										</h3>
										<p>
											<?php echo wp_kses_post($item['subtitle'], 'daltech_kses_allowed_html'); ?>
										</p>
										<?php if (!empty($item['url']['url'])) : ?>
											<a href="<?php echo esc_url($item['url']['url']); ?>" class="arrow-icon">
												<i class="far fa-arrow-right"></i>
											</a>
										<?php endif; ?>

									</div>
								</div>
							</div>
						<?php
							$counter++;
						endforeach;
						?>
					</div>
				</div>
			</section>

		<?php elseif ($settings['style'] == '3') : ?>

			<!--<< Service Section Three Start >>-->
			<section class="service-section fix section-padding section-bg-2">
				<div class="left-shape">
					<?php
					if (!empty($settings['bg_shape_one']['url'])) :
						echo daltech_img_tag(array(
							'url'   => esc_url($settings['bg_shape_one']['url'])
						));
					endif;
					?>
				</div>
				<div class="right-shape">
					<?php
					if (!empty($settings['bg_shape_two']['url'])) :
						echo daltech_img_tag(array(
							'url'   => esc_url($settings['bg_shape_two']['url'])
						));
					endif;
					?>
				</div>
				<div class="line-shape-2">
					<?php
					if (!empty($settings['bg_shape_three']['url'])) :
						echo daltech_img_tag(array(
							'url'   => esc_url($settings['bg_shape_three']['url'])
						));
					endif;
					?>
				</div>
				<div class="container">
					<div class="service-wrapper-2">
						<div class="row justify-content-between">
							<div class="col-lg-4">
								<div class="service-content">
									<div class="section-title">
										<span class="wow fadeInUp">
											<?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?>
										</span>
										<h2 class="wow fadeInUp" data-wow-delay=".3s">
											<?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
										</h2>
									</div>
									<p class="mt-4 mt-md-0 wow fadeInUp" data-wow-delay=".5s">
										<?php echo wp_kses_post($settings['section_summary'], 'daltech_kses_allowed_html'); ?>
									</p>
									<?php if (!empty($settings['button_label'])) : ?>
										<div class="service-button wow fadeInUp" data-wow-delay=".7s">
											<a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn">
												<span>
													<?php echo wp_kses_post($settings['button_label'], 'daltech_kses_allowed_html'); ?>
													<i class="fas fa-chevron-right"></i>
												</span>
											</a>
										</div>
									<?php endif; ?>
								</div>
							</div>
							<div class="col-lg-7 mt-5 mt-lg-0">
								<div class="row g-4">
									<?php
									foreach ($settings['layout_three_service_list'] as $item) :
									?>
										<div class="col-lg-6 col-md-6 wow fadeInUp" data-wow-delay=".3s">
											<div class="service-box-items-2">
												<div class="icon">
													<?php if (!empty($item['flat_icon'])) : ?>
														<i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
													<?php endif; ?>
													<?php if (!empty($item['icon_image']['url'])) : ?>
														<img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
													<?php endif; ?>
													<?php
													if (!empty($item['custom_icon'])) : ?>
														<i class="<?php echo esc_attr($item['custom_icon']); ?>"></i>
													<?php endif; ?>
												</div>
												<div class="content">
													<h3>
														<a href="<?php echo esc_url($item['url']['url']); ?>"><?php echo wp_kses_post($item['title'], 'daltech_kses_allowed_html'); ?>
														</a>
													</h3>
													<p>
														<?php echo wp_kses_post($item['subtitle'], 'daltech_kses_allowed_html'); ?>
													</p>
												</div>
											</div>
										</div>
									<?php
									endforeach;
									?>
								</div>
							</div>
						</div>
					</div>
				</div>
			</section>
			<!--<< Service Section Three End >>-->

		<?php elseif ($settings['style'] == '4') : ?>

			<!--<< Service Section Four Start >>-->
			<section class="service-section section-bg-4 fix section-padding">
				<div class="container">
					<div class="title-section-area">
						<div class="section-title style-2">
							<span class="wow fadeInUp"><?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?></span>
							<h2 class="wow fadeInUp" data-wow-delay=".3s">
								<?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
							</h2>
						</div>
						<p class="wow fadeInUp" data-wow-delay=".5s">
							<?php echo wp_kses_post($settings['section_summary'], 'daltech_kses_allowed_html'); ?>
						</p>
					</div>
					<div class="service-wrapper-3">
						<?php
						foreach ($settings['layout_four_service_list'] as $item) :
						?>
							<div class="service-box-items style-2 wow <?php echo esc_attr(('yes' == $item['active_status'] ? 'active' : '')); ?> fadeInUp" data-wow-delay=".3s">
								<div class="icon">
									<?php if (!empty($item['flat_icon'])) : ?>
										<i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
									<?php endif; ?>
									<?php if (!empty($item['icon_image']['url'])) : ?>
										<img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
									<?php endif; ?>
									<?php
									if (!empty($item['custom_icon'])) : ?>
										<i class="<?php echo esc_attr($item['custom_icon']); ?>"></i>
									<?php endif; ?>
								</div>
								<div class="content">
									<h6>
										<a href="<?php echo esc_url($item['url']['url']); ?>">
											<?php echo wp_kses_post($item['title'], 'daltech_kses_allowed_html'); ?>
										</a>
									</h6>
								</div>
							</div>
						<?php
						endforeach;
						?>
					</div>
					<div class="service-text-area text-center mt-5 wow fadeInUp" data-wow-delay=".4s">
						<h5>
							<?php echo wp_kses_post($settings['layout_four_bottom_text'], 'daltech_kses_allowed_html'); ?>
							<?php if (!empty($settings['layout_four_bottom_link_text'])) : ?>
								<a href="<?php echo esc_url($settings['layout_four_bottom_link']['url']); ?>" class="link-btn link-btn-2">
									<span><?php echo wp_kses_post($settings['layout_four_bottom_link_text'], 'daltech_kses_allowed_html'); ?></span>
									<i class="fal fa-plus"></i>
								</a>
							<?php endif; ?>
						</h5>
					</div>
				</div>
			</section>
			<!--<< Service Section Four End >>-->

			<script>
				(function($) {
					"use strict";
					$(document).ready(function() {
						if ($('.service-carousel-active').length > 0) {
							$('.service-carousel-active').slick({

								autoplay: <?php echo $autoplay; ?>,
								autoplaySpeed: <?php echo $autoplaytimeout; ?>,
								infinite: <?php echo $infinite; ?>,
								speed: 500,
								arrows: false,
								slidesToShow: <?php echo $slidestoshow; ?>,
								slidesToScroll: <?php echo $slidestoscroll; ?>,
								dots: true,
								dotsClass: 'slide-dots',
								responsive: [{
										breakpoint: 1600,
										settings: {
											slidesToShow: 3
										}
									},
									{
										breakpoint: 1399,
										settings: {
											slidesToShow: 2
										}
									},
									{
										breakpoint: 768,
										settings: {
											slidesToShow: 1,
											center: true,
										}
									},
									{
										breakpoint: 480,
										settings: {
											slidesToShow: 1
										}
									}
								],

							});
						}

					});
				}(jQuery));
			</script>

		<?php elseif ($settings['style'] == '5') : ?>

			<!--<< Service Section Five Strat >>-->
			<section class="service-section  section-padding pt-0">
				<div class="bg-shape">
					<?php
					if (!empty($settings['bg_shape_one']['url'])) :
						echo daltech_img_tag(array(
							'url'   => esc_url($settings['bg_shape_one']['url'])
						));
					endif;
					?>
				</div>
				<div class="container">
					<div class="section-title text-center">
						<span class=" wow fadeInUp">
							<?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?>
						</span>
						<h2 class="wow fadeInUp" data-wow-delay=".3s">
							<?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
						</h2>
					</div>
					<div class="row">
						<?php
						foreach ($settings['layout_five_service_list'] as $item) :
						?>
							<div class="col-xl-4 col-lg-4 col-md-6 wow fadeInUp" data-wow-delay=".3s">
								<div class="single-service-style-2 center">
									<div class="icon">
										<?php
										if (!empty($item['icon_image']['url'])) :
											echo daltech_img_tag(array(
												'url'   => esc_url($item['icon_image']['url'])
											));
										endif;
										?>
									</div>
									<div class="content">
										<h3>
											<a href="<?php echo esc_url($item['url']['url']); ?>">
												<?php echo wp_kses_post($item['title'], 'daltech_kses_allowed_html'); ?>
											</a>
										</h3>
										<p>
											<?php echo wp_kses_post($item['subtitle'], 'daltech_kses_allowed_html'); ?>
										</p>

										<?php if (!empty($item['read_more_text'])) : ?>
											<a href="<?php echo esc_url($item['url']['url']); ?>" class="theme-btn-2 color-style-2 mt-3">
												<?php echo wp_kses_post($item['read_more_text'], 'daltech_kses_allowed_html'); ?><i class="fas fa-chevron-right"></i>
											</a>
										<?php endif; ?>
									</div>
								</div>
							</div>
						<?php
						endforeach;
						?>
					</div>
				</div>
			</section>
			<!--<< Service Section Five End >>-->

		<?php elseif ($settings['style'] == '6') : ?>

			<!--<< Service Section Six Start >>-->
			<section class="service-provide">
				<div class="line-shape">
					<?php
					if (!empty($settings['bg_shape_one']['url'])) :
						echo daltech_img_tag(array(
							'url'   => esc_url($settings['bg_shape_one']['url'])
						));
					endif;
					?>
				</div>
				<div class="container">
					<div class="single-it-service-provide">
						<div class="arrow-shape wow fadeInUp" data-wow-delay=".3s">
							<?php
							if (!empty($settings['bg_shape_two']['url'])) :
								echo daltech_img_tag(array(
									'url'   => esc_url($settings['bg_shape_two']['url'])
								));
							endif;
							?>
						</div>
						<div class="arrow-shape-2 wow fadeInUp" data-wow-delay=".5s">
							<?php
							if (!empty($settings['bg_shape_three']['url'])) :
								echo daltech_img_tag(array(
									'url'   => esc_url($settings['bg_shape_three']['url'])
								));
							endif;
							?>
						</div>
						<div class="service-bg bg-cover" style="background-image: url(<?php echo esc_url($settings['bg_image_one']['url']); ?>);">
							<div class="single-provide-content">
								<div class="section-content">
									<span class="wow fadeInUp sub-cont">
										<?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?>
									</span>
									<h2 class="wow fadeInUp" data-wow-delay=".3s">
										<?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
									</h2>
									<p class="wow fadeInUp" data-wow-delay=".5s">
										<?php echo wp_kses_post($settings['section_summary'], 'daltech_kses_allowed_html'); ?>
									</p>

									<?php if (!empty($settings['button_label'])) : ?>
										<a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn bg-white wow fadeInUp" data-wow-delay=".7s">
											<span><?php echo wp_kses_post($settings['button_label'], 'daltech_kses_allowed_html'); ?></span>
										</a>
									<?php endif; ?>

								</div>
								<?php if (!empty($settings['video_url']['url'])) : ?>
									<div class="video-btn video-pulse">
										<a class="video-popup" href="<?php echo esc_url($settings['video_url']['url']); ?>"><i class="fas fa-play"></i></a>
									</div>
								<?php endif; ?>
							</div>
						</div>
					</div>
				</div>
			</section>
			<!--<< Service Section Six End >>-->

		<?php elseif ($settings['style'] == '7') : ?>

			<!--<< Service Section Seven Start >>-->
			<section class="service-provide-2 bg-5 section-padding pb-0">
				<div class="line-shape-2">
					<?php
					if (!empty($settings['bg_shape_one']['url'])) :
						echo daltech_img_tag(array(
							'url'   => esc_url($settings['bg_shape_one']['url'])
						));
					endif;
					?>
				</div>
				<div class="container">
					<div class="section-title text-center">
						<span class="wow fadeInUp">
							<?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?>
						</span>
						<h2 class="text-white wow fadeInUp" data-wow-delay=".3s">
							<?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
						</h2>
					</div>
					<div class="row">
						<?php
						foreach ($settings['layout_five_service_list'] as $item) :
						?>
							<div class="col-xl-3 col-lg-6 col-md-6 wow fadeInUp" data-wow-delay=".2s">
								<div class="single-service-provide-card">
									<div class="icon">
										<?php
										if (!empty($item['icon_image']['url'])) :
											echo daltech_img_tag(array(
												'url'   => esc_url($item['icon_image']['url'])
											));
										endif;
										?>
									</div>
									<div class="content">
										<h4>
											<a href="<?php echo esc_url($item['url']['url']); ?>">
												<?php echo wp_kses_post($item['title'], 'daltech_kses_allowed_html'); ?>
											</a>
										</h4>
										<p>
											<?php echo wp_kses_post($item['subtitle'], 'daltech_kses_allowed_html'); ?>
										</p>

										<?php if (!empty($item['read_more_text'])) : ?>
											<a href="<?php echo esc_url($item['url']['url']); ?>" class="link-btn text-white">
												<?php echo wp_kses_post($item['read_more_text'], 'daltech_kses_allowed_html'); ?><i class="fas fa-chevron-right"></i>
											</a>
										<?php endif; ?>

									</div>
								</div>
							</div>
						<?php
						endforeach;
						?>
					</div>
				</div>
			</section>
			<!--<< Service Section Seven End >>-->

		<?php elseif ($settings['style'] == '8') : ?>

			<!--<< Service Section Eight Start >>-->
			<section class="service-section fix section-padding">
				<div class="container">
					<div class="section-title text-center">
						<span class="wow fadeInUp">
							<?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?>
						</span>
						<h2 class="wow fadeInUp" data-wow-delay=".3s">
							<?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
						</h2>
					</div>
					<div class="row">
						<?php
						foreach ($settings['layout_two_service_list'] as $item) :
						?>
							<div class="col-xl-3 col-lg-6 col-md-6 wow fadeInUp" data-wow-delay=".3s">
								<div class="service-box-items">
									<div class="icon">
										<i class="flaticon-coding"></i>
									</div>
									<div class="content">
										<h3>
											<a href="<?php echo esc_url($item['url']['url']); ?>">
												<?php echo wp_kses_post($item['title'], 'daltech_kses_allowed_html'); ?>
											</a>
										</h3>
										<p>
											<?php echo wp_kses_post($item['subtitle'], 'daltech_kses_allowed_html'); ?>
										</p>
										<a href="<?php echo esc_url($item['url']['url']); ?>" class="arrow-icon">
											<i class="far fa-arrow-right"></i>
										</a>
									</div>
								</div>
							</div>
						<?php
						endforeach;
						?>
					</div>
				</div>
			</section>
			<!--<< Service Section Eight End >>-->

		<?php elseif ($settings['style'] == '9') : ?>

			<!--<< Service Section Nine End >>-->
			<div class="service-details-video">
				<div class="row g-4 align-items-center">
					<div class="col-lg-6">
						<div class="details-video-content">
							<h3><?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?></h3>
							<p>
								<?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?>
							</p>
							<ul>
								<?php echo wp_kses_post($settings['check_list'], 'daltech_kses_allowed_html'); ?>
							</ul>
						</div>
					</div>
					<div class="col-lg-6">
						<div class="video-image">
							<?php
							if (!empty($settings['bg_image_one']['url'])) :
								echo daltech_img_tag(array(
									'url'   => esc_url($settings['bg_image_one']['url'])
								));
							endif;
							?>
							<?php if (!empty($settings['video_url']['url'])) : ?>
								<div class="video-box">
									<a href="<?php echo esc_url($settings['video_url']['url']); ?>" class="video-btn ripple video-popup">
										<i class="fas fa-play"></i>
									</a>
								</div>
							<?php endif; ?>
						</div>
					</div>
				</div>
			</div>
			<!--<< Service Section Nine End >>-->

<?php
		endif;
	}
}
