<?php

use \Elementor\Controls_Manager;
use \Elementor\Repeater;
use \Elementor\Widget_Base;

/**
 *
 * Banner Widget .
 *
 */
class Daltech_Slider extends Widget_Base
{

	public function get_name()
	{
		return 'daltech_slider';
	}

	public function get_title()
	{
		return __('Slider', 'daltech-core');
	}

	public function get_icon()
	{
		return 'eicon-code';
	}

	public function get_categories()
	{
		return ['daltech'];
	}

	protected function register_controls()
	{

		$this->start_controls_section(
			'slider_section',
			[
				'label' => __('Slider', 'daltech-core'),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'style',
			[
				'label' => __('Style', 'daltech-core'),
				'type' => Controls_Manager::SELECT,
				'default' => '1',
				'options' => [
					'1' => __('Style One', 'daltech-core'),
					'2' => __('Style Two', 'daltech-core'),
					'3' => __('Style Three', 'daltech-core'),
					'4' => __('Style Four', 'daltech-core'),
				],
			]
		);

		$layout_one_sliders = new Repeater();

		$layout_one_sliders->add_control(
			'title',
			[
				'label' => __('Title', 'evona'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 2,
				'placeholder' => __('Awesome Title', 'daltech-core'),
				'default' => __('Default Title', 'daltech-core'),
				'label_block' => true,
			]
		);

		$layout_one_sliders->add_control(
			'subtitle',
			[
				'label' => __('Subtitle', 'daltech-core'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 3,
				'label_block' => true,
				'placeholder' => __('Awesome Subtitle', 'daltech-core'),
				'default' => __('Default Subtitle', 'daltech-core'),
			]
		);

		$layout_one_sliders->add_control(
			'image',
			[
				'label' => __('Image', 'daltech-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$layout_one_sliders->add_control(
			'shape',
			[
				'label' => __('Shape', 'daltech-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$layout_one_sliders->add_control(
			'button_label',
			[
				'label' => __('Button Label', 'daltech-core'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 2,
				'default' => __('Button Label', 'daltech-core'),
			]
		);

		$layout_one_sliders->add_control(
			'url',
			[
				'label' => __('URL', 'daltech-core'),
				'type' => Controls_Manager::URL,
				'placeholder' => __('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);

		$this->add_control(
			'layout_one_sliders',
			[
				'label' => __('Sliders', 'daltech-core'),
				'type' => Controls_Manager::REPEATER,
				'fields' => $layout_one_sliders->get_controls(),
				'title_field' => '{{{ title }}}',
				'prevent_empty' => false,
				'condition' => [
					'style' => '1',
				],
			]
		);

		$this->add_control(
			'layout_two_title',
			[
				'label' => __('Title', 'evona'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 2,
				'placeholder' => __('Awesome Title', 'daltech-core'),
				'default' => __('Default Title', 'daltech-core'),
				'label_block' => true,
				'condition' => [
					'style' => ['2', '4'],
				],
			]
		);

		$this->add_control(
			'layout_two_left_title',
			[
				'label' => __('Left Title', 'evona'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 2,
				'placeholder' => __('Awesome Title', 'daltech-core'),
				'default' => __('Default Title', 'daltech-core'),
				'label_block' => true,
				'condition' => [
					'style' => '2',
				],
			]
		);

		$this->add_control(
			'layout_two_subtitle',
			[
				'label' => __('Subtitle', 'daltech-core'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 3,
				'label_block' => true,
				'placeholder' => __('Awesome Subtitle', 'daltech-core'),
				'default' => __('Default Subtitle', 'daltech-core'),
				'condition' => [
					'style' => ['2', '4'],
				],
			]
		);

		$this->add_control(
			'layout_two_summary',
			[
				'label' => __('Summary', 'daltech-core'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 3,
				'label_block' => true,
				'placeholder' => __('Awesome Summary', 'daltech-core'),
				'default' => __('Default Summary', 'daltech-core'),
				'condition' => [
					'style' => ['2', '4'],
				],
			]
		);

		$this->add_control(
			'layout_two_image',
			[
				'label' => __('Image', 'daltech-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['2', '4'],
				],
			]
		);

		$this->add_control(
			'layout_two_shape_one',
			[
				'label' => __('Shape One', 'daltech-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['2', '4'],
				],
			]
		);

		$this->add_control(
			'layout_two_shape_two',
			[
				'label' => __('Shape Two', 'daltech-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => ['2', '4'],
				],
			]
		);

		$this->add_control(
			'layout_two_shape_three',
			[
				'label' => __('Shape Three', 'daltech-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => '2',
				],
			]
		);

		$this->add_control(
			'layout_two_shape_four',
			[
				'label' => __('Shape Four', 'daltech-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'style' => '2',
				],
			]
		);

		$this->add_control(
			'layout_two_button_label',
			[
				'label' => __('Button Label', 'daltech-core'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 2,
				'default' => __('Button Label', 'daltech-core'),
				'condition' => [
					'style' => ['2', '4'],
				],
			]
		);

		$this->add_control(
			'layout_two_button_url',
			[
				'label' => __('URL', 'daltech-core'),
				'type' => Controls_Manager::URL,
				'placeholder' => __('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => false,
					'nofollow' => false,
				],
				'condition' => [
					'style' => ['2', '4'],
				],
			]
		);

		$this->add_control(
			'layout_two_read_more_label',
			[
				'label' => __('Read More Label', 'daltech-core'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 2,
				'default' => __('Read More Label', 'daltech-core'),
				'condition' => [
					'style' => ['2', '4'],
				],
			]
		);

		$this->add_control(
			'layout_two_read_more_url',
			[
				'label' => __('URL', 'daltech-core'),
				'type' => Controls_Manager::URL,
				'placeholder' => __('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => false,
					'nofollow' => false,
				],
				'condition' => [
					'style' => ['2', '4'],
				],
			]
		);

		$this->add_control(
			'layout_two_title_before_shape',
			[
				'label' => esc_html__('Subtitle After Shape', 'agrofa-addon'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'selectors' => [
					'{{WRAPPER}} .hero-2 .hero-content h1 span::before' => 'background-image:url({{URL}});',
				],
				'condition' => [
					'style' => ['2']
				]
			]
		);

		$layout_three_sliders = new Repeater();

		$layout_three_sliders->add_control(
			'title',
			[
				'label' => __('Title', 'evona'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 2,
				'placeholder' => __('Awesome Title', 'daltech-core'),
				'default' => __('Default Title', 'daltech-core'),
				'label_block' => true,
			]
		);

		$layout_three_sliders->add_control(
			'subtitle',
			[
				'label' => __('Subtitle', 'daltech-core'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 3,
				'label_block' => true,
				'placeholder' => __('Awesome Subtitle', 'daltech-core'),
				'default' => __('Default Subtitle', 'daltech-core'),
			]
		);

		$layout_three_sliders->add_control(
			'title_shape',
			[
				'label' => esc_html__('Title Shape', 'agrofa-addon'),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
				'selectors' => [
					'{{WRAPPER}} .hero-3 .slide-bg .hero-content h4::before' => 'background-image:url({{URL}});',
				]
			]
		);

		$layout_three_sliders->add_control(
			'image',
			[
				'label' => __('Image', 'daltech-core'),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				],
			]
		);

		$layout_three_sliders->add_control(
			'button_label',
			[
				'label' => __('Button Label', 'daltech-core'),
				'type' => Controls_Manager::TEXTAREA,
				'rows' => 2,
				'default' => __('Button Label', 'daltech-core'),
			]
		);

		$layout_three_sliders->add_control(
			'url',
			[
				'label' => __('URL', 'daltech-core'),
				'type' => Controls_Manager::URL,
				'placeholder' => __('https://your-link.com', 'daltech-core'),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => false,
					'nofollow' => false,
				],
			]
		);

		$this->add_control(
			'layout_three_sliders',
			[
				'label' => __('Sliders', 'daltech-core'),
				'type' => Controls_Manager::REPEATER,
				'fields' => $layout_three_sliders->get_controls(),
				'title_field' => '{{{ title }}}',
				'prevent_empty' => false,
				'condition' => [
					'style' => '3',
				],
			]
		);

		$this->end_controls_section();

		// Slider Option
		$this->start_controls_section(
			'slider_settings',
			[
				'label' => __('Carousel Settings', 'daltech-core'),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'slidestoshow',
			[
				'label' => __('Slides To Show', 'daltech-core'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'label_block' => true,
				'default' => '1',
				'options' => [
					'1'  => __('1', 'daltech-core'),
					'2'  => __('2', 'daltech-core'),
					'3'  => __('3', 'daltech-core'),
				],
			]
		);

		$this->add_control(
			'slidestoscroll',
			[
				'label' => __('Slides To Scroll', 'daltech-core'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'label_block' => true,
				'default' => '1',
				'options' => [
					'1'  => __('1', 'daltech-core'),
					'2'  => __('2', 'daltech-core'),
					'3'  => __('3', 'daltech-core'),
					'4'  => __('4', 'daltech-core'),
				],
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label' => __('Auto Play?', 'daltech-core'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('Show', 'daltech-core'),
				'label_off' => __('Hide', 'daltech-core'),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'infinite',
			[
				'label' => __('Infinite Loop', 'daltech-core'),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __('Show', 'daltech-core'),
				'label_off' => __('Hide', 'daltech-core'),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);

		$this->add_control(
			'autoplaytimeout',
			[
				'label' => __('Autoplay Timeout', 'daltech-core'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'label_block' => true,
				'default' => '1000',
				'options' => [
					'1000'  => __('1 Second', 'daltech-core'),
					'2000'  => __('2 Second', 'daltech-core'),
					'3000'  => __('3 Second', 'daltech-core'),
					'4000'  => __('4 Second', 'daltech-core'),
					'5000'  => __('5 Second', 'daltech-core'),
					'6000'  => __('6 Second', 'daltech-core'),
					'7000'  => __('7 Second', 'daltech-core'),
					'8000'  => __('8 Second', 'daltech-core'),
					'9000'  => __('9 Second', 'daltech-core'),
					'10000' => __('10 Second', 'daltech-core'),
					'11000' => __('11 Second', 'daltech-core'),
					'12000' => __('12 Second', 'daltech-core'),
					'13000' => __('13 Second', 'daltech-core'),
					'14000' => __('14 Second', 'daltech-core'),
					'15000' => __('15 Second', 'daltech-core'),
				],
			]
		);

		$this->end_controls_section();

		include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'slider-style.php';
	}

	protected function render()
	{

		$settings = $this->get_settings_for_display();

		$dynamic_id = rand(123, 456);
		$slidestoshow = !empty($settings['slidestoshow']) ? $settings['slidestoshow'] : '2';
		$slidestoscroll = !empty($settings['slidestoscroll']) ? $settings['slidestoscroll'] : '2';
		$infinite = $settings['infinite'] == 'yes' ? 'true' : 'false';
		$autoplay = $settings['autoplay'] == 'yes' ? 'true' : 'false';
		$autoplaytimeout =  !empty($settings['autoplaytimeout']) ? $settings['autoplaytimeout'] : '800';

		if ($settings['style'] == '1') : ?>

			<!--<< Hero Section Start >>-->
			<section class="hero-section hero-1">
				<div class="hero-slider-active">
					<?php foreach ($settings['layout_one_sliders'] as $item) : ?>
						<div class="slide-bg bg-cover wow zoomIn" style="background-image: url(<?php echo esc_url($item['image']['url']); ?>);">
							<div class="container">
								<div class="row g-4 justify-content-between align-items-center">
									<div class="col-lg-8">
										<div class="hero-content">
											<h4 class="fs-lg animated" data-animation-in="fadeInRight" data-delay-in="0.2">
												<?php echo wp_kses($item['subtitle'], 'daltech_allowed_tags'); ?>
											</h4>
											<h1 class="fs-lg animated" data-animation-in="fadeInRight" data-delay-in="0.5">
												<?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?>
											</h1>
											<?php if (!empty($item['button_label'])) : ?>
												<div class="hero-button">
													<a href="<?php echo esc_url($item['url']['url']); ?>" class="theme-btn hover-white fs-lg animated" data-animation-in="fadeInRight" data-delay-in="0.7">
														<span>
															<?php echo wp_kses($item['button_label'], 'daltech_allowed_tags'); ?>
															<i class="fas fa-chevron-right"></i>
														</span>
													</a>
												</div>
											<?php endif; ?>
										</div>
									</div>
									<div class="col-lg-3">
										<div class="frame-shape fs-lg animated" data-animation-in="fadeInRight" data-delay-in="0.5">
											<?php
											if (!empty($item['shape']['url'])) {
												echo daltech_img_tag(array(
													'url'	=> esc_url($item['shape']['url']),
												));
											}
											?>
										</div>
									</div>
								</div>
							</div>
						</div>
					<?php endforeach; ?>
				</div>
				<svg xmlns="http://www.w3.org/2000/svg" style="display: none;">
					<symbol xmlns="http://www.w3.org/2000/svg" viewBox="0 0 44 44" width="44px" height="44px" id="circle" fill="none" stroke="currentColor">
						<circle r="20" cy="22" cx="22" id="translandcircle" />
					</symbol>
				</svg>
			</section>
			<script>
				(function($) {
					"use strict";
					$(document).ready(function() {

						$('.hero-1 .hero-slider-active').slick({
							autoplay: <?php echo $autoplay; ?>,
							speed: <?php echo $autoplaytimeout; ?>,
							lazyLoad: 'progressive',
							arrows: true,
							dots: false,
							prevArrow: '<div class="slick-nav prev-arrow"><i></i><svg><use xlink:href="#circle"></svg></div>',
							nextArrow: '<div class="slick-nav next-arrow"><i></i><svg><use xlink:href="#circle"></svg></div>',
						}).slickAnimation();

					});
				}(jQuery));
			</script>
		<?php elseif ($settings['style'] == '2') : ?>

			<!--<< Hero Section Start Two >>-->
			<section class="hero-section hero-2 fix">
				<div class="text-transparent">
					<h2><?php echo wp_kses($settings['layout_two_left_title'], 'daltech_allowed_tags'); ?></h2>
				</div>
				<div class="container">
					<div class="row g-4 align-items-center">
						<div class="col-lg-8">
							<div class="hero-content">
								<h5 class="wow fadeInUp">
									<?php echo wp_kses($settings['layout_two_subtitle'], 'daltech_allowed_tags'); ?></h5>
								<h1 class="wow fadeInUp" data-wow-delay=".3s">
									<?php echo wp_kses($settings['layout_two_title'], 'daltech_allowed_tags'); ?>
								</h1>
								<p class="wow fadeInUp" data-wow-delay=".5s">
									<?php echo wp_kses($settings['layout_two_summary'], 'daltech_allowed_tags'); ?>
								</p>
								<div class="hero-button">
									<?php if (!empty($settings['layout_two_button_label'])) : ?>
										<a href="<?php echo esc_url($settings['layout_two_button_url']['url']); ?>" class="theme-btn wow fadeInUp" data-wow-delay=".7s">
											<span>
												<?php echo wp_kses($settings['layout_two_button_label'], 'daltech_allowed_tags'); ?>
												<i class="fas fa-chevron-right"></i>
											</span>
										</a>
									<?php endif; ?>
									<?php if (!empty($settings['layout_two_read_more_label'])) : ?>
										<a href="<?php echo esc_url($settings['layout_two_read_more_url']['url']); ?>" class="link-btn wow fadeInUp" data-wow-delay=".9s">
											<span><?php echo wp_kses($settings['layout_two_read_more_label'], 'daltech_allowed_tags'); ?></span>
											<i class="fas fa-chevron-right"></i>
										</a>
									<?php endif; ?>
								</div>
							</div>
						</div>
						<div class="col-lg-4">
							<div class="hero-image">
								<div class="frame-shape">
									<?php
									if (!empty($settings['layout_two_shape_one']['url'])) {
										echo daltech_img_tag(array(
											'url'	=> esc_url($settings['layout_two_shape_one']['url']),
										));
									}
									?>
								</div>
								<div class="frame-shape-2">
									<?php
									if (!empty($settings['layout_two_shape_two']['url'])) {
										echo daltech_img_tag(array(
											'url'	=> esc_url($settings['layout_two_shape_two']['url']),
										));
									}
									?>
								</div>
								<div class="frame-shape-3">
									<?php
									if (!empty($settings['layout_two_shape_three']['url'])) {
										echo daltech_img_tag(array(
											'url'	=> esc_url($settings['layout_two_shape_three']['url']),
										));
									}
									?>
								</div>
								<?php if (!empty($settings['layout_two_image']['url'])) : ?>
									<img src="<?php echo esc_url($settings['layout_two_image']['url']); ?>" alt="hero-img" class="wow fadeInUp" data-wow-delay=".4s">
								<?php endif; ?>
								<div class="circle-shape">
									<?php
									if (!empty($settings['layout_two_shape_four']['url'])) {
										echo daltech_img_tag(array(
											'url'	=> esc_url($settings['layout_two_shape_four']['url']),
										));
									}
									?>
								</div>
							</div>
						</div>
					</div>
				</div>
			</section>
			<!--<< Hero Section End Two >>-->

		<?php elseif ($settings['style'] == '3') : ?>

			<!--<< Hero Section Start >>-->
			<section class="hero-section hero-3">
				<div class="slider-button">
					<div class="hero-nav-prev"><i class="fal fa-long-arrow-left"></i></div>
					<div class="hero-nav-next"><i class="fal fa-long-arrow-right"></i></div>
				</div>
				<div class="hero-slider-active-2">
					<?php foreach ($settings['layout_three_sliders'] as $item) : ?>
						<div class="single-slide">
							<div class="slide-bg bg-cover" style="background-image: url(<?php echo esc_url($item['image']['url']); ?>);">
								<div class="container">
									<div class="hero-content">
										<h4 class="fs-lg animated" data-animation-in="fadeInUp" data-delay-in="0.3">
											<?php echo wp_kses($item['subtitle'], 'daltech_allowed_tags'); ?>
										</h4>
										<h1 class="fs-lg animated" data-animation-in="fadeInUp" data-delay-in="0.5">
											<?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?>
										</h1>

										<?php if (!empty($item['button_label'])) : ?>
											<div class="hero-button fs-lg animated" data-animation-in="fadeInUp" data-delay-in="0.7">
												<a href="<?php echo esc_url($item['url']['url']); ?>" class="theme-btn theme-btn-2 hover-white">
													<span>
														<?php echo wp_kses($item['button_label'], 'daltech_allowed_tags'); ?>
														<i class="fas fa-chevron-right"></i>
													</span>
												</a>
											</div>
										<?php endif; ?>
									</div>
								</div>
							</div>
						</div>
					<?php endforeach; ?>
				</div>
			</section>

			<script>
				(function($) {
					"use strict";
					$(document).ready(function() {
						$('.hero-3 .hero-slider-active-2').slick({
							autoplay: <?php echo $autoplay; ?>,
							speed: <?php echo $autoplaytimeout; ?>,
							lazyLoad: 'progressive',
							arrows: true,
							fade: true,
							dots: false,
							prevArrow: $('.hero-nav-prev'),
							nextArrow: $('.hero-nav-next'),
						}).slickAnimation();

					});
				}(jQuery));
			</script>

		<?php elseif ($settings['style'] == '4') : ?>

			<!--<< Hero Section Start >>-->
			<section class="hero-section hero-4 bg-cover" style="background-image: url(<?php echo esc_url($settings['layout_two_image']['url']); ?>);">
				<div class="circle-shape">
					<?php
					if (!empty($settings['layout_two_shape_one']['url'])) {
						echo daltech_img_tag(array(
							'url'	=> esc_url($settings['layout_two_shape_one']['url']),
						));
					}
					?>
				</div>
				<div class="container">
					<div class="row align-items-center">
						<div class="col-xl-6 col-lg-6">
							<div class="hero-content">
								<h6 class="head-title wow fadeInUp">
									<?php echo wp_kses($settings['layout_two_subtitle'], 'daltech_allowed_tags'); ?>
								</h6>
								<h1 class="wow fadeInUp" data-wow-delay=".3s">
									<?php echo wp_kses($settings['layout_two_title'], 'daltech_allowed_tags'); ?>
								</h1>
								<h6 class="wow fadeInUp" data-wow-delay=".5s">
									<?php echo wp_kses($settings['layout_two_summary'], 'daltech_allowed_tags'); ?>
								</h6>
								<div class="hero-button wow fadeInUp" data-wow-delay=".7s">

									<?php if (!empty($settings['layout_two_button_label'])) : ?>
										<a href="<?php echo esc_url($settings['layout_two_button_url']['url']); ?>" class="theme-btn hover-white">
											<span><?php echo wp_kses($settings['layout_two_button_label'], 'daltech_allowed_tags'); ?></span>
										</a>
									<?php endif; ?>

									<?php if (!empty($settings['layout_two_read_more_label'])) : ?>
										<a href="<?php echo esc_url($settings['layout_two_read_more_url']['url']); ?>" class="theme-btn-2">
											<?php echo wp_kses($settings['layout_two_read_more_label'], 'daltech_allowed_tags'); ?> <i class="fas fa-chevron-right ps-2"></i>
										</a>
									<?php endif; ?>
								</div>
							</div>
						</div>
						<div class="col-xl-6 col-lg-6 mt-5 mt-lg-0 wow fadeInRight" data-wow-delay=".4s">
							<div class="hero-image">
								<?php
								if (!empty($settings['layout_two_shape_two']['url'])) {
									echo daltech_img_tag(array(
										'url'	=> esc_url($settings['layout_two_shape_two']['url']),
									));
								}
								?>
							</div>
						</div>
					</div>
				</div>
			</section>
			<!--<< Hero Section End Four >>-->


<?php
		endif;
	}
}
