<?php

/**
 * Elementor daltech Team Details Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Team_Skill extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Team Details widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_team_skill';
    }

    /**
     * Get widget title.
     *
     * Retrieve Team Details Nav Tab widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Team Skill', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Team Details Nav Tab widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Team Details Nav Tab widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'team_skill_content_style',
            [
                'label'        => esc_html__('Team Skill Style', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'section_title',
            [
                'label'         => esc_html__('Section Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('Section Title', 'daltech-core'),
                'default'         => esc_html__('Default Section Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $progress_bar_list = new \Elementor\Repeater();

        $progress_bar_list->add_control(
            'title',
            [
                'label'         => esc_html__('Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('title', 'daltech-core'),
                'default'         => esc_html__('Default Title', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $progress_bar_list->add_control(
            'number',
            [
                'label'         => esc_html__('Number', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'placeholder'     => esc_html__('Number', 'daltech-core'),
                'default'         => esc_html__('Default Number', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $this->add_control(
            'progress_bar_list',
            [
                'label'     => esc_html__('Service', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $progress_bar_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Service', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        //icon

        $this->add_control(
            'form_icon_style',
            [
                'label'     => esc_html__('Form Icon Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Flaticon', 'daltech-core'),
                    '3'     => esc_html__('Icon Image', 'daltech-core'),
                    '2'      => esc_html__('Custom Icon', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'flat_icon',
            [
                'label'      => esc_html__('Icon One', 'cleanu-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
                'condition' => [
                    'form_icon_style' => '1'
                ]
            ]
        );

        $this->add_control(
            'custom_icon',
            [
                'label'         => esc_html__('Custom Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'rows'          => '2',
                'condition' => [
                    'form_icon_style' => '2'
                ]
            ]
        );


        $this->add_control(
            'icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'form_icon_style' => '3'
                ]
            ]
        );


        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'team-skill-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') :
?>

            <!-- Team Skill Section Start -->
            <section class="team-skill fix section-padding">
                <div class="container">
                    <div class="team-skill-wrapper">
                        <div class="row justify-content-between align-items-center">
                            <div class="col-lg-6 wow fadeInUp" data-wow-delay=".3s">
                                <div class="team-skill-content">
                                    <h3>
                                        <?php echo wp_kses($settings['section_title'], 'daltech_allowed_tags'); ?>
                                    </h3>
                                </div>
                            </div>
                            <div class="col-lg-5 mt-4 mt-lg-0 wow fadeInUp" data-wow-delay=".5s">
                                <div class="progress-wrap">
                                    <?php
                                    foreach ($settings['progress_bar_list'] as $item) : ?>
                                        <div class="pro-items">
                                            <div class="pro-head">
                                                <h6 class="title">
                                                    <?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?>
                                                </h6>
                                                <span class="point">
                                                    <?php echo wp_kses($item['number'], 'daltech_allowed_tags'); ?>
                                                </span>
                                            </div>
                                            <div class="progress">
                                                <div class="progress-value"></div>
                                            </div>
                                        </div>
                                    <?php
                                    endforeach;
                                    ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </section>

            <!-- End  Team Details Style One -->


<?php
        endif;
    }
}
