<?php

/**
 * Elementor daltech teams Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Team extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve teams widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_team';
    }

    /**
     * Get widget title.
     *
     * Retrieve teams Nav Tab widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Team Member', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve teams Nav Tab widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the teams Nav Tab widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'daltech_team_style',
            [
                'label'        => esc_html__('Team Style', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                    '2'      => esc_html__('Style Two', 'daltech-core'),
                    '3'      => esc_html__('Style Three', 'daltech-core'),
                    '4'      => esc_html__('Style Four', 'daltech-core'),
                    '5'      => esc_html__('Style Five', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'sec_title',
            [
                'label'         => esc_html__('Section Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('title', 'daltech-core'),
                'default'         => esc_html__('Default Title', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['1', '2', '3', '4', '5']],
            ]
        );

        $this->add_control(
            'sec_subtitle',
            [
                'label'         => esc_html__('Section Subtitle', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('subtitle', 'daltech-core'),
                'default'         => esc_html__('Default SubTitle', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['1', '2', '3', '4', '5']],
            ]
        );

        $this->add_control(
            'sec_summary',
            [
                'label'         => esc_html__('Section Summary', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('subtitle', 'daltech-core'),
                'default'         => esc_html__('Default SubTitle', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['4']],
            ]
        );

        $layout_one_team_list = new \Elementor\Repeater();

        $layout_one_team_list->add_control(
            'name',
            [
                'label'         => esc_html__('Name', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('name', 'daltech-core'),
                'default'         => esc_html__('Default Name', 'daltech-core'),
                'rows' =>     '2',
            ]
        );
        $layout_one_team_list->add_control(
            'designation',
            [
                'label'         => esc_html__('Designation', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('designation', 'daltech-core'),
                'default'         => esc_html__('Default Designation', 'daltech-core'),
                'label_block'     => true,
                'rows' =>     '2',
            ]
        );

        $layout_one_team_list->add_control(
            'image',
            [
                'label'            => esc_html__('Add Image', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $layout_one_team_list->add_control(
            'url',
            [
                'label'         => esc_html__('URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => esc_html__('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => true,
                    'nofollow'         => true,
                ],
            ]
        );

        $layout_one_team_list->add_control(
            'social_network',
            [
                'label' => __('Social NetWork', 'insur-addon'),
                'type' => \Elementor\Controls_Manager::CODE,
                'label_block' => true,
                'default' => wp_kses('<li class="facebook"> <a class="facebook" href="#"> <i class="fab fa-facebook-f"></i> </a> </li>', 'daltech_kses_allowed_html')
            ]
        );

        $this->add_control(
            'layout_one_team_list',
            [
                'label'     => esc_html__('Team List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_one_team_list->get_controls(),
                'prevent_empty' => 'false',
                'title_field' => '{{{ name }}}',
                'condition'        => ['style'    =>    ['1', '2', '3', '4', '5']],
            ]
        );

        $this->add_control(
            'shape_one',
            [
                'label'            => esc_html__('Shape One', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition'        => ['style'    =>    ['1', '3']],
            ]
        );

        $this->add_control(
            'shape_two',
            [
                'label'            => esc_html__('Shape Two', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition'        => ['style'    =>    ['1']],
            ]
        );

        $this->add_control(
            'shape_title',
            [
                'label'         => esc_html__('Shape Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('Shape Title', 'daltech-core'),
                'default'         => esc_html__('Default Shape Title', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['1']],
            ]
        );

        $this->add_control(
            'shape_subtitle',
            [
                'label'         => esc_html__('Shape Sub Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('Shape Sub Title', 'daltech-core'),
                'default'         => esc_html__('Default Shape Sub Title', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['1']],
            ]
        );

        $this->add_control(
            'bottom_text',
            [
                'label'         => esc_html__('Bottom Text', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('Bottom Text', 'daltech-core'),
                'default'         => esc_html__('Default Bottom Text', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['4']],
            ]
        );

        $this->add_control(
            'button_label',
            [
                'label'     => __('Button Label', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::TEXTAREA,
                'rows'         => 2,
                'default'      => __('Button Label', 'daltech-core'),
                'condition' => [
                    'style' => ['2', '3', '4']
                ]
            ]
        );

        $this->add_control(
            'url',
            [
                'label'         => __('URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => __('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => false,
                    'nofollow'         => false,
                ],
                'condition' => [
                    'style' => ['2', '3', '4']
                ]
            ]
        );


        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'team-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') :
?>

            <!--<< Team Section Start >>-->
            <section class="team-section section-padding">
                <div class="container">
                    <div class="section-title text-center">
                        <span class="wow fadeInUp">
                            <?php echo wp_kses_post($settings['sec_subtitle'], 'daltech_kses_allowed_html'); ?>
                        </span>
                        <h2 class="wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses_post($settings['sec_title'], 'daltech_kses_allowed_html'); ?>
                        </h2>
                    </div>
                    <div class="team-wrapper">
                        <div class="row align-items-center">
                            <?php
                            $counter = 1;
                            foreach ($settings['layout_one_team_list'] as $item) : ?>

                                <div class="col-xl-3 col-lg-4 col-md-6 wow fadeInUp" data-wow-delay=".3s">
                                    <div class="single-team-items">
                                        <div class="team-image">
                                            <?php
                                            if (!empty($item['image']['url'])) :
                                                echo daltech_img_tag(array(
                                                    'url'   => esc_url($item['image']['url'])
                                                ));
                                            endif;
                                            ?>
                                            <?php if (!empty($item['social_network'])) : ?>
                                                <div class="social-profile">
                                                    <span class="plus-btn"><i class="fas fa-share-alt"></i></span>
                                                    <ul>
                                                        <?php echo wp_kses_post($item['social_network'], 'daltech_kses_allowed_html'); ?>
                                                    </ul>
                                                </div>
                                            <?php
                                            endif;
                                            ?>
                                        </div>
                                        <div class="team-content text-center">
                                            <h4>
                                                <a href="<?php echo esc_url($item['url']['url']); ?>"><?php echo wp_kses_post($item['name'], 'daltech_kses_allowed_html'); ?></a>
                                            </h4>
                                            <p><?php echo wp_kses_post($item['designation'], 'daltech_kses_allowed_html'); ?></p>
                                        </div>
                                    </div>
                                </div>
                            <?php
                                $counter++;
                                if ($counter == '5') {
                                    break;
                                }
                            endforeach; ?>
                            <?php if (!empty($settings['shape_one']['url'] || $settings['shape_two']['url'] || $settings['shape_title'])) : ?>
                                <div class="col-xl-5 col-lg-7 col-md-6 wow fadeInUp" data-wow-delay=".3s">
                                    <div class="single-team-items">
                                        <div class="team-join-content text-center">
                                            <div class="circle-shape">
                                                <?php
                                                if (!empty($settings['shape_one']['url'])) {
                                                    echo daltech_img_tag(array(
                                                        'url'    => esc_url($settings['shape_one']['url']),
                                                    ));
                                                }
                                                ?>
                                            </div>
                                            <div class="dot-shape">
                                                <?php
                                                if (!empty($settings['shape_two']['url'])) {
                                                    echo daltech_img_tag(array(
                                                        'url'    => esc_url($settings['shape_two']['url']),
                                                    ));
                                                }
                                                ?>
                                            </div>
                                            <h2> <?php echo wp_kses_post($settings['shape_title'], 'daltech_kses_allowed_html'); ?></h2>
                                            <h3> <?php echo wp_kses_post($settings['shape_subtitle'], 'daltech_kses_allowed_html'); ?>
                                            </h3>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-xl-1"></div>
                            <?php endif; ?>
                            <?php
                            $counter = 1;
                            foreach ($settings['layout_one_team_list'] as $item) :
                                if ($counter >= '5') :
                            ?>
                                    <div class="col-xl-3 col-lg-4 col-md-6 wow fadeInUp" data-wow-delay=".3s">
                                        <div class="single-team-items">
                                            <div class="team-image">
                                                <?php
                                                if (!empty($item['image']['url'])) :
                                                    echo daltech_img_tag(array(
                                                        'url'   => esc_url($item['image']['url'])
                                                    ));
                                                endif;
                                                ?>
                                                <?php if (!empty($item['social_network'])) : ?>
                                                    <div class="social-profile">
                                                        <span class="plus-btn"><i class="fas fa-share-alt"></i></span>
                                                        <ul>
                                                            <?php echo wp_kses_post($item['social_network'], 'daltech_kses_allowed_html'); ?>
                                                        </ul>
                                                    </div>
                                                <?php
                                                endif;
                                                ?>
                                            </div>
                                            <div class="team-content text-center">
                                                <h4>
                                                    <a href="<?php echo esc_url($item['url']['url']); ?>"><?php echo wp_kses_post($item['name'], 'daltech_kses_allowed_html'); ?></a>
                                                </h4>
                                                <p><?php echo wp_kses_post($item['designation'], 'daltech_kses_allowed_html'); ?></p>
                                            </div>
                                        </div>
                                    </div>
                            <?php
                                endif;
                                $counter++;
                            endforeach;
                            ?>

                        </div>
                    </div>
                </div>
            </section>

        <?php elseif ($settings['style'] == '2') : ?>

            <!--<< Team Section Start >>-->
            <section class="team-section section-padding section-bg-3">
                <div class="container">
                    <div class="section-title text-center">
                        <span class="wow fadeInUp">
                            <?php echo wp_kses_post($settings['sec_subtitle'], 'daltech_kses_allowed_html'); ?>
                        </span>
                        <h2 class="text-white wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses_post($settings['sec_title'], 'daltech_kses_allowed_html'); ?>
                        </h2>
                    </div>
                    <div class="row align-items-center">
                        <?php
                        foreach ($settings['layout_one_team_list'] as $item) :
                        ?>
                            <div class="col-xl-3 col-lg-4 col-md-6 wow fadeInUp" data-wow-delay=".3s">
                                <div class="single-team-items style-2">
                                    <div class="team-image">
                                        <?php
                                        if (!empty($item['image']['url'])) :
                                            echo daltech_img_tag(array(
                                                'url'   => esc_url($item['image']['url'])
                                            ));
                                        endif;
                                        ?>
                                        <?php if (!empty($item['social_network'])) : ?>
                                            <div class="social-profile">
                                                <span class="plus-btn"><i class="fas fa-share-alt"></i></span>
                                                <ul>
                                                    <?php echo wp_kses_post($item['social_network'], 'daltech_kses_allowed_html'); ?>
                                                </ul>
                                            </div>
                                        <?php
                                        endif;
                                        ?>
                                    </div>
                                    <div class="team-content text-center">
                                        <h5>
                                            <a href="<?php echo esc_url($item['url']['url']); ?>"><?php echo wp_kses_post($item['name'], 'daltech_kses_allowed_html'); ?></a>
                                        </h5>
                                        <p><?php echo wp_kses_post($item['designation'], 'daltech_kses_allowed_html'); ?></p>
                                    </div>
                                </div>
                            </div>
                        <?php
                        endforeach;
                        ?>
                    </div>
                    <?php if (!empty($settings['button_label'])) : ?>
                        <div class="team-button wow fadeInUp" data-wow-delay=".4s">
                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn mt-5 hover-white">
                                <span>
                                    <?php echo wp_kses_post($settings['button_label'], 'daltech_kses_allowed_html'); ?>
                                    <i class="fas fa-chevron-right"></i>
                                </span>
                            </a>
                        </div>
                    <?php
                    endif;
                    ?>
                </div>
            </section>

        <?php elseif ($settings['style'] == '3') : ?>

            <!--<< Team Section Start Three >>-->
            <section class="team-section section-padding pt-0 section-bg-3">
                <div class="dot-shape-2">
                    <?php
                    if (!empty($settings['shape_one']['url'])) :
                        echo daltech_img_tag(array(
                            'url'   => esc_url($settings['shape_one']['url'])
                        ));
                    endif;
                    ?>
                </div>
                <div class="container">
                    <div class="section-title style-2 text-center">
                        <span class="wow fadeInUp">
                            <?php echo wp_kses_post($settings['sec_subtitle'], 'daltech_kses_allowed_html'); ?>
                        </span>
                        <h2 class="text-white wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses_post($settings['sec_title'], 'daltech_kses_allowed_html'); ?>
                        </h2>
                    </div>
                    <div class="row">
                        <?php
                        foreach ($settings['layout_one_team_list'] as $item) :
                        ?>
                            <div class="col-xl-3 col-lg-4 col-md-6 wow fadeInUp" data-wow-delay=".3s">
                                <div class="team-card-items">
                                    <div class="team-content">
                                        <h4>
                                            <a href="<?php echo esc_url($item['url']['url']); ?>"><?php echo wp_kses_post($item['name'], 'daltech_kses_allowed_html'); ?></a>
                                        </h4>
                                        <p><?php echo wp_kses_post($item['designation'], 'daltech_kses_allowed_html'); ?></p>
                                    </div>
                                    <div class="team-image">
                                        <?php
                                        if (!empty($item['image']['url'])) :
                                            echo daltech_img_tag(array(
                                                'url'   => esc_url($item['image']['url'])
                                            ));
                                        endif;
                                        ?>
                                        <?php if (!empty($item['social_network'])) : ?>
                                            <div class="social-profile">
                                                <span class="plus-btn"><i class="fas fa-share-alt"></i></span>
                                                <ul>
                                                    <?php echo wp_kses_post($item['social_network'], 'daltech_kses_allowed_html'); ?>
                                                </ul>
                                            </div>
                                        <?php
                                        endif;
                                        ?>
                                    </div>
                                </div>
                            </div>
                        <?php
                        endforeach;
                        ?>
                    </div>
                    <?php if (!empty($settings['button_label'])) : ?>
                        <div class="team-button text-center mt-5 wow fadeInUp" data-wow-delay=".4s">
                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn theme-btn-2 hover-white">
                                <span>
                                    <?php echo wp_kses_post($settings['button_label'], 'daltech_kses_allowed_html'); ?>
                                    <i class="fas fa-chevron-right"></i>
                                </span>
                            </a>
                        </div>
                    <?php
                    endif;
                    ?>
                </div>
            </section>
            <!--<< Team Section Start Three >>-->

        <?php elseif ($settings['style'] == '4') : ?>

            <!--<< Team Section Start FOur >>-->
            <section class="team-section-2 fix section-padding pt-0">
                <div class="container">
                    <div class="row g-4 justify-content-between align-items-center">
                        <div class="col-xl-6 col-lg-4 col-md-6 wow fadeInUp" data-wow-delay=".2s">
                            <div class="single-team-style-1 it-single-team-style mt-0">
                                <div class="section-title">
                                    <span class="wow fadeInUp">
                                        <?php echo wp_kses_post($settings['sec_subtitle'], 'daltech_kses_allowed_html'); ?>
                                    </span>
                                    <h2 class="wow fadeInUp" data-wow-delay=".3s">
                                        <?php echo wp_kses_post($settings['sec_title'], 'daltech_kses_allowed_html'); ?>
                                    </h2>
                                    <p class="mt-3 mt-md-0 wow fadeInUp" data-wow-delay=".5s">
                                        <?php echo wp_kses_post($settings['sec_summary'], 'daltech_kses_allowed_html'); ?>
                                    </p>
                                </div>
                            </div>
                        </div>

                        <?php
                        foreach ($settings['layout_one_team_list'] as $item) :
                        ?>
                            <div class="col-xl-3 col-lg-4 col-md-6 wow fadeInUp" data-wow-delay=".3s">
                                <div class="single-team-style-1">
                                    <div class="team-image ralt">
                                        <?php
                                        if (!empty($item['image']['url'])) :
                                            echo daltech_img_tag(array(
                                                'url'   => esc_url($item['image']['url'])
                                            ));
                                        endif;
                                        ?>
                                        <?php if (!empty($item['social_network'])) : ?>
                                            <div class="icon-list">
                                                <ul>
                                                    <?php echo wp_kses_post($item['social_network'], 'daltech_kses_allowed_html'); ?>
                                                </ul>
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                    <div class="team-content center">
                                        <h3>
                                            <a href="<?php echo esc_url($item['url']['url']); ?>"><?php echo wp_kses_post($item['name'], 'daltech_kses_allowed_html'); ?></a>
                                        </h3>
                                        <p>
                                            <?php echo wp_kses_post($item['designation'], 'daltech_kses_allowed_html'); ?>
                                        </p>
                                    </div>
                                </div>
                            </div>
                        <?php
                        endforeach;
                        ?>
                        <?php if (!empty($settings['button_label'] || $settings['bottom_text'])) : ?>
                            <div class="col-xl-3 col-lg-4 col-md-6 wow fadeInUp" data-wow-delay=".8s">
                                <div class="it-team-content center">
                                    <p class="mt-0">
                                        <?php echo wp_kses_post($settings['bottom_text'], 'daltech_kses_allowed_html'); ?>
                                    </p>
                                    <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn mt-4">
                                        <span>
                                            <?php echo wp_kses_post($settings['button_label'], 'daltech_kses_allowed_html'); ?></span>
                                    </a>
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </section>
            <!--<< Team Section Start FOur >>-->

        <?php elseif ($settings['style'] == '5') : ?>

            <!--<< Team Section Start Five >>-->
            <section class="team-section section-padding section-bg-3">
                <div class="container">
                    <div class="section-title text-center">
                        <span class="wow fadeInUp">
                            <?php echo wp_kses_post($settings['sec_subtitle'], 'daltech_kses_allowed_html'); ?>
                        </span>
                        <h2 class="text-white wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses_post($settings['sec_title'], 'daltech_kses_allowed_html'); ?>
                        </h2>
                    </div>
                    <div class="row align-items-center">
                        <?php
                        foreach ($settings['layout_one_team_list'] as $item) :
                        ?>
                            <div class="col-xl-3 col-lg-4 col-md-6 wow fadeInUp" data-wow-delay=".3s">
                                <div class="single-team-items style-2">
                                    <div class="team-image">
                                        <?php
                                        if (!empty($item['image']['url'])) :
                                            echo daltech_img_tag(array(
                                                'url'   => esc_url($item['image']['url'])
                                            ));
                                        endif;
                                        ?>
                                        <?php if (!empty($item['social_network'])) : ?>
                                            <div class="social-profile">
                                                <span class="plus-btn"><i class="fas fa-share-alt"></i></span>
                                                <ul>
                                                    <?php echo wp_kses_post($item['social_network'], 'daltech_kses_allowed_html'); ?>
                                                </ul>
                                            </div>
                                        <?php
                                        endif;
                                        ?>
                                    </div>
                                    <div class="team-content text-center">
                                        <h5>
                                            <a href="<?php echo esc_url($item['url']['url']); ?>"><?php echo wp_kses_post($item['name'], 'daltech_kses_allowed_html'); ?></a>
                                        </h5>
                                        <p> <?php echo wp_kses_post($item['designation'], 'daltech_kses_allowed_html'); ?></p>
                                    </div>
                                </div>
                            </div>
                        <?php
                        endforeach;
                        ?>
                    </div>
                </div>
            </section>
            <!--<< Team Section Start Five >>-->
<?php
        endif;
    }
}
