<?php

/**
 * Elementor Testimonial Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Testimonial extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Testimonial widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_testimonial_content';
    }

    /**
     * Get widget title.
     *
     * Retrieve Testimonial widget title.
     *
     * @since 1.0.0
     * @access public 
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Testimonial', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Testimonial widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Testimonial widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    public function get_script_depends()
    {
        return array('main');
    }

    // Add The Input For User
    protected function register_controls()
    {


        $this->start_controls_section(
            'testimonial_content',
            [
                'label'        => esc_html__('Set Testimonial Content', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                    '2'      => esc_html__('Style Two', 'daltech-core'),
                    '3'      => esc_html__('Style Three', 'daltech-core'),
                    '4'      => esc_html__('Style Four', 'daltech-core'),
                    '5'      => esc_html__('Style Five', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'sec_title',
            [
                'label'         => esc_html__('Section Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('title', 'daltech-core'),
                'default'         => esc_html__('Default Title', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['1', '2', '4']],
            ]
        );
        $this->add_control(
            'sec_subtitle',
            [
                'label'         => esc_html__('Section Subtitle', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('subtitle', 'daltech-core'),
                'default'         => esc_html__('Default SubTitle', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['1', '2', '4']],
            ]
        );

        $layout_one_testimonial_list = new \Elementor\Repeater();

        $layout_one_testimonial_list->add_control(
            'name',
            [
                'label'         => esc_html__('Name', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 1,
                'placeholder' => __('Name', 'daltech-core'),
                'default' => __('Default Name', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_one_testimonial_list->add_control(
            'designation',
            [
                'label'         => esc_html__('Designation', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'rows' => 1,
                'placeholder' => __('Designation', 'daltech-core'),
                'default' => __('Designation', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_one_testimonial_list->add_control(
            'summary',
            [
                'label'         => esc_html__('Summary', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 4,
                'placeholder' => __('Summary', 'daltech-core'),
                'default' => __('Summary', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_one_testimonial_list->add_control(
            'date',
            [
                'label'         => esc_html__('Date', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'rows' => 4,
                'placeholder' => __('Date', 'daltech-core'),
                'default' => __('Date', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_one_testimonial_list->add_control(
            'image',
            [
                'label'     => esc_html__('Image', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'layout_one_testimonial_list',
            [
                'label'     => esc_html__('Testimonial List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_one_testimonial_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Testimonial', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ name }}}',
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $layout_two_testimonial_list = new \Elementor\Repeater();

        $layout_two_testimonial_list->add_control(
            'name',
            [
                'label'         => esc_html__('Name', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 1,
                'placeholder' => __('Name', 'daltech-core'),
                'default' => __('Default Name', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_two_testimonial_list->add_control(
            'designation',
            [
                'label'         => esc_html__('Designation', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'rows' => 1,
                'placeholder' => __('Designation', 'daltech-core'),
                'default' => __('Designation', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_two_testimonial_list->add_control(
            'summary',
            [
                'label'         => esc_html__('Summary', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 4,
                'placeholder' => __('Summary', 'daltech-core'),
                'default' => __('Summary', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_two_testimonial_list->add_control(
            'rating',
            [
                'label' => __('Rating', 'ploming-addon'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['count'],
                'range' => [
                    'count' => [
                        'min' => 1,
                        'max' => 5,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'count',
                    'size' => 5,
                ],
            ]
        );

        $layout_two_testimonial_list->add_control(
            'image',
            [
                'label'     => esc_html__('Image', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'layout_two_testimonial_list',
            [
                'label'     => esc_html__('Testimonial List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_two_testimonial_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Testimonial', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ name }}}',
                'condition' => [
                    'style' => ['2', '3', '5']
                ]
            ]
        );

        $layout_four_testimonial_list = new \Elementor\Repeater();

        $layout_four_testimonial_list->add_control(
            'title',
            [
                'label'         => esc_html__('Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 1,
                'placeholder' => __('Title', 'daltech-core'),
                'default' => __('Default Title', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_four_testimonial_list->add_control(
            'name',
            [
                'label'         => esc_html__('Name', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 1,
                'placeholder' => __('Name', 'daltech-core'),
                'default' => __('Default Name', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_four_testimonial_list->add_control(
            'designation',
            [
                'label'         => esc_html__('Designation', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'rows' => 1,
                'placeholder' => __('Designation', 'daltech-core'),
                'default' => __('Designation', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_four_testimonial_list->add_control(
            'summary',
            [
                'label'         => esc_html__('Summary', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 4,
                'placeholder' => __('Summary', 'daltech-core'),
                'default' => __('Summary', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_four_testimonial_list->add_control(
            'rating',
            [
                'label' => __('Rating', 'ploming-addon'),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => ['count'],
                'range' => [
                    'count' => [
                        'min' => 1,
                        'max' => 5,
                        'step' => 1,
                    ],
                ],
                'default' => [
                    'unit' => 'count',
                    'size' => 5,
                ],
            ]
        );

        $layout_four_testimonial_list->add_control(
            'image',
            [
                'label'     => esc_html__('Image', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $layout_four_testimonial_list->add_control(
            'shape',
            [
                'label'     => esc_html__('Shape', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'layout_four_testimonial_list',
            [
                'label'     => esc_html__('Testimonial List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_four_testimonial_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Testimonial', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ name }}}',
                'condition' => [
                    'style' => ['4']
                ]
            ]
        );

        $this->add_control(
            'shape_one',
            [
                'label'     => esc_html__('Shape One', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => ['4', '5']
                ]
            ]
        );

        $this->add_control(
            'shape_two',
            [
                'label'     => esc_html__('Shape Two', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => ['4', '5']
                ]
            ]
        );

        $this->end_controls_section();

        // Slider Option
        $this->start_controls_section(
            'slider_settings',
            [
                'label' => __('Carousel Settings', 'modina-core'),
                'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'slidestoshow',
            [
                'label' => __('Slides To Show', 'modina-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => true,
                'default' => '3',
                'options' => [
                    '1'  => __('1', 'modina-core'),
                    '2'  => __('2', 'modina-core'),
                    '3'  => __('3', 'modina-core'),
                ],
            ]
        );

        $this->add_control(
            'slidestoscroll',
            [
                'label' => __('Slides To Scroll', 'modina-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => true,
                'default' => '1',
                'options' => [
                    '1'  => __('1', 'modina-core'),
                    '2'  => __('2', 'modina-core'),
                    '3'  => __('3', 'modina-core'),
                    '4'  => __('4', 'modina-core'),
                ],
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label' => __('Auto Play?', 'modina-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'modina-core'),
                'label_off' => __('Hide', 'modina-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'infinite',
            [
                'label' => __('Infinite Loop', 'modina-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Show', 'modina-core'),
                'label_off' => __('Hide', 'modina-core'),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'autoplaytimeout',
            [
                'label' => __('Autoplay Timeout', 'modina-core'),
                'type' => \Elementor\Controls_Manager::SELECT,
                'label_block' => true,
                'default' => '1000',
                'options' => [
                    '1000'  => __('1 Second', 'modina-core'),
                    '2000'  => __('2 Second', 'modina-core'),
                    '3000'  => __('3 Second', 'modina-core'),
                    '4000'  => __('4 Second', 'modina-core'),
                    '5000'  => __('5 Second', 'modina-core'),
                    '6000'  => __('6 Second', 'modina-core'),
                    '7000'  => __('7 Second', 'modina-core'),
                    '8000'  => __('8 Second', 'modina-core'),
                    '9000'  => __('9 Second', 'modina-core'),
                    '10000' => __('10 Second', 'modina-core'),
                    '11000' => __('11 Second', 'modina-core'),
                    '12000' => __('12 Second', 'modina-core'),
                    '13000' => __('13 Second', 'modina-core'),
                    '14000' => __('14 Second', 'modina-core'),
                    '15000' => __('15 Second', 'modina-core'),
                ],
            ]
        );

        $this->end_controls_section();


        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'testimonial-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $dynamic_id = rand(123, 456);

        $slidestoshow = !empty($settings['slidestoshow']) ? $settings['slidestoshow'] : '2';
        $slidestoscroll = !empty($settings['slidestoscroll']) ? $settings['slidestoscroll'] : '2';
        $infinite = $settings['infinite'] == 'yes' ? 'true' : 'false';
        $autoplay = $settings['autoplay'] == 'yes' ? 'true' : 'false';
        $autoplaytimeout =  !empty($settings['autoplaytimeout']) ? $settings['autoplaytimeout'] : '800';

        if ($settings['style'] == '1') : ?>

            <!-- Start Our Testimonials One -->
            <section class="testimonial-section section-padding">
                <div class="container">
                    <div class="section-title text-center">
                        <span class="wow fadeInUp"><?php echo wp_kses($settings['sec_subtitle'], 'daltech_allowed_tags'); ?></span>
                        <h2 class="wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses($settings['sec_title'], 'daltech_allowed_tags'); ?>
                        </h2>
                    </div>
                    <div class="testimonial-carousel-active">
                        <?php
                        foreach ($settings['layout_one_testimonial_list'] as $item) :
                        ?>
                            <div class="testimonial-card-items">
                                <div class="author-items">
                                    <div class="author-image bg-cover" style="background-image: url(<?php echo esc_url($item['image']['url']); ?>);">
                                    </div>
                                    <div class="author-content">
                                        <h5><?php echo wp_kses($item['name'], 'daltech_allowed_tags'); ?></h5>
                                        <span> <?php echo wp_kses($item['designation'], 'daltech_allowed_tags'); ?></span>
                                    </div>
                                </div>
                                <p>
                                    <?php echo wp_kses($item['summary'], 'daltech_allowed_tags'); ?>
                                </p>
                                <ul>
                                    <li><?php echo wp_kses($item['date'], 'daltech_allowed_tags'); ?></li>
                                </ul>
                            </div>
                        <?php
                        endforeach;
                        ?>
                    </div>
                </div>
            </section>
            <!-- End Our Testimonials One -->

            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.testimonial-carousel-active').length > 0) {
                            $('.testimonial-carousel-active').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                speed: 500,
                                arrows: false,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                dots: true,
                                dotsClass: 'slide-dots',
                                responsive: [{
                                        breakpoint: 1399,
                                        settings: {
                                            slidesToShow: 3,
                                        }
                                    },
                                    {
                                        breakpoint: 1191,
                                        settings: {
                                            slidesToShow: 2,
                                        }
                                    },
                                    {
                                        breakpoint: 768,
                                        settings: {
                                            slidesToShow: 1,
                                            center: true,
                                        }
                                    },
                                    {
                                        breakpoint: 480,
                                        settings: {
                                            slidesToShow: 1
                                        }
                                    }
                                ],

                            });
                        }

                    });
                }(jQuery));
            </script>

        <?php elseif ($settings['style'] == '2') : ?>

            <!--<< Testimonial Section Two Start >>-->
            <section class="testimonial-section-2 section-bg-2 fix section-padding">
                <div class="container">
                    <div class="section-title text-center">
                        <span class="wow fadeInUp"><?php echo wp_kses($settings['sec_subtitle'], 'daltech_allowed_tags'); ?></span>
                        <h2 class="wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses($settings['sec_title'], 'daltech_allowed_tags'); ?>
                        </h2>
                    </div>
                </div>
                <div class="testimonial-wrapper">
                    <div class="testimonial-carousel-active-2">
                        <?php
                        foreach ($settings['layout_two_testimonial_list'] as $item) :
                        ?>
                            <div class="testimonial-card-items-2">
                                <div class="testimonial-image bg-cover" style="background-image: url(<?php echo esc_url($item['image']['url']); ?>);">
                                </div>
                                <div class="testimonial-content">
                                    <div class="star">
                                        <?php for ($i = 0; $i < $item['rating']['size']; $i++) : ?>
                                            <span class="fas fa-star"></span>
                                        <?php endfor; ?>
                                    </div>
                                    <p>
                                        <?php echo wp_kses($item['summary'], 'daltech_allowed_tags'); ?>
                                    </p>
                                    <div class="author-name">
                                        <h6><?php echo wp_kses($item['name'], 'daltech_allowed_tags'); ?></h6>
                                        <p><?php echo wp_kses($item['designation'], 'daltech_allowed_tags'); ?></p>
                                    </div>
                                </div>
                            </div>
                        <?php
                        endforeach;
                        ?>
                    </div>
                </div>
            </section>
            <!--<< Testimonial Section Two End >>-->

            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.testimonial-carousel-active-2').length > 0) {
                            $('.testimonial-carousel-active-2').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                speed: 500,
                                arrows: false,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                dots: true,
                                dotsClass: 'slide-dots',
                                responsive: [{
                                        breakpoint: 1399,
                                        settings: {
                                            slidesToShow: 3,
                                        }
                                    },
                                    {
                                        breakpoint: 1191,
                                        settings: {
                                            slidesToShow: 2,
                                        }
                                    },
                                    {
                                        breakpoint: 768,
                                        settings: {
                                            slidesToShow: 1,
                                            center: true,
                                        }
                                    },
                                    {
                                        breakpoint: 480,
                                        settings: {
                                            slidesToShow: 1
                                        }
                                    }
                                ],

                            });
                        }

                    });
                }(jQuery));
            </script>

        <?php elseif ($settings['style'] == '3') : ?>

            <!--<< Testimonial Section Three Start >>-->
            <section class="testimonial-section-3 fix section-padding pt-0">
                <div class="container-fluid">
                    <div class="testimonial-wrapper-3">
                        <div class="testimonial-carousel-active-3">
                            <?php
                            foreach ($settings['layout_two_testimonial_list'] as $item) :
                            ?>
                                <div class="testimonial-items">
                                    <div class="testimonial-image-area">
                                        <div class="testimonial-image bg-cover" style="background-image: url(<?php echo esc_url($item['image']['url']); ?>);">
                                            <div class="icon">
                                                <i class="flaticon-double-quotes"></i>
                                            </div>
                                        </div>
                                        <div class="star">
                                            <?php for ($i = 0; $i < $item['rating']['size']; $i++) : ?>
                                                <span class="fas fa-star"></span>
                                            <?php endfor; ?>
                                        </div>
                                    </div>
                                    <div class="testimonial-content">
                                        <h3>
                                            <?php echo wp_kses($item['summary'], 'daltech_allowed_tags'); ?>
                                        </h3>
                                        <div class="athor-name">
                                            <h4><?php echo wp_kses($item['name'], 'daltech_allowed_tags'); ?></h4>
                                            <p><?php echo wp_kses($item['designation'], 'daltech_allowed_tags'); ?></p>
                                        </div>
                                    </div>
                                </div>
                            <?php
                            endforeach;
                            ?>
                        </div>
                        <div class="slider-button">
                            <div class="testimonial-nav-prev"><i class="fas fa-long-arrow-left"></i></div>
                            <div class="testimonial-nav-next"><i class="fas fa-long-arrow-right"></i></div>
                        </div>
                    </div>
                </div>
            </section>
            <!--<< Testimonial Section Three End >>-->

            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.testimonial-carousel-active-3').length > 0) {
                            $('.testimonial-carousel-active-3').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                speed: 500,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                arrows: true,
                                dots: false,
                                prevArrow: $('.testimonial-nav-prev'),
                                nextArrow: $('.testimonial-nav-next'),
                            });
                        }

                    });
                }(jQuery));
            </script>

        <?php elseif ($settings['style'] == '4') : ?>

            <!--<< Testimonial Section Four End >>-->
            <section class="testimonial-section-5 section-padding pt-0">
                <div class="shape float-bob-y">
                    <?php
                    if (!empty($settings['shape_one']['url'])) :
                        echo daltech_img_tag(array(
                            'url'   => esc_url($settings['shape_one']['url'])
                        ));
                    endif;
                    ?>
                </div>
                <div class="bg-shape">
                    <?php
                    if (!empty($settings['shape_two']['url'])) :
                        echo daltech_img_tag(array(
                            'url'   => esc_url($settings['shape_two']['url'])
                        ));
                    endif;
                    ?>
                </div>
                <div class="container">
                    <div class="section-title text-center">
                        <span class="wow fadeInUp">
                            <?php echo wp_kses($settings['sec_subtitle'], 'daltech_allowed_tags'); ?>
                        </span>
                        <h2 class="wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses($settings['sec_title'], 'daltech_allowed_tags'); ?>
                        </h2>
                    </div>
                    <div class="single-testimonial-style-2 mt-5 mt-md-0">
                        <div class="testimonial-carousel-active-4">
                            <?php
                            foreach ($settings['layout_four_testimonial_list'] as $item) :
                            ?>
                                <div class="single-testimonial-items-2">
                                    <div class="ratting-items">
                                        <div class="quote-icon">
                                            <?php
                                            if (!empty($item['shape']['url'])) :
                                                echo daltech_img_tag(array(
                                                    'url'   => esc_url($item['shape']['url'])
                                                ));
                                            endif;
                                            ?>
                                        </div>
                                        <div class="client-ratting">
                                            <h5> <?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?></h5>
                                            <ul>
                                                <?php for ($i = 0; $i < $item['rating']['size']; $i++) : ?>
                                                    <li><i class="fas fa-star"></i></li>
                                                <?php endfor; ?>
                                            </ul>
                                        </div>
                                    </div>
                                    <p class="text">
                                        <?php echo wp_kses($item['summary'], 'daltech_allowed_tags'); ?>
                                    </p>
                                    <div class="client-info">
                                        <div class="image">
                                            <?php
                                            if (!empty($item['image']['url'])) :
                                                echo daltech_img_tag(array(
                                                    'url'   => esc_url($item['image']['url'])
                                                ));
                                            endif;
                                            ?>
                                        </div>
                                        <div class="content">
                                            <h3>
                                                <?php echo wp_kses($item['name'], 'daltech_allowed_tags'); ?>
                                            </h3>
                                            <p>
                                                <?php echo wp_kses($item['designation'], 'daltech_allowed_tags'); ?>
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            <?php
                            endforeach;
                            ?>
                        </div>
                    </div>
                </div>
            </section>
            <!--<< Testimonial Section Four End >>-->

            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.testimonial-carousel-active-4').length > 0) {
                            $('.testimonial-carousel-active-4').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                speed: 800,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                arrows: true,
                                dots: false,
                                prevArrow: $('.testimonial-nav-prev'),
                                nextArrow: $('.testimonial-nav-next'),
                            });
                        }

                    });
                }(jQuery));
            </script>

        <?php elseif ($settings['style'] == '5') : ?>

            <!--<< Testimonial Section Five End >>-->
            <section class="testimonial-section-4 fix section-padding">
                <div class="client-1">
                    <?php
                    if (!empty($settings['shape_one']['url'])) :
                        echo daltech_img_tag(array(
                            'url'   => esc_url($settings['shape_one']['url'])
                        ));
                    endif;
                    ?>
                </div>
                <div class="client-2">
                    <?php
                    if (!empty($settings['shape_two']['url'])) :
                        echo daltech_img_tag(array(
                            'url'   => esc_url($settings['shape_two']['url'])
                        ));
                    endif;
                    ?>
                </div>
                <div class="container">
                    <div class="testimonial-carousel-active-4">
                        <?php
                        foreach ($settings['layout_two_testimonial_list'] as $item) :
                        ?>
                            <div class="testimonial-wrapper-4">
                                <div class="row justify-content-center">
                                    <div class="col-lg-11">
                                        <div class="testimonial-items">
                                            <div class="testimonial-image bg-cover" style="background-image: url(<?php echo esc_url($item['image']['url']); ?>);"></div>
                                            <div class="client-info">
                                                <h5>
                                                    <?php echo wp_kses($item['name'], 'daltech_allowed_tags'); ?>
                                                </h5>
                                                <h6>
                                                    <?php echo wp_kses($item['designation'], 'daltech_allowed_tags'); ?>
                                                </h6>
                                            </div>
                                            <div class="testimonial-content">
                                                <h3>
                                                    <?php echo wp_kses($item['summary'], 'daltech_allowed_tags'); ?>
                                                </h3>
                                                <div class="star">
                                                    <?php for ($i = 0; $i < $item['rating']['size']; $i++) : ?>
                                                        <span class="fas fa-star"></span>
                                                    <?php endfor; ?>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php
                        endforeach;
                        ?>
                    </div>
                </div>
                <div class="slider-button">
                    <div class="testimonial-nav-prev"><i class="fas fa-chevron-left"></i></div>
                    <div class="testimonial-nav-next"><i class="fas fa-chevron-right"></i></div>
                </div>
            </section>
            <!--<< Testimonial Section Five End >>-->

            <script>
                (function($) {
                    "use strict";
                    $(document).ready(function() {
                        if ($('.testimonial-carousel-active-4').length > 0) {
                            $('.testimonial-carousel-active-4').slick({
                                autoplay: <?php echo $autoplay; ?>,
                                autoplaySpeed: <?php echo $autoplaytimeout; ?>,
                                speed: 800,
                                slidesToShow: <?php echo $slidestoshow; ?>,
                                slidesToScroll: <?php echo $slidestoscroll; ?>,
                                arrows: true,
                                dots: false,
                                prevArrow: $('.testimonial-nav-prev'),
                                nextArrow: $('.testimonial-nav-next'),
                            });
                        }

                    });
                }(jQuery));
            </script>
<?php
        endif;
    }
}
