<?php

/**
 * Elementor Text Slider Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Text_Slider extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Text Slider widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_text_slider';
    }

    /**
     * Get widget title.
     *
     * Retrieve Text Slider widget title.
     *
     * @since 1.0.0
     * @access public 
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Text Slider', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Text Slider widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Text Slider widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    public function get_script_depends()
    {
        return array('main');
    }

    // Add The Input For User
    protected function register_controls()
    {


        $this->start_controls_section(
            'Text Slider_content',
            [
                'label'        => esc_html__('Set Text Slider Content', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                    '2'      => esc_html__('Style Two', 'daltech-core'),
                    '3'      => esc_html__('Style Three', 'daltech-core'),
                    '4'      => esc_html__('Style Four', 'daltech-core'),
                ],
            ]
        );

        $layout_one_text_slider_list = new \Elementor\Repeater();

        $layout_one_text_slider_list->add_control(
            'title',
            [
                'label'         => esc_html__('Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 5,
                'placeholder' => __('Title', 'daltech-core'),
                'default' => __('Default Title', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'layout_one_text_slider_list',
            [
                'label'     => esc_html__('Text Slider List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_one_text_slider_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Text Slider', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ title }}}',
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $layout_two_text_slider_list = new \Elementor\Repeater();

        $layout_two_text_slider_list->add_control(
            'title',
            [
                'label'         => esc_html__('Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 5,
                'placeholder' => __('Title', 'daltech-core'),
                'default' => __('Default Title', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $layout_two_text_slider_list->add_control(
            'image',
            [
                'label'            => esc_html__('Add Image', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'layout_two_text_slider_list',
            [
                'label'     => esc_html__('Text Slider List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_two_text_slider_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Text Slider', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ title }}}',
                'condition' => [
                    'style' => ['2', '3', '4']
                ]
            ]
        );

        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'text-slider-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') : ?>

            <!--<< Case Studies Start >>-->
            <div class="marque-section section-padding pt-0">
                <div class="marquee-wrapper text-slider">
                    <div class="marquee-inner to-left">
                        <ul class="marqee-list d-flex">
                            <li class="marquee-item">
                                <?php
                                foreach ($settings['layout_one_text_slider_list'] as $item) :
                                ?>
                                    <?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?>
                                <?php
                                endforeach;
                                ?>
                            </li>
                        </ul>
                    </div>
                </div>
            </div>
            <!-- End Our Text Sliders One -->

        <?php elseif ($settings['style'] == '2') : ?>

            <!-- End Our Text Sliders Two -->
            <div class="marque-section section-padding section-bg-2 pt-0">
                <div class="container-fluid">
                    <div class="marquee-wrapper text-slider style-height">
                        <div class="marquee-inner to-left">
                            <ul class="marqee-list d-flex">
                                <li class="marquee-item style-2">
                                    <?php
                                    foreach ($settings['layout_two_text_slider_list'] as $item) :
                                    ?>
                                        <span class="text-slider">
                                            <?php
                                            if (!empty($item['image']['url'])) {
                                                echo daltech_img_tag(array(
                                                    'url'    => esc_url($item['image']['url']),
                                                ));
                                            }
                                            ?>
                                        </span>
                                        <span class="text-slider text-style"><?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?></span>
                                    <?php
                                    endforeach;
                                    ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End Our Text Sliders Two -->

        <?php elseif ($settings['style'] == '3') : ?>

            <!-- Start Our Text Sliders Three -->
            <div class="marque-section-2">
                <div class="container-fluid">
                    <div class="marquee-wrapper text-slider style-height-2">
                        <div class="marquee-inner to-left">
                            <ul class="marqee-list d-flex">
                                <li class="marquee-item style-3">
                                    <?php
                                    foreach ($settings['layout_two_text_slider_list'] as $item) :
                                    ?>
                                        <span class="text-slider">
                                            <?php
                                            if (!empty($item['image']['url'])) {
                                                echo daltech_img_tag(array(
                                                    'url'    => esc_url($item['image']['url']),
                                                ));
                                            }
                                            ?>
                                        </span>
                                        <span class="text-slider">
                                            <?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?>
                                        </span>
                                    <?php
                                    endforeach;
                                    ?>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End Our Text Sliders Three -->

        <?php elseif ($settings['style'] == '4') : ?>

            <!-- Start Our Text Sliders Four -->
            <div class="marque-section section-padding">
                <div class="marquee-wrapper text-slider style-height">
                    <div class="marquee-inner to-left">
                        <ul class="marqee-list d-flex">
                            <?php
                            foreach ($settings['layout_two_text_slider_list'] as $item) :
                            ?>
                                <li class="marquee-item style-2">
                                    <span class="text-slider">
                                        <?php
                                        if (!empty($item['image']['url'])) {
                                            echo daltech_img_tag(array(
                                                'url'    => esc_url($item['image']['url']),
                                            ));
                                        }
                                        ?>
                                    </span>
                                    <span class="text-slider text-style-2">
                                        <?php echo wp_kses($item['title'], 'daltech_allowed_tags'); ?></span>
                                </li>
                            <?php
                            endforeach;
                            ?>
                        </ul>
                    </div>
                </div>
            </div>
            <!-- End Our Text Sliders Four -->
<?php
        endif;
    }
}
