<?php

/**
 * Elementor counter Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Topbar extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve counter widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_topabr';
    }

    /**
     * Get widget title.
     *
     * Retrieve counter widget title.
     *
     * @since 1.0.0
     * @access public 
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('TopBar', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve counter widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the counter widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    public function get_script_depends()
    {
        return array('main');
    }

    // Add The Input For User
    protected function register_controls()
    {


        $this->start_controls_section(
            'counter_content',
            [
                'label'        => esc_html__('Set counter Content', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                    '2'      => esc_html__('Style Two', 'daltech-core'),
                    '3'      => esc_html__('Style Three', 'daltech-core'),
                ],
            ]
        );

        $contact_info_list = new \Elementor\Repeater();

        $contact_info_list->add_control(
            'info',
            [
                'label'         => esc_html__('Info', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 3,
                'placeholder' => __('Info', 'daltech-core'),
                'default' => __('Default Info', 'daltech-core'),
                'label_block' => true,
            ]
        );

        $contact_info_list->add_control(
            'icon_style',
            [
                'label'     => esc_html__('Icon Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Flaticon', 'daltech-core'),
                    '3'     => esc_html__('Icon Image', 'daltech-core'),
                    '2'      => esc_html__('Custom Icon', 'daltech-core'),
                ],
            ]
        );

        $contact_info_list->add_control(
            'flat_icon',
            [
                'label'      => esc_html__('Icon One', 'cleanu-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
                'condition' => [
                    'icon_style' => '1'
                ]
            ]
        );

        $contact_info_list->add_control(
            'custom_icon',
            [
                'label'         => esc_html__('Custom Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'rows'          => '2',
                'condition' => [
                    'icon_style' => '2'
                ]
            ]
        );


        $contact_info_list->add_control(
            'icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'icon_style' => '3'
                ]
            ]
        );

        $this->add_control(
            'contact_info_list',
            [
                'label'     => esc_html__('Contact Info List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $contact_info_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Contact Info', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ info }}}',
                'condition' => [
                    'style' => ['1', '2', '3', '4']
                ]
            ]
        );

        $this->add_control(
            'g_trnalate_sc',
            [
                'label'         => esc_html__('Tranlator Shortcode', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows' => 1,
                'placeholder' => __('Tranlator Shortcod', 'daltech-core'),
                'default' => __('Tranlator Shortcod', 'daltech-core'),
                'label_block' => true,
                'condition' => [
                    'style' => ['2', '3']
                ]
            ]
        );

        $this->add_control(
            'contact_info_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );


        $social = new \Elementor\Repeater();

        $social->add_control(
            'icon_style',
            [
                'label'     => esc_html__('Icon Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Flaticon', 'daltech-core'),
                    '3'     => esc_html__('Icon Image', 'daltech-core'),
                    '2'      => esc_html__('Custom Icon', 'daltech-core'),
                ],
            ]
        );

        $social->add_control(
            'flat_icon',
            [
                'label'      => esc_html__('Icon One', 'cleanu-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
                'default'    => 'flaticon-budget',
                'condition' => [
                    'icon_style' => '1'
                ]
            ]
        );

        $social->add_control(
            'custom_icon',
            [
                'label'         => esc_html__('Custom Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXT,
                'label_block'     => true,
                'condition' => [
                    'icon_style' => '2'
                ]
            ]
        );


        $social->add_control(
            'icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'icon_style' => '3'
                ]
            ]
        );

        $social->add_control(
            'url',
            [
                'label' => __('Add Url', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __('#', 'daltech-core'),
                'show_external' => false,
                'default' => [
                    'url' => '#',
                    'is_external' => false,
                    'nofollow' => false,
                ],
                'show_label' => false,
            ]
        );

        $this->add_control(
            'social_list',
            [
                'label' => __('Social List', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $social->get_controls(),
                'prevent_empty' => false,
                'default' => [
                    [
                        'social_url' => [
                            'url' => '#',
                            'is_external' => false,
                            'nofollow' => false,
                        ],
                    ],
                ],
                'condition' => [
                    'style' => ['1', '2', '3', '4']
                ]

            ]
        );

        $this->add_control(
            'social_hr',
            [
                'type' => \Elementor\Controls_Manager::DIVIDER,
            ]
        );

        $nav_menus = new \Elementor\Repeater();

        $nav_menus->add_control(
            'nav_menu',
            [
                'label' => __('Select Nav Menu', 'ogency-addon'),
                'type' => \Elementor\Controls_Manager::SELECT2,
                'options' => daltech_get_nav_menu(),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'nav_menus',
            [
                'label' => __('Topbar Nav Menus', 'ogency-addon'),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'prevent_empty' => false,
                'fields' => $nav_menus->get_controls(),
                'condition' => [
                    'style' => ['1', '2']
                ]
            ]
        );



        $this->end_controls_section();

        include DALTECH_PLUGIN_WIDGET_STYLE_PATH . 'topbar-style.php';
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') : ?>

            <!-- Start Our Topbar One -->
            <div class="header-top-section fix">
                <div class="container">
                    <div class="header-top-wrapper">
                        <ul class="contact-list">
                            <?php
                            $counter = 1;
                            foreach ($settings['contact_info_list'] as $item) :
                            ?>
                                <li>
                                    <?php if (!empty($item['flat_icon'])) : ?>
                                        <i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
                                    <?php endif; ?>
                                    <?php if (!empty($item['icon_image']['url']['0'])) : ?>
                                        <img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                    <?php endif; ?>
                                    <?php
                                    if (!empty($item['custom_icon'])) : ?>
                                        <i class="<?php echo esc_attr($item['custom_icon']); ?>"></i><?php endif; ?>
                                    <?php echo wp_kses($item['info'], 'daltech_allowed_tags'); ?>
                                </li>
                            <?php $counter++;
                            endforeach; ?>
                        </ul>
                        <div class="top-right">
                            <div class="social-icon d-flex align-items-center">
                                <?php
                                foreach ($settings['social_list'] as $single_item) :
                                ?>

                                    <a href="<?php echo esc_url($single_item['url']['url']); ?>">
                                        <?php if (!empty($single_item['flat_icon'])) : ?>
                                            <i class="<?php echo esc_attr($single_item['flat_icon']); ?>"></i>
                                        <?php endif; ?>
                                        <?php if (!empty($single_item['icon_image']['url'])) : ?>
                                            <img src="<?php echo esc_url($single_item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                        <?php endif; ?>
                                        <?php
                                        if (!empty($single_item['custom_icon'])) : ?>
                                            <i class="<?php echo esc_attr($single_item['custom_icon']); ?>"></i>
                                        <?php endif; ?>
                                    </a>

                                <?php endforeach; ?>
                            </div>
                            <?php foreach ($settings['nav_menus'] as $nav_menu) : ?>
                                <?php wp_nav_menu(array(
                                    'menu' => $nav_menu['nav_menu'],
                                    'container'  => '',
                                    'menu_class' => 'header-menu'
                                )); ?>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End Our Topbar One -->

        <?php elseif ($settings['style'] == '2') : ?>

            <!-- Start Our Topbar Two -->
            <div class="header-top-section-2">
                <div class="container">
                    <div class="header-top-wrapper style-2">
                        <div class="top-left">
                            <ul class="contact-list">
                                <?php
                                $counter = 1;
                                foreach ($settings['contact_info_list'] as $item) :
                                ?>
                                    <li>
                                        <?php if (!empty($item['flat_icon'])) : ?>
                                            <i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
                                        <?php endif; ?>
                                        <?php if (!empty($item['icon_image']['url']['0'])) : ?>
                                            <img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                        <?php endif; ?>
                                        <?php
                                        if (!empty($item['custom_icon'])) : ?>
                                            <i class="<?php echo esc_attr($item['custom_icon']); ?>"></i><?php endif; ?>
                                        <?php echo wp_kses($item['info'], 'daltech_allowed_tags'); ?>
                                    </li>
                                <?php $counter++;
                                endforeach; ?>
                            </ul>
                            <div class="flag-wrap">
                                <?php echo do_shortcode($settings['g_trnalate_sc']); ?>
                            </div>
                        </div>
                        <div class="top-right">
                            <?php foreach ($settings['nav_menus'] as $nav_menu) : ?>
                                <?php wp_nav_menu(array(
                                    'menu' => $nav_menu['nav_menu'],
                                    'container'  => '',
                                    'menu_class' => 'header-menu'
                                )); ?>
                            <?php endforeach; ?>
                            <div class="social-icon d-flex align-items-center">
                                <?php
                                foreach ($settings['social_list'] as $single_item) :
                                ?>

                                    <a href="<?php echo esc_url($single_item['url']['url']); ?>">
                                        <?php if (!empty($single_item['flat_icon'])) : ?>
                                            <i class="<?php echo esc_attr($single_item['flat_icon']); ?>"></i>
                                        <?php endif; ?>
                                        <?php if (!empty($single_item['icon_image']['url'])) : ?>
                                            <img src="<?php echo esc_url($single_item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                        <?php endif; ?>
                                        <?php
                                        if (!empty($single_item['custom_icon'])) : ?>
                                            <i class="<?php echo esc_attr($single_item['custom_icon']); ?>"></i>
                                        <?php endif; ?>
                                    </a>

                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End Our Topbar Two -->

        <?php elseif ($settings['style'] == '3') : ?>

            <!-- End Our Topbar Three  -->
            <div class="header-top-section-3">
                <div class="container-fluid">
                    <div class="header-top-wrapper style-2 style-3">
                        <div class="top-left">
                            <ul class="contact-list">
                                <?php
                                foreach ($settings['contact_info_list'] as $item) :
                                ?>
                                    <li>
                                        <?php if (!empty($item['flat_icon'])) : ?>
                                            <i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
                                        <?php endif; ?>
                                        <?php if (!empty($item['icon_image']['url']['0'])) : ?>
                                            <img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                        <?php endif; ?>
                                        <?php
                                        if (!empty($item['custom_icon'])) : ?>
                                            <i class="<?php echo esc_attr($item['custom_icon']); ?>"></i><?php endif; ?>
                                        <?php echo wp_kses($item['info'], 'daltech_allowed_tags'); ?>
                                    </li>
                                <?php
                                endforeach; ?>
                            </ul>
                        </div>
                        <div class="top-right">

                            <div class="flag-wrap">
                                <?php echo do_shortcode($settings['g_trnalate_sc']); ?>
                            </div>
                            <div class="social-icon d-flex align-items-center">
                                <?php
                                foreach ($settings['social_list'] as $single_item) :
                                ?>

                                    <a href="<?php echo esc_url($single_item['url']['url']); ?>">
                                        <?php if (!empty($single_item['flat_icon'])) : ?>
                                            <i class="<?php echo esc_attr($single_item['flat_icon']); ?>"></i>
                                        <?php endif; ?>
                                        <?php if (!empty($single_item['icon_image']['url'])) : ?>
                                            <img src="<?php echo esc_url($single_item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                        <?php endif; ?>
                                        <?php
                                        if (!empty($single_item['custom_icon'])) : ?>
                                            <i class="<?php echo esc_attr($single_item['custom_icon']); ?>"></i>
                                        <?php endif; ?>
                                    </a>

                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End Our Topbar Three -->

<?php
        endif;
    }
}
