<?php

/**
 * Elementor daltech Trusted Client Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Trusted_Client extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Trusted Client widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_trusted_client';
    }

    /**
     * Get widget title.
     *
     * Retrieve Trusted Client Nav Tab widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Trusted Client', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Trusted Client Nav Tab widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Trusted Client Nav Tab widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'daltech_trusted_client_style',
            [
                'label'        => esc_html__('Trusted Client Style', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Trusted Client Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                ],
            ]
        );


        $this->add_control(
            'section_title',
            [
                'label'         => esc_html__('Section Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section title', 'daltech-core'),
                'default'         => esc_html__('Default Section Title', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'section_subtitle',
            [
                'label'         => esc_html__('Section Subtitle', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section subtitle', 'daltech-core'),
                'default'         => esc_html__('Default Section SubTitle', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'section_summary',
            [
                'label'         => esc_html__('Section Summary', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('section Summary', 'daltech-core'),
                'default'         => esc_html__('Default Section Summary', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $layout_one_trusted_client_list = new \Elementor\Repeater();

        $layout_one_trusted_client_list->add_control(
            'title',
            [
                'label'         => esc_html__('Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('title', 'daltech-core'),
                'default'         => esc_html__('Default Title', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_trusted_client_list->add_control(
            'check_list',
            [
                'label'         => esc_html__('Check List', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '4',
                'placeholder'     => esc_html__('Check List', 'daltech-core'),
                'default'         => esc_html__('Check List', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_trusted_client_list->add_control(
            'feature_title_one',
            [
                'label'         => esc_html__('Feature Title One', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('Feature Title One', 'daltech-core'),
                'default'         => esc_html__('Feature Title One', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_trusted_client_list->add_control(
            'flat_icon_one',
            [
                'label'      => esc_html__('Icon One', 'daltech-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
            ]
        );

        $layout_one_trusted_client_list->add_control(
            'feature_title_two',
            [
                'label'         => esc_html__('Feature Title Two', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('Feature Title Two', 'daltech-core'),
                'default'         => esc_html__('Feature Title Two', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_trusted_client_list->add_control(
            'flat_icon_two',
            [
                'label'      => esc_html__('Icon Two', 'daltech-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
            ]
        );

        $layout_one_trusted_client_list->add_control(
            'progress_title',
            [
                'label'         => esc_html__('Progress Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('Progress Title', 'daltech-core'),
                'default'         => esc_html__('Default Progress Title', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_trusted_client_list->add_control(
            'progress_number',
            [
                'label'         => esc_html__('Progress Number', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '1',
                'placeholder'     => esc_html__('Number', 'daltech-core'),
                'default'         => esc_html__('55', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $layout_one_trusted_client_list->add_control(
            'active_status',
            [
                'label' => __('Is active?', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __('Yes', 'ploming-addon'),
                'label_off' => __('No', 'ploming-addon'),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'layout_one_trusted_client_list',
            [
                'label'     => esc_html__('Trusted Client', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_one_trusted_client_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Trusted Client', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'bg_image',
            [
                'label' => esc_html__('Background Image', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'circle_image',
            [
                'label' => esc_html__('Circle Image', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'icon_image',
            [
                'label' => esc_html__('Icon Image', 'daltech-core'),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $counter_list = new \Elementor\Repeater();

        $counter_list->add_control(
            'title',
            [
                'label'         => esc_html__('Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('title', 'daltech-core'),
                'default'         => esc_html__('Default Title', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $counter_list->add_control(
            'number',
            [
                'label'         => esc_html__('Number', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'rows'             => '2',
                'placeholder'     => esc_html__('number', 'daltech-core'),
                'default'         => esc_html__('50', 'daltech-core'),
                'label_block'     => true,
            ]
        );

        $this->add_control(
            'counter_list',
            [
                'label'     => esc_html__('Counter List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $counter_list->get_controls(),
                'default'     => [
                    [
                        'list_title' => esc_html__('Add Counter List', 'daltech-core'),
                    ],
                ],
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false,
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->end_controls_section();
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') :
?>
            <!--<< Trusted Client Section Start >>-->
            <section class="trusted-client-section fix section-padding pt-0">
                <div class="container">
                    <div class="trusted-client-wrapper">
                        <div class="row align-items-center">
                            <div class="col-xl-5">
                                <div class="trusted-client-image bg-cover" style="background-image: url(<?php echo esc_url($settings['bg_image']['url']); ?>);">
                                    <div class="icon-box">
                                        <?php
                                        if (!empty($settings['circle_image']['url'])) :
                                            echo daltech_img_tag(array(
                                                'url'   => esc_url($settings['circle_image']['url'])
                                            ));
                                        endif;
                                        ?>
                                        <div class="icon">
                                            <?php
                                            if (!empty($settings['icon_image']['url'])) :
                                                echo daltech_img_tag(array(
                                                    'url'   => esc_url($settings['icon_image']['url'])
                                                ));
                                            endif;
                                            ?>
                                        </div>
                                    </div>
                                    <div class="counter-main-area">
                                        <div class="counter-area">
                                            <?php
                                            $counter = 1;
                                            foreach ($settings['counter_list'] as $item) :
                                            ?>
                                                <div class="counter-items">
                                                    <h2><span class="count">
                                                            <?php echo wp_kses_post($item['number'], 'daltech_kses_allowed_html'); ?>
                                                    </h2>
                                                    <h3><?php echo wp_kses_post($item['title'], 'daltech_kses_allowed_html'); ?></h3>
                                                </div>
                                            <?php
                                                $counter++;
                                            endforeach;
                                            ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <div class="col-xl-7 mt-5 mt-xl-0">
                                <div class="trusted-content">
                                    <div class="section-title">
                                        <span class="wow fadeInUp">
                                            <?php echo wp_kses_post($settings['section_subtitle'], 'daltech_kses_allowed_html'); ?></span>
                                        <h2 class="wow fadeInUp" data-wow-delay=".3s">
                                            <?php echo wp_kses_post($settings['section_title'], 'daltech_kses_allowed_html'); ?>
                                        </h2>
                                    </div>
                                    <p class="mt-4 mt-md-0 wow fadeInUp" data-wow-delay=".5s">
                                        <?php echo wp_kses_post($settings['section_summary'], 'daltech_kses_allowed_html'); ?>
                                    </p>
                                    <div class="single-tab-items">
                                        <ul class="nav mb-4" role="tablist">
                                            <?php
                                            $counter = 1;
                                            foreach ($settings['layout_one_trusted_client_list'] as $item) :
                                            ?>
                                                <li class="nav-item wow fadeInUp" role="presentation">
                                                    <a href="#item<?php echo esc_attr($counter); ?>" data-bs-toggle="tab" class="nav-link <?php echo esc_attr(('yes' == $item['active_status'] ? 'active' : '')); ?>" aria-selected="true" role="tab" tabindex="-1">
                                                        <?php echo wp_kses_post($item['title'], 'daltech_kses_allowed_html'); ?>
                                                    </a>
                                                </li>
                                            <?php
                                                $counter++;
                                            endforeach;
                                            ?>
                                        </ul>
                                        <div class="tab-content">
                                            <?php
                                            $counter = 1;
                                            foreach ($settings['layout_one_trusted_client_list'] as $item) :
                                            ?>
                                                <div id="item<?php echo esc_attr($counter); ?>" class="tab-pane fade <?php echo esc_attr(('yes' == $item['active_status'] ? 'show active' : '')); ?>" role="tabpanel">
                                                    <div class="tab-content-items">
                                                        <ul class="wow fadeInUp">
                                                            <?php echo wp_kses_post($item['check_list'], 'daltech_kses_allowed_html'); ?>
                                                        </ul>
                                                        <div class="icon-area">
                                                            <div class="icon-items d-flex align-items-center gap-3 wow fadeInUp">
                                                                <div class="icon">
                                                                    <?php if (!empty($item['flat_icon_one'])) : ?>
                                                                        <i class="<?php echo esc_attr($item['flat_icon_one']); ?>"></i>
                                                                    <?php endif; ?>
                                                                </div>
                                                                <h6>
                                                                    <?php echo wp_kses_post($item['feature_title_one'], 'daltech_kses_allowed_html'); ?>
                                                                </h6>
                                                            </div>
                                                            <div class="icon-items d-flex align-items-center gap-3 wow fadeInUp" data-wow-delay=".7s">
                                                                <div class="icon">
                                                                    <?php if (!empty($item['flat_icon_two'])) : ?>
                                                                        <i class="<?php echo esc_attr($item['flat_icon_two']); ?>"></i>
                                                                    <?php endif; ?>
                                                                </div>
                                                                <h6> <?php echo wp_kses_post($item['feature_title_two'], 'daltech_kses_allowed_html'); ?>
                                                                </h6>
                                                            </div>
                                                        </div>
                                                        <div class="pro-items wow fadeInUp" data-wow-delay=".9s">
                                                            <div class="pro-head">
                                                                <h6 class="title">
                                                                    <?php echo wp_kses_post($item['progress_title'], 'daltech_kses_allowed_html'); ?>
                                                                </h6>
                                                                <span class="point">
                                                                    <?php echo wp_kses_post($item['progress_number'], 'daltech_kses_allowed_html'); ?>
                                                                </span>
                                                            </div>
                                                            <div class="progress">
                                                                <div class="progress-value"></div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                </div>
                                            <?php
                                                $counter++;
                                            endforeach;
                                            ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </section>
            <!-- End Trusted Clients style one -->
<?php
        endif;
    }
}
