<?php

/**
 * Elementor daltech Working-Processs Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class Daltech_Working_Process extends \Elementor\Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve Working-Processs widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'daltech_Working-Process';
    }

    /**
     * Get widget title.
     *
     * Retrieve Working-Processs Nav Tab widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Working Process', 'daltech-core');
    }

    /**
     * Get widget icon.
     *
     * Retrieve Working-Processs Nav Tab widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-code';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the Working-Processs Nav Tab widget belongs to.
     *
     * @since 1.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return ['daltech'];
    }

    // Add The Input For User
    protected function register_controls()
    {

        $this->start_controls_section(
            'daltech_working-process_style',
            [
                'label'        => esc_html__('Content Style', 'daltech-core'),
                'tab'        => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'style',
            [
                'label'     => esc_html__('Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Style One', 'daltech-core'),
                ],
            ]
        );

        $this->add_control(
            'sec_title',
            [
                'label'         => esc_html__('Section Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('title', 'daltech-core'),
                'default'         => esc_html__('Default Title', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['1']],
            ]
        );
        $this->add_control(
            'sec_subtitle',
            [
                'label'         => esc_html__('Section Subtitle', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('subtitle', 'daltech-core'),
                'default'         => esc_html__('Default SubTitle', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['1']],
            ]
        );

        $layout_one_working_process_list = new \Elementor\Repeater();

        $layout_one_working_process_list->add_control(
            'title',
            [
                'label'         => esc_html__('Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('Title', 'daltech-core'),
                'default'         => esc_html__('Default Title', 'daltech-core'),
                'rows' =>     '2',
            ]
        );

        $layout_one_working_process_list->add_control(
            'number',
            [
                'label'         => esc_html__('Number', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'placeholder'     => esc_html__('number', 'daltech-core'),
                'default'         => esc_html__('1', 'daltech-core'),
                'label_block'     => true,
                'rows' =>     '1',
            ]
        );

        $layout_one_working_process_list->add_control(
            'form_icon_style',
            [
                'label'     => esc_html__('Form Icon Style', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::SELECT,
                'default'     => '1',
                'options'     => [
                    '1'      => esc_html__('Flaticon', 'daltech-core'),
                    '3'     => esc_html__('Icon Image', 'daltech-core'),
                    '2'      => esc_html__('Custom Icon', 'daltech-core'),
                ],
            ]
        );

        $layout_one_working_process_list->add_control(
            'flat_icon',
            [
                'label'      => esc_html__('Icon One', 'cleanu-core'),
                'type'       => \Elementor\Controls_Manager::ICON,
                'options'    => daltech_flaticons(),
                'include'    => daltech_include_flaticons(),
                'condition' => [
                    'form_icon_style' => '1'
                ]
            ]
        );

        $layout_one_working_process_list->add_control(
            'custom_icon',
            [
                'label'         => esc_html__('Custom Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'rows'          => '2',
                'condition' => [
                    'form_icon_style' => '2'
                ]
            ]
        );

        $layout_one_working_process_list->add_control(
            'icon_image',
            [
                'label'            => esc_html__('Add Image Icon', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'condition' => [
                    'form_icon_style' => '3'
                ]
            ]
        );

        $this->add_control(
            'layout_one_working_process_list',
            [
                'label'     => esc_html__('Working-Process List', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::REPEATER,
                'fields'     => $layout_one_working_process_list->get_controls(),
                'prevent_empty' => 'false',
                'title_field' => '{{{ name }}}',
                'condition'        => ['style'    =>    ['1']],
            ]
        );


        $this->add_control(
            'cta_title',
            [
                'label'         => esc_html__('Call To Action Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('Call To Action', 'daltech-core'),
                'default'         => esc_html__('Default Call To Action', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['1']],
            ]
        );

        $this->add_control(
            'cta_subtitle',
            [
                'label'         => esc_html__('Call To Action Sub Title', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::TEXTAREA,
                'label_block'     => true,
                'placeholder'     => esc_html__('Call To Action Sub Title', 'daltech-core'),
                'default'         => esc_html__('Default Call To Action Sub Title', 'daltech-core'),
                'rows' =>     '2',
                'condition'        => ['style'    =>    ['1']],
            ]
        );

        $this->add_control(
            'cta_image',
            [
                'label'            => esc_html__('Add Image', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'button_label',
            [
                'label'     => __('Button Label', 'daltech-core'),
                'type'         => \Elementor\Controls_Manager::TEXTAREA,
                'rows'         => 2,
                'default'      => __('Button Label', 'daltech-core'),
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'url',
            [
                'label'         => __('URL', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::URL,
                'placeholder'     => __('https://your-link.com', 'daltech-core'),
                'show_external' => true,
                'default'         => [
                    'url'             => '#',
                    'is_external'     => false,
                    'nofollow'         => false,
                ],
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'shape_one',
            [
                'label'            => esc_html__('Shape One', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );

        $this->add_control(
            'shape_two',
            [
                'label'            => esc_html__('Shape Two', 'daltech-core'),
                'type'             => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => \Elementor\Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'style' => ['1']
                ]
            ]
        );



        $this->end_controls_section();
    }

    // Output For User
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        if ($settings['style'] == '1') :
?>

            <!--<< Working-Process Section Start >>-->
            <section class="woeking-process fix section-padding section-bg-3">
                <div class="left-shape">
                    <?php
                    if (!empty($settings['shape_one']['url'])) {
                        echo daltech_img_tag(array(
                            'url'    => esc_url($settings['shape_one']['url']),
                        ));
                    }
                    ?>
                </div>
                <div class="right-shape">
                    <?php
                    if (!empty($settings['shape_two']['url'])) {
                        echo daltech_img_tag(array(
                            'url'    => esc_url($settings['shape_two']['url']),
                        ));
                    }
                    ?>
                </div>
                <div class="container">
                    <div class="section-title text-center">
                        <span class="color-style wow fadeInUp">
                            <?php echo wp_kses_post($settings['sec_subtitle'], 'daltech_kses_allowed_html'); ?></span>
                        <h2 class="text-white wow fadeInUp" data-wow-delay=".3s">
                            <?php echo wp_kses_post($settings['sec_title'], 'daltech_kses_allowed_html'); ?>
                        </h2>
                    </div>
                    <div class="row">
                        <?php
                        foreach ($settings['layout_one_working_process_list'] as $item) :
                        ?>
                            <div class="col-xl-3 col-lg-4 col-md-6 wow fadeInUp" data-wow-delay=".3s">
                                <div class="process-items">
                                    <span class="process-number"><?php echo wp_kses_post($item['number'], 'daltech_kses_allowed_html'); ?></span>
                                    <div class="content">
                                        <div class="icon">
                                            <?php if (!empty($item['flat_icon'])) : ?>
                                                <i class="<?php echo esc_attr($item['flat_icon']); ?>"></i>
                                            <?php endif; ?>
                                            <?php if (!empty($item['icon_image']['url'])) : ?>
                                                <img src="<?php echo esc_url($item['icon_image']['url']); ?>" alt="<?php echo get_bloginfo('name'); ?>">
                                            <?php endif; ?>
                                            <?php
                                            if (!empty($item['custom_icon'])) : ?>
                                                <i class="<?php echo esc_attr($item['custom_icon']); ?>"></i>
                                            <?php endif; ?>
                                        </div>
                                        <h3><?php echo wp_kses_post($item['title'], 'daltech_kses_allowed_html'); ?></h3>
                                    </div>
                                </div>
                            </div>
                        <?php
                        endforeach;
                        ?>
                    </div>
                    <div class="cta-banner-2 mb-0 wow fadeInUp" data-wow-delay=".4s">
                        <div class="cta-items">
                            <?php
                            if (!empty($settings['cta_image']['url'])) {
                                echo daltech_img_tag(array(
                                    'url'    => esc_url($settings['cta_image']['url']),
                                ));
                            }
                            ?>
                            <div class="content">
                                <p><?php echo wp_kses($settings['cta_subtitle'], 'daltech_allowed_tags'); ?></p>
                                <h6><?php echo wp_kses($settings['cta_title'], 'daltech_allowed_tags'); ?></h6>
                            </div>
                        </div>
                        <?php if (!empty($settings['button_label'])) : ?>
                            <a href="<?php echo esc_url($settings['url']['url']); ?>" class="theme-btn bg-white">
                                <span>
                                    <?php echo wp_kses($settings['button_label'], 'daltech_allowed_tags'); ?>
                                    <i class="fas fa-chevron-right"></i>
                                </span>
                            </a>
                        <?php endif; ?>
                    </div>
                </div>
            </section>
<?php
        endif;
    }
}
