<?php

/**
 * The Recent Post Widget class
 */

class BlogCategories extends \WP_Widget
{

    function __construct()
    {
        parent::__construct(
            'daltech_blog_categories_widget',
            __('Blog Categories Widget', 'daltech-core'),
            array('description' => __('A custom widget for displaying Categories.', 'daltech-core'))
        );
    }

    public function widget($args, $instance)
    {
        $title = apply_filters('widget_title', $instance['title']);
        $category_count = intval($instance['category_count']);


        echo $args['before_widget'];
        if ($title) {
            echo $args['before_title'] . $title . $args['after_title'];
        }
?>
        <div class="widget_categories">
            <ul>
                <?php
                $categories = get_categories(array(
                    'hide_empty' => true, // Include empty categories
                ));
                $i = 1;
                if (!empty($categories)) :
                    foreach ($categories as $category) :
                ?>
                        <li><a href="<?php echo esc_url(get_category_link($category->term_id)) ?>"><?php echo esc_html($category->name) ?><span><?php echo esc_html($category->category_count) ?></span></a>
                        </li>
                    <?php
                        if ($i ==  $category_count) {
                            break;
                        }
                        $i++;
                    endforeach;
                    ?>
                <?php endif; ?>
            </ul><!-- /.sidebar__categories list-unstyled -->
        </div>
    <?php
        echo $args['after_widget'];
    }

    public function form($instance)
    {
        $title = !empty($instance['title']) ? $instance['title'] : __('Categories', 'daltech-core');
        $category_count = !empty($instance['category_count']) ? $instance['category_count'] : 5;


    ?>
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'daltech-core'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>">
        </p>

        <p>
            <label for="<?php echo $this->get_field_id('category_count'); ?>"><?php _e('Number of Categories:', 'daltech-core'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('category_count'); ?>" name="<?php echo $this->get_field_name('category_count'); ?>" type="number" value="<?php echo esc_attr($category_count); ?>">
        </p>
<?php
    }

    public function update($new_instance, $old_instance)
    {
        $instance = array();
        $instance['title'] = sanitize_text_field($new_instance['title']);
        $instance['category_count'] = intval($new_instance['category_count']);
        return $instance;
    }
}

// Register and load the widget
function daltech_category_widget()
{
    register_widget('BlogCategories');
}
add_action('widgets_init', 'daltech_category_widget');
