<?php

/**
 * daltech Social Media widget
 *
 * Displays Social Media widget
 *
 * @author       validthemes
 * @category     Widgets
 * @package      daltech/widgets
 * @version      1.0.0
 * @extends      WP_Widget
 */
class Daltech_Social_Media extends WP_Widget
{

    // vars
    private $icons = array(
        'facebook'   => 'facebook-f',
        'twitter'    => 'twitter',
        'linkedin'   => 'fab fa-linkedin-in',
        'pinterest'  => 'pinterest',
        'instagram'  => 'fab fa-instagram',
        'youtube'   => 'fab fa-youtube',

    );

    /**
     * Sets up a new Recent Posts widget instance.
     */
    public function __construct()
    {
        $widget_ops = array(
            'classname'                   => 'social',
            'description'                 => esc_html__('A widget shows the social media icons.', 'daltech-core'),
            'customize_selective_refresh' => true,
        );
        parent::__construct('social-media', esc_html__('Daltech Social Media', 'daltech-core'), $widget_ops);
    }

    /**
     * Front-end display of widget.
     *
     * @see WP_Widget::widget()
     *
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     */
    public function widget($args, $instance)
    {
        if (!isset($args['widget_id'])) {
            $args['widget_id'] = $this->id;
        }


        $title = apply_filters('widget_title', $instance['title']);
        $widget = $args['before_widget'];

        $widget .= '<div class="single-sidebar-widget">';
        $widget .= '<div class="wid-title">';
        $widget .= '<h3>' . $title . '</h3>';
        $widget .= '</div>';

        $widget .= '<div class="social-link">';

        foreach ($this->icons as $key => $icon) :
            $i = isset($instance[$key]) ? $instance[$key] : '';

            if (!empty($i)) :
                $widget .= '<a href="' . esc_url($i) . '"><i class="fab fa-' . esc_attr($icon) . '"></i></a>';
            endif;

        endforeach;

        $widget .= '</div>';
        $widget .= '</div>';
        $widget .= $args['after_widget'];
        print $widget;
    }



    /**
     * Back-end widget form.
     *
     * @see WP_Widget::form()
     *
     * @param array $instance Previously saved values from database.
     */
    public function form($instance)
    {
        $title = !empty($instance['title']) ? $instance['title'] : __('Title', 'daltech-core');
        foreach ($this->icons as $key => $icon) {
            $defaults[$key] = '';
        }
        // prepare options
        $instance = wp_parse_args((array) $instance, $defaults);

?>
        <!-- Title -->
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'daltech-core'); ?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>">
        </p>
        <?php
        foreach ($this->icons as $key => $icon) : ?>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id($key)); ?>"><?php echo esc_html($key); ?></label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id($key)); ?>" name="<?php echo esc_attr($this->get_field_name($key)); ?>" type="text" value="<?php echo esc_attr($instance[$key]); ?>" />
            </p>
<?php
        endforeach;
    }
}

function daltech_register_social_media_widgets()
{
    register_widget('Daltech_Social_Media');
}
add_action('widgets_init', 'daltech_register_social_media_widgets');
